@@ -99,11 +99,9 @@ acpica_exclude_paths()
 	local paths
 
 	paths="\
-		include/acpi/acclib.h \
 		include/acpi/acdisasm.h \
 		include/acpi/platform/accygwin.h \
 		include/acpi/platform/acefi.h \
-		include/acpi/platform/acefiex.h \
 		include/acpi/platform/acfreebsd.h \
 		include/acpi/platform/achaiku.h \
 		include/acpi/platform/acintel.h \
@@ -113,8 +111,6 @@ acpica_exclude_paths()
 		include/acpi/platform/acos2.h \
 		include/acpi/platform/acwin.h \
 		include/acpi/platform/acwin64.h \
-		include/acpi/platform/acdragonfly.h \
-		include/acpi/platform/acdragonflyex.h \
 		drivers/acpi/acpica/utclib.c \
 	"
 	echo $paths
