@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -126,9 +126,7 @@
 const AH_DEVICE_ID  AslDeviceIds[] =
 {
     {"10EC5640",    "Realtek I2S Audio Codec"},
-    {"80860F09",    "Intel PWM Controller"},
     {"80860F0A",    "Intel Atom UART Controller"},
-    {"80860F0E",    "Intel SPI Controller"},
     {"80860F14",    "Intel Baytrail SDIO/MMC Host Controller"},
     {"80860F28",    "Intel SST Audio DSP"},
     {"80860F41",    "Intel Baytrail I2C Host Controller"},
@@ -147,20 +145,12 @@ const AH_DEVICE_ID  AslDeviceIds[] =
     {"ACPI000D",    "Power Meter Device"},
     {"ACPI000E",    "Time and Alarm Device"},
     {"ACPI000F",    "User Presence Detection Device"},
-    {"ADMA0F28",    "Intel Audio DMA"},
-    {"AMCR0F28",    "Intel Audio Machine Driver"},
     {"ATK4001",     "Asus Radio Control Button"},
     {"ATML1000",    "Atmel Touchscreen Controller"},
-    {"AUTH2750",    "AuthenTec AES2750"},
     {"BCM2E39",     "Broadcom BT Serial Bus Driver over UART Bus Enumerator"},
-    {"BCM4752E",    "Broadcom GPS Controller"},
-    {"BMG0160",     "Bosch Gyro Sensor"},
     {"CPLM3218",    "Capella Micro CM3218x Ambient Light Sensor"},
     {"DELLABCE",    "Dell Airplane Mode Switch Driver"},
     {"DLAC3002",    "Qualcomm Atheros Bluetooth UART Transport"},
-    {"FTTH5506",    "FocalTech 5506 Touch Controller"},
-    {"HAD0F28",     "Intel HDMI Audio Driver"},
-    {"INBC0000",    "GPIO Expander"},
     {"INT0002",     "Virtual GPIO Controller"},
     {"INT0800",     "Intel 82802 Firmware Hub Device"},
     {"INT3394",     "ACPI System Fan"},
@@ -169,7 +159,6 @@ const AH_DEVICE_ID  AslDeviceIds[] =
     {"INT33A1",     "Intel Power Engine"},
     {"INT33BB",     "Intel Baytrail SD Host Controller"},
     {"INT33BD",     "Intel Baytrail Mailbox Device"},
-    {"INT33BE",     "Camera Sensor OV5693"},
     {"INT33C0",     "Intel Serial I/O SPI Host Controller"},
     {"INT33C1",     "Intel Serial I/O SPI Host Controller"},
     {"INT33C2",     "Intel Serial I/O I2C Host Controller"},
@@ -188,12 +177,9 @@ const AH_DEVICE_ID  AslDeviceIds[] =
     {"INT33D4",     "Intel GPIO Buttons"},
     {"INT33D6",     "Intel Virtual Buttons Device"},
     {"INT33F0",     "Camera Sensor MT9M114"},
-    {"INT33F4",     "XPOWER PMIC Controller"},
-    {"INT33F5",     "TI PMIC Controller"},
     {"INT33FB",     "MIPI-CSI Camera Sensor OV2722"},
     {"INT33FC",     "Intel Baytrail GPIO Controller"},
     {"INT33FD",     "Intel Baytrail Power Management IC"},
-    {"INT33FE",     "XPOWER Battery Device"},
     {"INT3400",     "Intel Dynamic Power Performance Management"},
     {"INT3401",     "Intel Extended Thermal Model CPU"},
     {"INT3403",     "DPTF Temperature Sensor"},
@@ -213,10 +199,8 @@ const AH_DEVICE_ID  AslDeviceIds[] =
     {"LNXSYSTM",    "ACPI Root Node"},
     {"LNXTHERM",    "ACPI Thermal Zone"},
     {"LNXVIDEO",    "ACPI Video Controller"},
-    {"MAX17047",    "Fuel Gauge Controller"},
     {"MSFT0101",    "TPM 2.0 Security Device"},
     {"NXP5442",     "NXP 5442 Near Field Communications Controller"},
-    {"NXP5472",     "NXP NFC"},
     {"PNP0000",     "8259-compatible Programmable Interrupt Controller"},
     {"PNP0001",     "EISA Interrupt Controller"},
     {"PNP0002",     "MCA Interrupt Controller"},
@@ -269,13 +253,7 @@ const AH_DEVICE_ID  AslDeviceIds[] =
     {"PNP0D40",     "SDA Standard Compliant SD Host Controller"},
     {"PNP0D80",     "Windows-compatible System Power Management Controller"},
     {"PNP0F03",     "Microsoft PS/2-style Mouse"},
-    {"PNP0F13",     "PS/2 Mouse"},
-    {"RTL8723",     "Realtek Wireless Controller"},
-    {"SMB0349",     "Charger"},
     {"SMO91D0",     "Sensor Hub"},
-    {"SMSC3750",    "SMSC 3750 USB MUX"},
-    {"SSPX0000",    "Intel SSP Device"},
-    {"TBQ24296",    "Charger"},
 
     {NULL, NULL}
 };
