@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,91 +111,54 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "acpi.h"
 #include "accommon.h"
-#include "acuuid.h"
 
 #define _COMPONENT          ACPI_UTILITIES
         ACPI_MODULE_NAME    ("ahuuids")
 
-
 /*
  * Table of "known" (ACPI-related) UUIDs
  */
-const AH_UUID  Gbl_AcpiUuids[] =
+const AH_UUID  AcpiUuids[] =
 {
-    {"[Controllers]",               NULL},
-    {"GPIO Controller",             UUID_GPIO_CONTROLLER},
-    {"USB Controller",              UUID_USB_CONTROLLER},
-    {"SATA Controller",             UUID_SATA_CONTROLLER},
+    {"PCI Host Bridge Device",
+        "33db4d5b-1ff7-401c-9657-7441c03dd766"},
 
-    {"[Devices]",                   NULL},
-    {"PCI Host Bridge Device",      UUID_PCI_HOST_BRIDGE},
-    {"HID I2C Device",              UUID_I2C_DEVICE},
-    {"Power Button Device",         UUID_POWER_BUTTON},
+    {"Platform-wide Capabilities",
+        "0811b06e-4a27-44f9-8d60-3cbbc22e7b48"},
 
-    {"[Interfaces]",                NULL},
-    {"Device Labeling Interface",   UUID_DEVICE_LABELING},
-    {"Physical Presence Interface", UUID_PHYSICAL_PRESENCE},
+    {"Dynamic Enumeration",
+        "d8c1a3a6-be9b-4c9b-91bf-c3cb81fc5daf"},
 
-    {"[Non-volatile DIMM and NFIT table]",       NULL},
-    {"Volatile Memory Region",      UUID_VOLATILE_MEMORY},
-    {"Persistent Memory Region",    UUID_PERSISTENT_MEMORY},
-    {"NVDIMM Control Region",       UUID_CONTROL_REGION},
-    {"NVDIMM Data Region",          UUID_DATA_REGION},
-    {"Volatile Virtual Disk",       UUID_VOLATILE_VIRTUAL_DISK},
-    {"Volatile Virtual CD",         UUID_VOLATILE_VIRTUAL_CD},
-    {"Persistent Virtual Disk",     UUID_PERSISTENT_VIRTUAL_DISK},
-    {"Persistent Virtual CD",       UUID_PERSISTENT_VIRTUAL_CD},
+    {"GPIO Controller",
+        "4f248f40-d5e2-499f-834c-27758ea1cd3f"},
 
-    {"[Processor Properties]",      NULL},
-    {"Cache Properties",            UUID_CACHE_PROPERTIES},
-    {"Physical Package Property",   UUID_PHYSICAL_PROPERTY},
+    {"Battery Thermal Limit",
+        "4c2067e3-887d-475c-9720-4af1d3ed602e"},
 
-    {"[Miscellaneous]",             NULL},
-    {"Platform-wide Capabilities",  UUID_PLATFORM_CAPABILITIES},
-    {"Dynamic Enumeration",         UUID_DYNAMIC_ENUMERATION},
-    {"Battery Thermal Limit",       UUID_BATTERY_THERMAL_LIMIT},
-    {"Thermal Extensions",          UUID_THERMAL_EXTENSIONS},
-    {"Device Properties for _DSD",  UUID_DEVICE_PROPERTIES},
+    {"Thermal Extensions",
+        "14d399cd-7a27-4b18-8fb4-7cb7b9f4e500"},
+
+    {"USB Controller",
+        "ce2ee385-00e6-48cb-9f05-2edb927c4899"},
+
+    {"HID I2C Device",
+        "3cdff6f7-4267-4555-ad05-b30a3d8938de"},
+
+    {"Power Button Device",
+        "dfbcf3c5-e7a5-44e6-9c1f-29c76f6e059c"},
+
+    {"Device Labeling Interface",
+        "e5c937d0-3553-4d7a-9117-ea4d19c3434d"},
+
+    {"SATA Controller",
+        "e4db149b-fcfe-425b-a6d8-92357d78fc7f"},
+
+    {"Physical Presence Interface",
+        "3dddfaa6-361b-4eb4-a424-8d10089d1653"},
 
     {NULL, NULL}
 };
@@ -224,18 +187,11 @@ AcpiAhMatchUuid (
 
     /* Walk the table of known ACPI-related UUIDs */
 
-    for (Info = Gbl_AcpiUuids; Info->Description; Info++)
+    for (Info = AcpiUuids; Info->Description; Info++)
     {
-        /* Null string means description is a UUID class */
-
-        if (!Info->String)
-        {
-            continue;
-        }
-
         AcpiUtConvertStringToUuid (Info->String, UuidBuffer);
 
-        if (!memcmp (Data, UuidBuffer, UUID_BUFFER_LENGTH))
+        if (!ACPI_MEMCMP (Data, UuidBuffer, UUID_BUFFER_LENGTH))
         {
             return (Info->Description);
         }
