@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -217,7 +217,7 @@ AcpiGetopt(
         {
             return (ACPI_OPT_END);
         }
-        else if (strcmp (argv[AcpiGbl_Optind], "--") == 0)
+        else if (ACPI_STRCMP (argv[AcpiGbl_Optind], "--") == 0)
         {
             AcpiGbl_Optind++;
             return (ACPI_OPT_END);
@@ -231,7 +231,7 @@ AcpiGetopt(
     /* Make sure that the option is legal */
 
     if (CurrentChar == ':' ||
-       (OptsPtr = strchr (opts, CurrentChar)) == NULL)
+       (OptsPtr = ACPI_STRCHR (opts, CurrentChar)) == NULL)
     {
         ACPI_OPTION_ERROR ("Illegal option: -", CurrentChar);
 
