@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include <string.h>
@@ -158,15 +123,6 @@
         ACPI_MODULE_NAME    ("aslanalyze")
 
 
-/* Local Prototypes */
-
-static ACPI_STATUS
-ApDeviceSubtreeWalk (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    void                    *Context);
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AnIsInternalMethod
@@ -184,8 +140,8 @@ AnIsInternalMethod (
     ACPI_PARSE_OBJECT       *Op)
 {
 
-    if ((!strcmp (Op->Asl.ExternalName, "\\_OSI")) ||
-        (!strcmp (Op->Asl.ExternalName, "_OSI")))
+    if ((!ACPI_STRCMP (Op->Asl.ExternalName, "\\_OSI")) ||
+        (!ACPI_STRCMP (Op->Asl.ExternalName, "_OSI")))
     {
         return (TRUE);
     }
@@ -211,8 +167,8 @@ AnGetInternalMethodReturnType (
     ACPI_PARSE_OBJECT       *Op)
 {
 
-    if ((!strcmp (Op->Asl.ExternalName, "\\_OSI")) ||
-        (!strcmp (Op->Asl.ExternalName, "_OSI")))
+    if ((!ACPI_STRCMP (Op->Asl.ExternalName, "\\_OSI")) ||
+        (!ACPI_STRCMP (Op->Asl.ExternalName, "_OSI")))
     {
         return (ACPI_BTYPE_STRING);
     }
@@ -256,7 +212,8 @@ AnCheckId (
     Length = strlen (Op->Asl.Value.String);
     if (!Length)
     {
-        AslError (ASL_ERROR, ASL_MSG_NULL_STRING, Op, NULL);
+        AslError (ASL_ERROR, ASL_MSG_NULL_STRING,
+            Op, NULL);
         return;
     }
 
@@ -307,7 +264,7 @@ AnCheckId (
         return;
     }
 
-    /* _HID Length is valid (7 or 8), now check prefix (first 3 or 4 chars) */
+    /* _HID Length is valid (7 or 8), now check the prefix (first 3 or 4 chars) */
 
     if (Length == 7)
     {
@@ -347,8 +304,8 @@ AnCheckId (
     {
         if (!isxdigit ((int) Op->Asl.Value.String[i]))
         {
-            AslError (ASL_ERROR, ASL_MSG_HID_SUFFIX,
-                Op, &Op->Asl.Value.String[i]);
+         AslError (ASL_ERROR, ASL_MSG_HID_SUFFIX,
+            Op, &Op->Asl.Value.String[i]);
             break;
         }
     }
@@ -425,35 +382,28 @@ AnCheckMethodReturnValue (
 
     Node = ArgOp->Asl.Node;
 
-    if (!Node)
-    {
-        /* No error message, this can happen and is OK */
-
-        return;
-    }
 
     /* Examine the parent op of this method */
 
     OwningOp = Node->Op;
-    if (OwningOp->Asl.CompileFlags & OP_METHOD_NO_RETVAL)
+    if (OwningOp->Asl.CompileFlags & NODE_METHOD_NO_RETVAL)
     {
         /* Method NEVER returns a value */
 
         AslError (ASL_ERROR, ASL_MSG_NO_RETVAL, Op, Op->Asl.ExternalName);
     }
-    else if (OwningOp->Asl.CompileFlags & OP_METHOD_SOME_NO_RETVAL)
+    else if (OwningOp->Asl.CompileFlags & NODE_METHOD_SOME_NO_RETVAL)
     {
         /* Method SOMETIMES returns a value, SOMETIMES not */
 
-        AslError (ASL_WARNING, ASL_MSG_SOME_NO_RETVAL,
-            Op, Op->Asl.ExternalName);
+        AslError (ASL_WARNING, ASL_MSG_SOME_NO_RETVAL, Op, Op->Asl.ExternalName);
     }
     else if (!(ThisNodeBtype & RequiredBtypes))
     {
         /* Method returns a value, but the type is wrong */
 
-        AnFormatBtype (AslGbl_StringBuffer, ThisNodeBtype);
-        AnFormatBtype (AslGbl_StringBuffer2, RequiredBtypes);
+        AnFormatBtype (StringBuffer, ThisNodeBtype);
+        AnFormatBtype (StringBuffer2, RequiredBtypes);
 
         /*
          * The case where the method does not return any value at all
@@ -463,11 +413,11 @@ AnCheckMethodReturnValue (
          */
         if (ThisNodeBtype != 0)
         {
-            sprintf (AslGbl_MsgBuffer,
+            sprintf (MsgBuffer,
                 "Method returns [%s], %s operator requires [%s]",
-                AslGbl_StringBuffer, OpInfo->Name, AslGbl_StringBuffer2);
+                StringBuffer, OpInfo->Name, StringBuffer2);
 
-            AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, ArgOp, AslGbl_MsgBuffer);
+            AslError (ASL_ERROR, ASL_MSG_INVALID_TYPE, ArgOp, MsgBuffer);
         }
     }
 }
@@ -523,13 +473,12 @@ AnIsResultUsed (
         {
             return (TRUE);
         }
-
         return (FALSE);
 
     /* Not used if one of these is the parent */
 
     case PARSEOP_METHOD:
-    case PARSEOP_DEFINITION_BLOCK:
+    case PARSEOP_DEFINITIONBLOCK:
     case PARSEOP_ELSE:
 
         return (FALSE);
@@ -563,14 +512,14 @@ ApCheckForGpeNameConflict (
 {
     ACPI_PARSE_OBJECT       *NextOp;
     UINT32                  GpeNumber;
-    char                    Name[ACPI_NAMESEG_SIZE + 1];
-    char                    Target[ACPI_NAMESEG_SIZE];
+    char                    Name[ACPI_NAME_SIZE + 1];
+    char                    Target[ACPI_NAME_SIZE];
 
 
     /* Need a null-terminated string version of NameSeg */
 
     ACPI_MOVE_32_TO_32 (Name, &Op->Asl.NameSeg);
-    Name[ACPI_NAMESEG_SIZE] = 0;
+    Name[ACPI_NAME_SIZE] = 0;
 
     /*
      * For a GPE method:
@@ -586,7 +535,7 @@ ApCheckForGpeNameConflict (
 
     /* Verify 3rd/4th chars are a valid hex value */
 
-    GpeNumber = strtoul (&Name[2], NULL, 16);
+    GpeNumber = ACPI_STRTOUL (&Name[2], NULL, 16);
     if (GpeNumber == ACPI_UINT32_MAX)
     {
         return;
@@ -622,7 +571,7 @@ ApCheckForGpeNameConflict (
         if ((NextOp->Asl.ParseOpcode == PARSEOP_METHOD) ||
             (NextOp->Asl.ParseOpcode == PARSEOP_NAME))
         {
-            if (ACPI_COMPARE_NAMESEG (Target, NextOp->Asl.NameSeg))
+            if (ACPI_COMPARE_NAME (Target, NextOp->Asl.NameSeg))
             {
                 /* Found both _Exy and _Lxy in the same scope, error */
 
@@ -666,7 +615,7 @@ ApCheckRegMethod (
 
     /* We are only interested in _REG methods */
 
-    if (!ACPI_COMPARE_NAMESEG (METHOD_NAME__REG, &Op->Asl.NameSeg))
+    if (!ACPI_COMPARE_NAME (METHOD_NAME__REG, &Op->Asl.NameSeg))
     {
         return;
     }
@@ -694,108 +643,6 @@ ApCheckRegMethod (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    ApFindNameInDeviceTree
- *
- * PARAMETERS:  Name                - Name to search for
- *              Op                  - Current parse op
- *
- * RETURN:      TRUE if name found in the same scope as Op.
- *
- * DESCRIPTION: Determine if a name appears in the same scope as Op, as either
- *              a Method() or a Name(). "Same scope" can mean under an If or
- *              Else statement.
- *
- * NOTE: Detects _HID/_ADR in this type of construct (legal in ACPI 6.1+)
- *
- * Scope (\_SB.PCI0)
- * {
- *     Device (I2C0)
- *     {
- *         If (SMD0 != 4) {
- *             Name (_HID, "INT3442")
- *         } Else {
- *             Name (_ADR, 0x400)
- *         }
- *     }
- * }
- ******************************************************************************/
-
-BOOLEAN
-ApFindNameInDeviceTree (
-    char                    *Name,
-    ACPI_PARSE_OBJECT       *Op)
-{
-    ACPI_STATUS             Status;
-
-
-    Status = TrWalkParseTree (Op, ASL_WALK_VISIT_DOWNWARD,
-        ApDeviceSubtreeWalk, NULL, Name);
-
-    if (Status == AE_CTRL_TRUE)
-    {
-        return (TRUE);  /* Found a match */
-    }
-
-    return (FALSE);
-}
-
-
-/* Callback function for interface above */
-
-static ACPI_STATUS
-ApDeviceSubtreeWalk (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    void                    *Context)
-{
-    char                    *Name = ACPI_CAST_PTR (char, Context);
-
-
-    switch (Op->Asl.ParseOpcode)
-    {
-    case PARSEOP_DEVICE:
-
-        /* Level 0 is the starting device, ignore it */
-
-        if (Level > 0)
-        {
-            /* Ignore sub-devices */
-
-            return (AE_CTRL_DEPTH);
-        }
-        break;
-
-    case PARSEOP_NAME:
-    case PARSEOP_METHOD:
-
-        /* These are what we are looking for */
-
-        if (ACPI_COMPARE_NAMESEG (Name, Op->Asl.NameSeg))
-        {
-            return (AE_CTRL_TRUE);
-        }
-        return (AE_CTRL_DEPTH);
-
-    case PARSEOP_SCOPE:
-    case PARSEOP_FIELD:
-    case PARSEOP_OPERATIONREGION:
-
-        /*
-         * We want to ignore these, because either they can be large
-         * subtrees or open a scope to somewhere else.
-         */
-        return (AE_CTRL_DEPTH);
-
-    default:
-        break;
-    }
-
-    return (AE_OK);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    ApFindNameInScope
@@ -831,7 +678,7 @@ ApFindNameInScope (
         if ((Next->Asl.ParseOpcode == PARSEOP_METHOD) ||
             (Next->Asl.ParseOpcode == PARSEOP_NAME))
         {
-            if (ACPI_COMPARE_NAMESEG (Name, Next->Asl.NameSeg))
+            if (ACPI_COMPARE_NAME (Name, Next->Asl.NameSeg))
             {
                 return (TRUE);
             }
