@@ -8,13 +8,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2012, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +31,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +43,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +55,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +80,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +92,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -155,15 +155,19 @@ AnMapArgTypeToBtype (
     /* Simple types */
 
     case ARGI_ANYTYPE:
+
         return (ACPI_BTYPE_OBJECTS_AND_REFS);
 
     case ARGI_PACKAGE:
+
         return (ACPI_BTYPE_PACKAGE);
 
     case ARGI_EVENT:
+
         return (ACPI_BTYPE_EVENT);
 
     case ARGI_MUTEX:
+
         return (ACPI_BTYPE_MUTEX);
 
     case ARGI_DDBHANDLE:
@@ -183,31 +187,36 @@ AnMapArgTypeToBtype (
     case ARGI_BUFFER:
     case ARGI_BUFFER_OR_STRING:
     case ARGI_COMPUTEDATA:
+
         return (ACPI_BTYPE_COMPUTE_DATA);
 
     /* References */
 
     case ARGI_INTEGER_REF:
+
         return (ACPI_BTYPE_INTEGER);
 
     case ARGI_OBJECT_REF:
+
         return (ACPI_BTYPE_ALL_OBJECTS);
 
     case ARGI_DEVICE_REF:
+
         return (ACPI_BTYPE_DEVICE_OBJECTS);
 
     case ARGI_REFERENCE:
+
         return (ACPI_BTYPE_REFERENCE);
 
     case ARGI_TARGETREF:
     case ARGI_FIXED_TARGET:
     case ARGI_SIMPLE_TARGET:
+
         return (ACPI_BTYPE_OBJECTS_AND_REFS);
 
     /* Complex types */
 
     case ARGI_DATAOBJECT:
-
         /*
          * Buffer, string, package or reference to a Op -
          * Used only by SizeOf operator
@@ -222,6 +231,7 @@ AnMapArgTypeToBtype (
         return (ACPI_BTYPE_STRING | ACPI_BTYPE_BUFFER | ACPI_BTYPE_PACKAGE);
 
     case ARGI_REF_OR_STRING:
+
         return (ACPI_BTYPE_STRING | ACPI_BTYPE_REFERENCE);
 
     case ARGI_REGION_OR_BUFFER:
@@ -231,10 +241,12 @@ AnMapArgTypeToBtype (
         return (ACPI_BTYPE_REGION | ACPI_BTYPE_BUFFER | ACPI_BTYPE_FIELD_UNIT);
 
     case ARGI_DATAREFOBJ:
+
         return (ACPI_BTYPE_INTEGER |ACPI_BTYPE_STRING | ACPI_BTYPE_BUFFER |
             ACPI_BTYPE_PACKAGE | ACPI_BTYPE_REFERENCE | ACPI_BTYPE_DDB_HANDLE);
 
     default:
+
         break;
     }
 
@@ -279,31 +291,38 @@ AnMapEtypeToBtype (
         switch (Etype)
         {
         case ACPI_TYPE_INTEGER:
+
             return (ACPI_BTYPE_COMPUTE_DATA | ACPI_BTYPE_DDB_HANDLE);
 
         case ACPI_TYPE_STRING:
         case ACPI_TYPE_BUFFER:
+
             return (ACPI_BTYPE_COMPUTE_DATA);
 
         case ACPI_TYPE_PACKAGE:
+
             return (ACPI_BTYPE_PACKAGE);
 
         case ACPI_TYPE_FIELD_UNIT:
+
             return (ACPI_BTYPE_COMPUTE_DATA | ACPI_BTYPE_FIELD_UNIT);
 
         case ACPI_TYPE_BUFFER_FIELD:
+
             return (ACPI_BTYPE_COMPUTE_DATA | ACPI_BTYPE_BUFFER_FIELD);
 
         case ACPI_TYPE_DDB_HANDLE:
+
             return (ACPI_BTYPE_INTEGER | ACPI_BTYPE_DDB_HANDLE);
 
-        case ACPI_BTYPE_DEBUG_OBJECT:
+        case ACPI_TYPE_DEBUG_OBJECT:
 
             /* Cannot be used as a source operand */
 
             return (0);
 
         default:
+
             return (1 << (Etype - 1));
         }
     }
@@ -331,6 +350,7 @@ AnMapEtypeToBtype (
         return (ACPI_BTYPE_REFERENCE);
 
     default:
+
         printf ("Unhandled encoded type: %X\n", Etype);
         return (0);
     }
@@ -510,51 +530,67 @@ AnMapObjTypeToBtype (
     switch (Op->Asl.ParseOpcode)
     {
     case PARSEOP_OBJECTTYPE_BFF:        /* "BuffFieldObj" */
+
         return (ACPI_BTYPE_BUFFER_FIELD);
 
     case PARSEOP_OBJECTTYPE_BUF:        /* "BuffObj" */
+
         return (ACPI_BTYPE_BUFFER);
 
     case PARSEOP_OBJECTTYPE_DDB:        /* "DDBHandleObj" */
+
         return (ACPI_BTYPE_DDB_HANDLE);
 
     case PARSEOP_OBJECTTYPE_DEV:        /* "DeviceObj" */
+
         return (ACPI_BTYPE_DEVICE);
 
     case PARSEOP_OBJECTTYPE_EVT:        /* "EventObj" */
+
         return (ACPI_BTYPE_EVENT);
 
     case PARSEOP_OBJECTTYPE_FLD:        /* "FieldUnitObj" */
+
         return (ACPI_BTYPE_FIELD_UNIT);
 
     case PARSEOP_OBJECTTYPE_INT:        /* "IntObj" */
+
         return (ACPI_BTYPE_INTEGER);
 
     case PARSEOP_OBJECTTYPE_MTH:        /* "MethodObj" */
+
         return (ACPI_BTYPE_METHOD);
 
     case PARSEOP_OBJECTTYPE_MTX:        /* "MutexObj" */
+
         return (ACPI_BTYPE_MUTEX);
 
     case PARSEOP_OBJECTTYPE_OPR:        /* "OpRegionObj" */
+
         return (ACPI_BTYPE_REGION);
 
     case PARSEOP_OBJECTTYPE_PKG:        /* "PkgObj" */
+
         return (ACPI_BTYPE_PACKAGE);
 
     case PARSEOP_OBJECTTYPE_POW:        /* "PowerResObj" */
+
         return (ACPI_BTYPE_POWER);
 
     case PARSEOP_OBJECTTYPE_STR:        /* "StrObj" */
+
         return (ACPI_BTYPE_STRING);
 
     case PARSEOP_OBJECTTYPE_THZ:        /* "ThermalZoneObj" */
+
         return (ACPI_BTYPE_THERMAL);
 
     case PARSEOP_OBJECTTYPE_UNK:        /* "UnknownObj" */
+
         return (ACPI_BTYPE_OBJECTS_AND_REFS);
 
     default:
+
         return (0);
     }
 }
