@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #ifndef __ASLCOMPILER_H
 #define __ASLCOMPILER_H
 
@@ -170,6 +135,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
@@ -181,7 +147,6 @@
 #include "aslmessages.h"
 #include "aslglobal.h"
 #include "preprocess.h"
-#include "dtcompiler.h"
 
 
 /*******************************************************************************
@@ -218,11 +183,6 @@ AslPushInputFileStack (
     FILE                    *InputFile,
     char                    *Filename);
 
-void
-AslParserCleanup (
-    void);
-
-
 /*
  * aslstartup - entered from main()
  */
@@ -254,12 +214,8 @@ void
 AslCompilerFileHeader (
     UINT32                  FileId);
 
-ACPI_STATUS
-CmDoCompile (
-    void);
-
 int
-CmDoAslMiddleAndBackEnd (
+CmDoCompile (
     void);
 
 void
@@ -271,61 +227,12 @@ CmCleanupAndExit (
     void);
 
 ACPI_STATUS
-AslDoDisassembly (
-    void);
+FlCheckForAcpiTable (
+    FILE                    *Handle);
 
-
-/*
- * aslallocate - memory allocation
- */
-void *
-UtLocalCalloc (
-    UINT32                  Size);
-
-void
-UtExpandLineBuffers (
-    void);
-
-void
-UtReallocLineBuffers (
-    char                    **Buffer,
-    UINT32                  OldSize,
-    UINT32                  NewSize);
-
-void
-UtFreeLineBuffers (
-    void);
-
-
-/*
- * aslcache - local cache support
- */
-char *
-UtLocalCacheCalloc (
-    UINT32                  Length);
-
-ACPI_PARSE_OBJECT *
-UtParseOpCacheCalloc (
-    void);
-
-DT_SUBTABLE *
-UtSubtableCacheCalloc (
-    void);
-
-DT_FIELD *
-UtFieldCacheCalloc (
-    void);
-
-void
-UtDeleteLocalCaches (
-    void);
-
-
-/*
- * aslascii - ascii support
- */
 ACPI_STATUS
-FlIsFileAsciiSource (
+FlCheckForAscii (
+    FILE                    *Handle,
     char                    *Filename,
     BOOLEAN                 DisplayErrors);
 
@@ -445,10 +352,6 @@ ApFindNameInScope (
     char                    *Name,
     ACPI_PARSE_OBJECT       *Op);
 
-BOOLEAN
-ApFindNameInDeviceTree (
-    char                    *Name,
-    ACPI_PARSE_OBJECT       *Op);
 
 /*
  * aslerror - error handling/reporting
@@ -457,16 +360,6 @@ void
 AslAbort (
     void);
 
-void
-AslDualParseOpError (
-    UINT8                   Level,
-    UINT16                  MainMessageId,
-    ACPI_PARSE_OBJECT       *MainOp,
-    char                    *MainMessage,
-    UINT16                  SecondMessageId,
-    ACPI_PARSE_OBJECT       *SecondOp,
-    char                    *SecondaryMessage);
-
 void
 AslError (
     UINT8                   Level,
@@ -474,24 +367,12 @@ AslError (
     ACPI_PARSE_OBJECT       *Op,
     char                    *ExtraMessage);
 
-void
-AslCheckExpectedExceptions (
-    void);
-
-ACPI_STATUS
-AslExpectException (
-    char                    *MessageIdString);
-
-ACPI_STATUS
-AslElevateException (
-    char                    *MessageIdString);
-
 ACPI_STATUS
 AslDisableException (
     char                    *MessageIdString);
 
 BOOLEAN
-AslIsExceptionIgnored (
+AslIsExceptionDisabled (
     UINT8                   Level,
     UINT16                  MessageId);
 
@@ -710,7 +591,7 @@ OpnDoPackage (
 
 
 /*
- * aslopt - optimization
+ * aslopt - optmization
  */
 void
 OptOptimizeNamePath (
@@ -721,35 +602,6 @@ OptOptimizeNamePath (
     ACPI_NAMESPACE_NODE     *TargetNode);
 
 
-/*
- * aslpld - ToPLD macro support
- */
-void
-OpcDoPld (
-    ACPI_PARSE_OBJECT       *Op);
-
-
-/*
- * aslprintf - Printf/Fprintf macros
- */
-void
-OpcDoPrintf (
-    ACPI_PARSE_OBJECT       *Op);
-
-void
-OpcDoFprintf (
-    ACPI_PARSE_OBJECT       *Op);
-
-
-/*
- * aslprune - parse tree pruner
- */
-void
-AslPruneParseTree (
-    UINT32                  PruneDepth,
-    UINT32                  Type);
-
-
 /*
  * aslcodegen - code generation
  */
@@ -757,12 +609,6 @@ void
 CgGenerateAmlOutput (
     void);
 
-void
-CgLocalWriteAmlData (
-    ACPI_PARSE_OBJECT       *Op,
-    void                    *Buffer,
-    UINT32                  Length);
-
 
 /*
  * aslfile
@@ -850,149 +696,16 @@ ApCheckPackage (
  * asltransform - parse tree transformations
  */
 ACPI_STATUS
-TrAmlTransformWalkBegin (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    void                    *Context);
-
-ACPI_STATUS
-TrAmlTransformWalkEnd (
+TrAmlTransformWalk (
     ACPI_PARSE_OBJECT       *Op,
     UINT32                  Level,
     void                    *Context);
 
 
 /*
- * aslexternal - External opcode support
+ * asltree - parse tree support
  */
 ACPI_STATUS
-ExAmlExternalWalkBegin (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    void                    *Context);
-
-ACPI_STATUS
-ExAmlExternalWalkEnd (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    void                    *Context);
-
-void
-ExDoExternal (
-    ACPI_PARSE_OBJECT       *Op);
-
-/* Values for "Visitation" parameter above */
-
-#define ASL_WALK_VISIT_DOWNWARD         0x01
-#define ASL_WALK_VISIT_UPWARD           0x02
-#define ASL_WALK_VISIT_DB_SEPARATELY    0x04
-#define ASL_WALK_VISIT_TWICE            (ASL_WALK_VISIT_DOWNWARD | ASL_WALK_VISIT_UPWARD)
-
-
-/*
- * aslparseop.c - Parse op create/allocate/cache
- */
-ACPI_PARSE_OBJECT *
-TrCreateOp (
-    UINT32                  ParseOpcode,
-    UINT32                  NumChildren,
-    ...);
-
-ACPI_PARSE_OBJECT *
-TrCreateLeafOp (
-    UINT32                  ParseOpcode);
-
-ACPI_PARSE_OBJECT *
-TrCreateNullTargetOp (
-    void);
-
-ACPI_PARSE_OBJECT *
-TrCreateAssignmentOp (
-    ACPI_PARSE_OBJECT       *Target,
-    ACPI_PARSE_OBJECT       *Source);
-
-ACPI_PARSE_OBJECT *
-TrCreateTargetOp (
-    ACPI_PARSE_OBJECT       *OriginalOp,
-    ACPI_PARSE_OBJECT       *ParentOp);
-
-ACPI_PARSE_OBJECT *
-TrCreateValuedLeafOp (
-    UINT32                  ParseOpcode,
-    UINT64                  Value);
-
-ACPI_PARSE_OBJECT *
-TrCreateConstantLeafOp (
-    UINT32                  ParseOpcode);
-
-ACPI_PARSE_OBJECT *
-TrAllocateOp (
-    UINT32                  ParseOpcode);
-
-void
-TrPrintOpFlags (
-    UINT32                  Flags,
-    UINT32                  OutputLevel);
-
-
-/*
- * asltree.c - Parse tree management
- */
-void
-TrSetOpParent (
-    ACPI_PARSE_OBJECT       *Op,
-    ACPI_PARSE_OBJECT       *ParentOp);
-
-ACPI_PARSE_OBJECT *
-TrSetOpIntegerValue (
-    UINT32                  ParseOpcode,
-    ACPI_PARSE_OBJECT       *Op);
-
-void
-TrSetOpEndLineNumber (
-    ACPI_PARSE_OBJECT       *Op);
-
-void
-TrSetOpCurrentFilename (
-    ACPI_PARSE_OBJECT       *Op);
-
-void
-TrSetOpIntegerWidth (
-    ACPI_PARSE_OBJECT       *TableSignature,
-    ACPI_PARSE_OBJECT       *Revision);
-
-ACPI_PARSE_OBJECT *
-TrLinkOpChildren (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  NumChildren,
-    ...);
-
-ACPI_PARSE_OBJECT *
-TrLinkPeerOp (
-    ACPI_PARSE_OBJECT       *Op1,
-    ACPI_PARSE_OBJECT       *Op2);
-
-ACPI_PARSE_OBJECT *
-TrLinkChildOp (
-    ACPI_PARSE_OBJECT       *Op1,
-    ACPI_PARSE_OBJECT       *Op2);
-
-ACPI_PARSE_OBJECT *
-TrSetOpFlags (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Flags);
-
-ACPI_PARSE_OBJECT *
-TrSetOpAmlLength (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Length);
-
-ACPI_PARSE_OBJECT *
-TrLinkPeerOps (
-    UINT32                  NumPeers,
-    ...);
-
-ACPI_STATUS
 TrWalkParseTree (
     ACPI_PARSE_OBJECT       *Op,
     UINT32                  Visitation,
@@ -1000,6 +713,84 @@ TrWalkParseTree (
     ASL_WALK_CALLBACK       AscendingCallback,
     void                    *Context);
 
+/* Values for "Visitation" parameter above */
+
+#define ASL_WALK_VISIT_DOWNWARD     0x01
+#define ASL_WALK_VISIT_UPWARD       0x02
+#define ASL_WALK_VISIT_TWICE        (ASL_WALK_VISIT_DOWNWARD | ASL_WALK_VISIT_UPWARD)
+
+
+ACPI_PARSE_OBJECT *
+TrAllocateNode (
+    UINT32                  ParseOpcode);
+
+void
+TrReleaseNode (
+    ACPI_PARSE_OBJECT       *Op);
+
+ACPI_PARSE_OBJECT *
+TrUpdateNode (
+    UINT32                  ParseOpcode,
+    ACPI_PARSE_OBJECT       *Op);
+
+ACPI_PARSE_OBJECT *
+TrCreateNode (
+    UINT32                  ParseOpcode,
+    UINT32                  NumChildren,
+    ...);
+
+ACPI_PARSE_OBJECT *
+TrCreateLeafNode (
+    UINT32                  ParseOpcode);
+
+ACPI_PARSE_OBJECT *
+TrCreateValuedLeafNode (
+    UINT32                  ParseOpcode,
+    UINT64                  Value);
+
+ACPI_PARSE_OBJECT *
+TrCreateConstantLeafNode (
+    UINT32                  ParseOpcode);
+
+ACPI_PARSE_OBJECT *
+TrLinkChildren (
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  NumChildren,
+    ...);
+
+void
+TrSetEndLineNumber (
+    ACPI_PARSE_OBJECT       *Op);
+
+void
+TrWalkTree (
+    void);
+
+ACPI_PARSE_OBJECT *
+TrLinkPeerNode (
+    ACPI_PARSE_OBJECT       *Op1,
+    ACPI_PARSE_OBJECT       *Op2);
+
+ACPI_PARSE_OBJECT *
+TrLinkChildNode (
+    ACPI_PARSE_OBJECT       *Op1,
+    ACPI_PARSE_OBJECT       *Op2);
+
+ACPI_PARSE_OBJECT *
+TrSetNodeFlags (
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  Flags);
+
+ACPI_PARSE_OBJECT *
+TrSetNodeAmlLength (
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  Length);
+
+ACPI_PARSE_OBJECT *
+TrLinkPeerNodes (
+    UINT32                  NumPeers,
+    ...);
+
 
 /*
  * aslfiles - File I/O support
@@ -1043,11 +834,6 @@ FlSeekFile (
     UINT32                  FileId,
     long                    Offset);
 
-void
-FlSeekFileSet (
-    UINT32                  FileId,
-    long                    Offset);
-
 void
 FlCloseFile (
     UINT32                  FileId);
@@ -1082,37 +868,6 @@ ACPI_STATUS
 FlOpenMiscOutputFiles (
     char                    *InputFilename);
 
-ACPI_STATUS
-FlInitOneFile (
-    char                    *InputFilename);
-
-ASL_FILE_SWITCH_STATUS
-FlSwitchFileSet (
-    char                    *InputFilename);
-
-FILE *
-FlGetFileHandle (
-    UINT32                  OutFileId,
-    UINT32                  InFileId,
-    char                    *Filename);
-
-ASL_GLOBAL_FILE_NODE *
-FlGetFileNode (
-    UINT32                  FileId,
-    char                    *Filename);
-
-ASL_GLOBAL_FILE_NODE *
-FlGetCurrentFileNode (
-    void);
-
-
-/*
- * aslhwmap - hardware map summary
- */
-void
-MpEmitMappingInfo (
-    void);
-
 
 /*
  * asload - load namespace in prep for cross reference
@@ -1121,6 +876,7 @@ ACPI_STATUS
 LdLoadNamespace (
     ACPI_PARSE_OBJECT       *RootOp);
 
+
 /*
  * asllookup - namespace lookup functions
  */
@@ -1128,9 +884,8 @@ void
 LkFindUnreferencedObjects (
     void);
 
-
 /*
- * aslhelp - help screens
+ * aslmain - startup
  */
 void
 Usage (
@@ -1140,10 +895,6 @@ void
 AslFilenameHelp (
     void);
 
-void
-AslDisassemblyHelp (
-    void);
-
 
 /*
  * aslnamesp - namespace output file generation
@@ -1156,7 +907,6 @@ void
 NsSetupNamespaceListing (
     void                    *Handle);
 
-
 /*
  * asloptions - command line processing
  */
@@ -1165,7 +915,6 @@ AslCommandLine (
     int                     argc,
     char                    **argv);
 
-
 /*
  * aslxref - namespace cross reference
  */
@@ -1175,25 +924,7 @@ XfCrossReferenceNamespace (
 
 
 /*
- * aslxrefout
- */
-void
-OtPrintHeaders (
-    char                    *Message);
-
-void
-OtCreateXrefFile (
-    void);
-
-void
-OtXrefWalkPart1 (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    ASL_METHOD_INFO         *MethodInfo);
-
-
-/*
- * aslutils - common compiler utilities
+ * aslutils - common compiler utilites
  */
 void
 DbgPrint (
@@ -1207,39 +938,6 @@ DbgPrint (
 #define ASL_PARSE_OUTPUT    1
 #define ASL_TREE_OUTPUT     2
 
-UINT8
-UtIsBigEndianMachine (
-    void);
-
-BOOLEAN
-UtQueryForOverwrite (
-    char                    *Pathname);
-
-void
-UtDumpStringOp (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level);
-
-void
-UtDumpIntegerOp (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level,
-    UINT32                  IntegerLength);
-
-void
-UtDumpBasicOp (
-    ACPI_PARSE_OBJECT       *Op,
-    UINT32                  Level);
-
-void *
-UtGetParentMethod (
-    ACPI_NAMESPACE_NODE     *Node);
-
-BOOLEAN
-UtNodeIsDescendantOf (
-    ACPI_NAMESPACE_NODE     *Node1,
-    ACPI_NAMESPACE_NODE     *Node2);
-
 void
 UtDisplaySupportedTables (
     void);
@@ -1256,15 +954,19 @@ void
 UtEndEvent (
     UINT8                   Event);
 
+void *
+UtLocalCalloc (
+    UINT32                  Size);
+
+void
+UtPrintFormattedName (
+    UINT16                  ParseOpcode,
+    UINT32                  Level);
+
 void
 UtDisplaySummary (
     UINT32                  FileId);
 
-void
-UtDisplayOneSummary (
-    UINT32                  FileId,
-    BOOLEAN                 DisplayErrorSummary);
-
 void
 UtConvertByteToHex (
     UINT8                   RawByte,
@@ -1283,6 +985,14 @@ void
 UtSetParseOpName (
     ACPI_PARSE_OBJECT       *Op);
 
+char *
+UtGetStringBuffer (
+    UINT32                  Length);
+
+void
+UtExpandLineBuffers (
+    void);
+
 ACPI_STATUS
 UtInternalizeName (
     char                    *ExternalName,
@@ -1303,6 +1013,12 @@ UINT64
 UtDoConstant (
     char                    *String);
 
+ACPI_STATUS
+UtStrtoul64 (
+    char                    *String,
+    UINT32                  Base,
+    UINT64                  *RetInteger);
+
 
 /*
  * asluuid - UUID support
@@ -1316,7 +1032,6 @@ AuConvertUuidToString (
     char                    *UuIdBuffer,
     char                    *OutString);
 
-
 /*
  * aslresource - Resource template generation utilities
  */
@@ -1386,7 +1101,8 @@ RsCheckListForDuplicates (
 
 ASL_RESOURCE_NODE *
 RsDoOneResourceDescriptor (
-    ASL_RESOURCE_INFO       *Info,
+    ACPI_PARSE_OBJECT       *DescriptorTypeOp,
+    UINT32                  CurrentByteOffset,
     UINT8                   *State);
 
 /* Values for State above */
@@ -1410,35 +1126,43 @@ RsDoResourceTemplate (
  */
 ASL_RESOURCE_NODE *
 RsDoEndTagDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoEndDependentDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory24Descriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory32Descriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoMemory32FixedDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoStartDependentDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoStartDependentNoPriDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoVendorSmallDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1446,27 +1170,33 @@ RsDoVendorSmallDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoDmaDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoFixedDmaDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoFixedIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIrqDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoIrqNoFlagsDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1474,71 +1204,61 @@ RsDoIrqNoFlagsDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoInterruptDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoVendorLargeDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGeneralRegisterDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGpioIntDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoGpioIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoI2cSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoSpiSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoUartSerialBusDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
-ASL_RESOURCE_NODE *
-RsDoPinFunctionDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
-ASL_RESOURCE_NODE *
-RsDoPinConfigDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
-ASL_RESOURCE_NODE *
-RsDoPinGroupDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
-ASL_RESOURCE_NODE *
-RsDoPinGroupFunctionDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
-ASL_RESOURCE_NODE *
-RsDoPinGroupConfigDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 /*
  * aslrestype2d - DWord address descriptors
  */
 ASL_RESOURCE_NODE *
 RsDoDwordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoDwordMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoDwordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1546,15 +1266,18 @@ RsDoDwordSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoExtendedIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoExtendedMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoExtendedSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1562,15 +1285,18 @@ RsDoExtendedSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoQwordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoQwordMemoryDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoQwordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 
 /*
@@ -1578,16 +1304,18 @@ RsDoQwordSpaceDescriptor (
  */
 ASL_RESOURCE_NODE *
 RsDoWordIoDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoWordSpaceDescriptor (
-    ASL_RESOURCE_INFO       *Info);
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 ASL_RESOURCE_NODE *
 RsDoWordBusNumberDescriptor (
-    ASL_RESOURCE_INFO       *Info);
-
+    ACPI_PARSE_OBJECT       *Op,
+    UINT32                  CurrentByteOffset);
 
 /*
  * Entry to data table compiler subsystem
@@ -1598,16 +1326,6 @@ DtDoCompile(
 
 ACPI_STATUS
 DtCreateTemplates (
-    char                    **argv);
-
-
-/*
- * ASL/ASL+ converter debug
- */
-void
-CvDbgPrint (
-    char                    *Fmt,
-    ...);
-
+    char                    *Signature);
 
 #endif /*  __ASLCOMPILER_H */
