@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,47 +111,11 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
-#include "acnamesp.h"
 #include "acparser.h"
 #include "amlcode.h"
 
@@ -162,15 +126,11 @@
 
 /* Local prototypes */
 
-static void
+void
 MtCheckNamedObjectInMethod (
     ACPI_PARSE_OBJECT       *Op,
     ASL_METHOD_INFO         *MethodInfo);
 
-static void
-MtCheckStaticOperationRegionInMethod (
-    ACPI_PARSE_OBJECT       *Op);
-
 
 /*******************************************************************************
  *
@@ -202,64 +162,32 @@ MtMethodAnalysisWalkBegin (
     char                    ArgName[] = "Arg0";
     ACPI_PARSE_OBJECT       *ArgNode;
     ACPI_PARSE_OBJECT       *NextType;
+    ACPI_PARSE_OBJECT       *NextParamType;
     UINT8                   ActualArgs = 0;
-    BOOLEAN                 HidExists;
-    BOOLEAN                 AdrExists;
 
 
-    /* Build cross-reference output file if requested */
-
-    if (AslGbl_CrossReferenceOutput)
-    {
-        OtXrefWalkPart1 (Op, Level, MethodInfo);
-    }
-
     switch (Op->Asl.ParseOpcode)
     {
     case PARSEOP_METHOD:
 
-        AslGbl_TotalMethods++;
+        TotalMethods++;
 
         /* Create and init method info */
 
-        MethodInfo = UtLocalCalloc (sizeof (ASL_METHOD_INFO));
+        MethodInfo       = UtLocalCalloc (sizeof (ASL_METHOD_INFO));
         MethodInfo->Next = WalkInfo->MethodStack;
         MethodInfo->Op = Op;
 
         WalkInfo->MethodStack = MethodInfo;
 
-        /*
-         * Special handling for _PSx methods. Dependency rules (same scope):
-         *
-         * 1) _PS0 - One of these must exist: _PS1, _PS2, _PS3
-         * 2) _PS1/_PS2/_PS3: A _PS0 must exist
-         */
-        if (ACPI_COMPARE_NAMESEG (METHOD_NAME__PS0, Op->Asl.NameSeg))
-        {
-            /* For _PS0, one of _PS1/_PS2/_PS3 must exist */
+        /* Special handling for _DSD, must have a _HID also */
 
-            if ((!ApFindNameInScope (METHOD_NAME__PS1, Op)) &&
-                (!ApFindNameInScope (METHOD_NAME__PS2, Op)) &&
-                (!ApFindNameInScope (METHOD_NAME__PS3, Op)))
+        if (!ACPI_STRCMP (METHOD_NAME__DSD, Op->Asl.NameSeg))
+        {
+            if (!ApFindNameInScope (METHOD_NAME__HID, Op))
             {
                 AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                    "_PS0 requires one of _PS1/_PS2/_PS3 in same scope");
-            }
-        }
-        else if (
-            ACPI_COMPARE_NAMESEG (METHOD_NAME__PS1, Op->Asl.NameSeg) ||
-            ACPI_COMPARE_NAMESEG (METHOD_NAME__PS2, Op->Asl.NameSeg) ||
-            ACPI_COMPARE_NAMESEG (METHOD_NAME__PS3, Op->Asl.NameSeg))
-        {
-            /* For _PS1/_PS2/_PS3, a _PS0 must exist */
-
-            if (!ApFindNameInScope (METHOD_NAME__PS0, Op))
-            {
-                sprintf (AslGbl_MsgBuffer,
-                    "%4.4s requires _PS0 in same scope", Op->Asl.NameSeg);
-
-                AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                    AslGbl_MsgBuffer);
+                    "_DSD requires _HID in same scope");
             }
         }
 
@@ -286,37 +214,47 @@ MtMethodAnalysisWalkBegin (
         Next = Next->Asl.Next;
 
         NextType = Next->Asl.Child;
+        while (NextType)
+        {
+            /* Get and map each of the ReturnTypes */
 
-        MethodInfo->ValidReturnTypes = MtProcessTypeOp (NextType);
+            MethodInfo->ValidReturnTypes |= AnMapObjTypeToBtype (NextType);
+            NextType->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
+            NextType = NextType->Asl.Next;
+        }
 
         /* Get the ParameterType node */
 
         Next = Next->Asl.Next;
 
         NextType = Next->Asl.Child;
-        if (!NextType)
+        while (NextType)
         {
-            /*
-             * The optional parameter types list was omitted  at the source
-             * level. Use the Argument count parameter instead.
-             */
-            ActualArgs = MethodInfo->NumArguments;
-        }
-        else
-        {
-            ActualArgs = MtProcessParameterTypeList (NextType,
-                MethodInfo->ValidArgTypes);
-            MethodInfo->NumArguments = ActualArgs;
-            ArgNode->Asl.Value.Integer |= ActualArgs;
+            if (NextType->Asl.ParseOpcode == PARSEOP_DEFAULT_ARG)
+            {
+                NextParamType = NextType->Asl.Child;
+                while (NextParamType)
+                {
+                    MethodInfo->ValidArgTypes[ActualArgs] |= AnMapObjTypeToBtype (NextParamType);
+                    NextParamType->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
+                    NextParamType = NextParamType->Asl.Next;
+                }
+            }
+            else
+            {
+                MethodInfo->ValidArgTypes[ActualArgs] =
+                    AnMapObjTypeToBtype (NextType);
+                NextType->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
+                ActualArgs++;
+            }
+
+            NextType = NextType->Asl.Next;
         }
 
         if ((MethodInfo->NumArguments) &&
             (MethodInfo->NumArguments != ActualArgs))
         {
-            sprintf (AslGbl_MsgBuffer,
-                "Length = %u", ActualArgs);
-            AslError (ASL_ERROR, ASL_MSG_ARG_COUNT_MISMATCH,
-                Op->Asl.Child->Asl.Next, AslGbl_MsgBuffer);
+            /* error: Param list did not match number of args */
         }
 
         /* Allow numarguments == 0 for Function() */
@@ -340,31 +278,10 @@ MtMethodAnalysisWalkBegin (
 
     case PARSEOP_METHODCALL:
 
-        /* Check for a recursive method call */
-
         if (MethodInfo &&
            (Op->Asl.Node == MethodInfo->Op->Asl.Node))
         {
-            if (MethodInfo->CreatesNamedObjects)
-            {
-                /*
-                 * This is an error, as it will fail at runtime on all ACPI
-                 * implementations. Any named object declarations will be
-                 * executed twice, causing failure the second time. Note,
-                 * this is independent of whether the method is declared
-                 * Serialized, because the same thread is attempting to
-                 * reenter the method, and this will always succeed.
-                 */
-                AslDualParseOpError (ASL_ERROR, ASL_MSG_ILLEGAL_RECURSION, Op,
-                    Op->Asl.Value.String, ASL_MSG_FOUND_HERE, MethodInfo->Op,
-                    MethodInfo->Op->Asl.ExternalName);
-            }
-            else
-            {
-                /* Method does not create objects, issue a remark */
-
-                AslError (ASL_REMARK, ASL_MSG_RECURSION, Op, Op->Asl.ExternalName);
-            }
+            AslError (ASL_REMARK, ASL_MSG_RECURSION, Op, Op->Asl.ExternalName);
         }
         break;
 
@@ -383,18 +300,17 @@ MtMethodAnalysisWalkBegin (
              * Local was used outside a control method, or there was an error
              * in the method declaration.
              */
-            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD, Op, Op->Asl.ExternalName);
             return (AE_ERROR);
         }
 
-        RegisterNumber = (Op->Asl.AmlOpcode & 0x0007);
+        RegisterNumber = (Op->Asl.AmlOpcode & 0x000F);
 
         /*
          * If the local is being used as a target, mark the local
          * initialized
          */
-        if (Op->Asl.CompileFlags & OP_IS_TARGET)
+        if (Op->Asl.CompileFlags & NODE_IS_TARGET)
         {
             MethodInfo->LocalInitialized[RegisterNumber] = TRUE;
         }
@@ -427,8 +343,7 @@ MtMethodAnalysisWalkBegin (
              * Arg was used outside a control method, or there was an error
              * in the method declaration.
              */
-            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_REMARK, ASL_MSG_LOCAL_OUTSIDE_METHOD, Op, Op->Asl.ExternalName);
             return (AE_ERROR);
         }
 
@@ -439,7 +354,7 @@ MtMethodAnalysisWalkBegin (
          * If the Arg is being used as a target, mark the local
          * initialized
          */
-        if (Op->Asl.CompileFlags & OP_IS_TARGET)
+        if (Op->Asl.CompileFlags & NODE_IS_TARGET)
         {
             MethodInfo->ArgInitialized[RegisterNumber] = TRUE;
         }
@@ -451,7 +366,7 @@ MtMethodAnalysisWalkBegin (
          * The only operator that accepts an uninitialized value is ObjectType()
          */
         else if ((!MethodInfo->ArgInitialized[RegisterNumber]) &&
-            (Op->Asl.Parent->Asl.ParseOpcode != PARSEOP_OBJECTTYPE))
+                 (Op->Asl.Parent->Asl.ParseOpcode != PARSEOP_OBJECTTYPE))
         {
             AslError (ASL_ERROR, ASL_MSG_ARG_INIT, Op, ArgName);
         }
@@ -478,7 +393,7 @@ MtMethodAnalysisWalkBegin (
 
         /*
          * A child indicates a possible return value. A simple Return or
-         * Return() is marked with OP_IS_NULL_RETURN by the parser so
+         * Return() is marked with NODE_IS_NULL_RETURN by the parser so
          * that it is not counted as a "real" return-with-value, although
          * the AML code that is actually emitted is Return(0). The AML
          * definition of Return has a required parameter, so we are
@@ -486,7 +401,7 @@ MtMethodAnalysisWalkBegin (
          */
         if ((Op->Asl.Child) &&
             (Op->Asl.Child->Asl.ParseOpcode != PARSEOP_DEFAULT_ARG) &&
-            (!(Op->Asl.Child->Asl.CompileFlags & OP_IS_NULL_RETURN)))
+            (!(Op->Asl.Child->Asl.CompileFlags & NODE_IS_NULL_RETURN)))
         {
             MethodInfo->NumReturnWithValue++;
         }
@@ -527,29 +442,6 @@ MtMethodAnalysisWalkBegin (
         break;
 
     case PARSEOP_DEVICE:
-
-        /* Check usage of _HID and _ADR objects */
-
-        HidExists = ApFindNameInDeviceTree (METHOD_NAME__HID, Op);
-        AdrExists = ApFindNameInDeviceTree (METHOD_NAME__ADR, Op);
-
-        if (!HidExists && !AdrExists)
-        {
-            AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
-                "Device object requires a _HID or _ADR in same scope");
-        }
-        else if (HidExists && AdrExists)
-        {
-            /*
-             * According to the ACPI spec, "A device object must contain
-             * either an _HID object or an _ADR object, but should not contain
-             * both".
-             */
-            AslError (ASL_WARNING, ASL_MSG_MULTIPLE_TYPES, Op,
-                "Device object requires either a _HID or _ADR, but not both");
-        }
-        break;
-
     case PARSEOP_EVENT:
     case PARSEOP_MUTEX:
     case PARSEOP_OPERATIONREGION:
@@ -564,11 +456,8 @@ MtMethodAnalysisWalkBegin (
         i = ApCheckForPredefinedName (Op, Op->Asl.NameSeg);
         if (i < ACPI_VALID_RESERVED_NAME_MAX)
         {
-            AslError (ASL_ERROR, ASL_MSG_RESERVED_USE,
-                Op, Op->Asl.ExternalName);
+            AslError (ASL_ERROR, ASL_MSG_RESERVED_USE, Op, Op->Asl.ExternalName);
         }
-
-        MtCheckStaticOperationRegionInMethod (Op);
         break;
 
     case PARSEOP_NAME:
@@ -579,7 +468,7 @@ MtMethodAnalysisWalkBegin (
 
         /* Special typechecking for _HID */
 
-        if (ACPI_COMPARE_NAMESEG (METHOD_NAME__HID, Op->Asl.NameSeg))
+        if (!ACPI_STRCMP (METHOD_NAME__HID, Op->Asl.NameSeg))
         {
             Next = Op->Asl.Child->Asl.Next;
             AnCheckId (Next, ASL_TYPE_HID);
@@ -587,7 +476,7 @@ MtMethodAnalysisWalkBegin (
 
         /* Special typechecking for _CID */
 
-        else if (ACPI_COMPARE_NAMESEG (METHOD_NAME__CID, Op->Asl.NameSeg))
+        else if (!ACPI_STRCMP (METHOD_NAME__CID, Op->Asl.NameSeg))
         {
             Next = Op->Asl.Child->Asl.Next;
 
@@ -607,6 +496,15 @@ MtMethodAnalysisWalkBegin (
             }
         }
 
+        else if (!ACPI_STRCMP (METHOD_NAME__DSD, Op->Asl.NameSeg))
+        {
+            if (!ApFindNameInScope (METHOD_NAME__HID, Op))
+            {
+                AslError (ASL_WARNING, ASL_MSG_MISSING_DEPENDENCY, Op,
+                    "_DSD requires _HID in same scope");
+            }
+        }
+
         break;
 
     default:
@@ -621,81 +519,6 @@ MtMethodAnalysisWalkBegin (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    MtProcessTypeOp
- *
- * PARAMETERS:  Op                  - Op representing a btype
- *
- * RETURN:      Btype represented by Op
- *
- * DESCRIPTION: Process a parse object that represents single parameter type or
- *              a return type in method, function, and external declarations.
- *
- ******************************************************************************/
-
-UINT32
-MtProcessTypeOp (
-    ACPI_PARSE_OBJECT       *TypeOp)
-{
-    UINT32                  Btype = ACPI_BTYPE_ANY;
-
-
-    while (TypeOp)
-    {
-        Btype |= AnMapObjTypeToBtype (TypeOp);
-        TypeOp->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
-        TypeOp = TypeOp->Asl.Next;
-    }
-
-    return (Btype);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    MtProcessParameterTypeList
- *
- * PARAMETERS:  Op                  - Op representing a btype
- *
- * RETURN:      Btype represented by Op
- *
- * DESCRIPTION: Process a parse object that represents a parameter type list in
- *              method, function, and external declarations.
- *
- ******************************************************************************/
-
-UINT8
-MtProcessParameterTypeList (
-    ACPI_PARSE_OBJECT       *ParamTypeOp,
-    UINT32                  *TypeList)
-{
-    UINT8                   ParameterCount = 0;
-
-
-    if (ParamTypeOp && ParamTypeOp->Asl.ParseOpcode != PARSEOP_DEFAULT_ARG)
-    {
-        /* Special case for a single parameter without braces */
-
-        TypeList[ParameterCount] =
-            MtProcessTypeOp (ParamTypeOp);
-
-        return (1);
-    }
-
-    while (ParamTypeOp)
-    {
-        TypeList[ParameterCount] =
-            MtProcessTypeOp (ParamTypeOp->Asl.Child);
-
-        ParameterCount++;
-        ParamTypeOp = ParamTypeOp->Asl.Next;
-    }
-
-    return (ParameterCount);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    MtCheckNamedObjectInMethod
@@ -711,130 +534,47 @@ MtProcessParameterTypeList (
  *
  ******************************************************************************/
 
-static void
+void
 MtCheckNamedObjectInMethod (
     ACPI_PARSE_OBJECT       *Op,
     ASL_METHOD_INFO         *MethodInfo)
 {
     const ACPI_OPCODE_INFO  *OpInfo;
-    char                    *ExternalPath;
 
 
-    /* We don't care about actual method declarations or scopes */
+    /* We don't care about actual method declarations */
 
-    if ((Op->Asl.AmlOpcode == AML_METHOD_OP) ||
-        (Op->Asl.AmlOpcode == AML_SCOPE_OP))
+    if (Op->Asl.AmlOpcode == AML_METHOD_OP)
     {
         return;
     }
 
-    /* Determine if we are creating a named object within a method */
-
-    if (!MethodInfo)
-    {
-        return;
-    }
+    /* Determine if we are creating a named object */
 
     OpInfo = AcpiPsGetOpcodeInfo (Op->Asl.AmlOpcode);
-    if ((OpInfo->Class == AML_CLASS_NAMED_OBJECT) && (Op->Asl.AmlOpcode != AML_FIELD_OP))
+    if (OpInfo->Class == AML_CLASS_NAMED_OBJECT)
     {
         /*
-         * 1) Mark the method as a method that creates named objects.
-         *
-         * 2) Issue a remark indicating the inefficiency of creating named
-         * objects within a method (Except for compiler-emitted temporary
-         * variables).
-         *
-         * 3) If the method is non-serialized, emit a remark that the method
-         * should be serialized.
+         * If we have a named object created within a non-serialized method,
+         * emit a remark that the method should be serialized.
          *
          * Reason: If a thread blocks within the method for any reason, and
-         * another thread enters the method, the method will fail because
-         * an attempt will be made to create the same object twice.
-         *
-         * Note: The Field opcode is disallowed here because Field() does not
-         * create a new named object.
+         * another thread enters the method, the method will fail because an
+         * attempt will be made to create the same object twice.
          */
-        ExternalPath = AcpiNsGetNormalizedPathname (MethodInfo->Op->Asl.Node, TRUE);
-
-        /* No error for compiler temp variables (name starts with "_T_") */
-
-        if ((Op->Asl.NameSeg[0] != '_') &&
-            (Op->Asl.NameSeg[1] != 'T') &&
-            (Op->Asl.NameSeg[2] != '_'))
-        {
-            AslError (ASL_REMARK, ASL_MSG_NAMED_OBJECT_CREATION, Op,
-                ExternalPath);
-        }
-
-        MethodInfo->CreatesNamedObjects = TRUE;
-        if (!MethodInfo->ShouldBeSerialized)
+        if (MethodInfo && !MethodInfo->ShouldBeSerialized)
         {
             AslError (ASL_REMARK, ASL_MSG_SERIALIZED_REQUIRED, MethodInfo->Op,
-                ExternalPath);
+                "due to creation of named objects within");
 
             /* Emit message only ONCE per method */
 
             MethodInfo->ShouldBeSerialized = TRUE;
         }
-
-        if (ExternalPath)
-        {
-            ACPI_FREE (ExternalPath);
-        }
     }
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    MtCheckStaticOperationRegionInMethod
- *
- * PARAMETERS:  Op                  - Current parser op
- *
- * RETURN:      None
- *
- * DESCRIPTION: Warns if an Operation Region with static address or length
- *              is declared inside a control method
- *
- ******************************************************************************/
-
-static void
-MtCheckStaticOperationRegionInMethod(
-    ACPI_PARSE_OBJECT*       Op)
-{
-    ACPI_PARSE_OBJECT*       AddressOp;
-    ACPI_PARSE_OBJECT*       LengthOp;
-
-
-    if (Op->Asl.ParseOpcode != PARSEOP_OPERATIONREGION)
-    {
-        return;
-    }
-
-    /*
-     * OperationRegion should have 4 arguments defined. At this point, we
-     * assume that the parse tree is well-formed.
-     */
-    AddressOp = Op->Asl.Child->Asl.Next->Asl.Next;
-    LengthOp = Op->Asl.Child->Asl.Next->Asl.Next->Asl.Next;
-
-    if (UtGetParentMethodOp (Op) &&
-        AddressOp->Asl.ParseOpcode == PARSEOP_INTEGER &&
-        LengthOp->Asl.ParseOpcode == PARSEOP_INTEGER)
-    {
-        /*
-         * At this point, a static operation region declared inside of a
-         * control method has been found. Throw a warning because this is
-         * highly inefficient.
-         */
-        AslError(ASL_WARNING, ASL_MSG_STATIC_OPREGION_IN_METHOD, Op, NULL);
-    }
-
-    return;
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    MtMethodAnalysisWalkEnd
@@ -856,7 +596,6 @@ MtMethodAnalysisWalkEnd (
 {
     ASL_ANALYSIS_WALK_INFO  *WalkInfo = (ASL_ANALYSIS_WALK_INFO *) Context;
     ASL_METHOD_INFO         *MethodInfo = WalkInfo->MethodStack;
-    char                    *ExternalPath;
 
 
     switch (Op->Asl.ParseOpcode)
@@ -892,7 +631,7 @@ MtMethodAnalysisWalkEnd (
          * of the method can possibly terminate without a return statement.
          */
         if ((!AnLastStatementIsReturn (Op)) &&
-            (!(Op->Asl.CompileFlags & OP_HAS_NO_EXIT)))
+            (!(Op->Asl.CompileFlags & NODE_HAS_NO_EXIT)))
         {
             /*
              * No return statement, and execution can possibly exit
@@ -909,15 +648,8 @@ MtMethodAnalysisWalkEnd (
         if (MethodInfo->NumReturnNoValue &&
             MethodInfo->NumReturnWithValue)
         {
-            ExternalPath = AcpiNsGetNormalizedPathname (Op->Asl.Node, TRUE);
-
             AslError (ASL_WARNING, ASL_MSG_RETURN_TYPES, Op,
-                ExternalPath);
-
-            if (ExternalPath)
-            {
-                ACPI_FREE (ExternalPath);
-            }
+                Op->Asl.ExternalName);
         }
 
         /*
@@ -931,11 +663,11 @@ MtMethodAnalysisWalkEnd (
         {
             if (MethodInfo->NumReturnWithValue)
             {
-                Op->Asl.CompileFlags |= OP_METHOD_SOME_NO_RETVAL;
+                Op->Asl.CompileFlags |= NODE_METHOD_SOME_NO_RETVAL;
             }
             else
             {
-                Op->Asl.CompileFlags |= OP_METHOD_NO_RETVAL;
+                Op->Asl.CompileFlags |= NODE_METHOD_NO_RETVAL;
             }
         }
 
@@ -979,7 +711,7 @@ MtMethodAnalysisWalkEnd (
          * The parent block does not "exit" and continue execution -- the
          * method is terminated here with the Return() statement.
          */
-        Op->Asl.Parent->Asl.CompileFlags |= OP_HAS_NO_EXIT;
+        Op->Asl.Parent->Asl.CompileFlags |= NODE_HAS_NO_EXIT;
 
         /* Used in the "typing" pass later */
 
@@ -992,14 +724,13 @@ MtMethodAnalysisWalkEnd (
          */
         if (Op->Asl.Next)
         {
-            AslError (ASL_WARNING, ASL_MSG_UNREACHABLE_CODE,
-                Op->Asl.Next, NULL);
+            AslError (ASL_WARNING, ASL_MSG_UNREACHABLE_CODE, Op->Asl.Next, NULL);
         }
         break;
 
     case PARSEOP_IF:
 
-        if ((Op->Asl.CompileFlags & OP_HAS_NO_EXIT) &&
+        if ((Op->Asl.CompileFlags & NODE_HAS_NO_EXIT) &&
             (Op->Asl.Next) &&
             (Op->Asl.Next->Asl.ParseOpcode == PARSEOP_ELSE))
         {
@@ -1008,32 +739,32 @@ MtMethodAnalysisWalkEnd (
              * (it contains an unconditional Return)
              * mark the ELSE block to remember this fact.
              */
-            Op->Asl.Next->Asl.CompileFlags |= OP_IF_HAS_NO_EXIT;
+            Op->Asl.Next->Asl.CompileFlags |= NODE_IF_HAS_NO_EXIT;
         }
         break;
 
     case PARSEOP_ELSE:
 
-        if ((Op->Asl.CompileFlags & OP_HAS_NO_EXIT) &&
-            (Op->Asl.CompileFlags & OP_IF_HAS_NO_EXIT))
+        if ((Op->Asl.CompileFlags & NODE_HAS_NO_EXIT) &&
+            (Op->Asl.CompileFlags & NODE_IF_HAS_NO_EXIT))
         {
             /*
              * This ELSE block has no exit and the corresponding IF block
              * has no exit either. Therefore, the parent node has no exit.
              */
-            Op->Asl.Parent->Asl.CompileFlags |= OP_HAS_NO_EXIT;
+            Op->Asl.Parent->Asl.CompileFlags |= NODE_HAS_NO_EXIT;
         }
         break;
 
 
     default:
 
-        if ((Op->Asl.CompileFlags & OP_HAS_NO_EXIT) &&
+        if ((Op->Asl.CompileFlags & NODE_HAS_NO_EXIT) &&
             (Op->Asl.Parent))
         {
             /* If this node has no exit, then the parent has no exit either */
 
-            Op->Asl.Parent->Asl.CompileFlags |= OP_HAS_NO_EXIT;
+            Op->Asl.Parent->Asl.CompileFlags |= NODE_HAS_NO_EXIT;
         }
         break;
     }
