@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include "amlcode.h"
@@ -239,7 +204,7 @@ OpcAmlOpcodeWalk (
     void                    *Context)
 {
 
-    AslGbl_TotalParseNodes++;
+    TotalParseNodes++;
 
     OpcGenerateAmlOpcode (Op);
     OpnGenerateAmlOperands (Op);
@@ -271,9 +236,9 @@ OpcGetIntegerWidth (
         return;
     }
 
-    if (AslGbl_RevisionOverride)
+    if (Gbl_RevisionOverride)
     {
-        AcpiUtSetIntegerWidth (AslGbl_RevisionOverride);
+        AcpiUtSetIntegerWidth (Gbl_RevisionOverride);
     }
     else
     {
@@ -315,7 +280,7 @@ OpcSetOptimalIntegerSize (
      */
     if (Op->Asl.Parent &&
         Op->Asl.Parent->Asl.Parent &&
-       (Op->Asl.Parent->Asl.Parent->Asl.ParseOpcode == PARSEOP_DEFINITION_BLOCK))
+       (Op->Asl.Parent->Asl.Parent->Asl.ParseOpcode == PARSEOP_DEFINITIONBLOCK))
     {
         return (0);
     }
@@ -328,7 +293,7 @@ OpcSetOptimalIntegerSize (
      *
      * This optimization is optional.
      */
-    if (AslGbl_IntegerOptimizationFlag)
+    if (Gbl_IntegerOptimizationFlag)
     {
         switch (Op->Asl.Value.Integer)
         {
@@ -385,34 +350,28 @@ OpcSetOptimalIntegerSize (
         Op->Asl.AmlOpcode = AML_BYTE_OP;
         return (1);
     }
-
     if (Op->Asl.Value.Integer <= ACPI_UINT16_MAX)
     {
         Op->Asl.AmlOpcode = AML_WORD_OP;
         return (2);
     }
-
     if (Op->Asl.Value.Integer <= ACPI_UINT32_MAX)
     {
         Op->Asl.AmlOpcode = AML_DWORD_OP;
         return (4);
     }
-    else /* 64-bit integer */
+    else
     {
         if (AcpiGbl_IntegerByteWidth == 4)
         {
             AslError (ASL_WARNING, ASL_MSG_INTEGER_LENGTH,
                 Op, NULL);
 
-            if (!AslGbl_IgnoreErrors)
+            if (!Gbl_IgnoreErrors)
             {
                 /* Truncate the integer to 32-bit */
-
-                Op->Asl.Value.Integer &= ACPI_UINT32_MAX;
-
-                /* Now set the optimal integer size */
-
-                return (OpcSetOptimalIntegerSize (Op));
+                Op->Asl.AmlOpcode = AML_DWORD_OP;
+                return (4);
             }
         }
 
@@ -459,16 +418,15 @@ OpcDoAccessAs (
     {
         AttribOp->Asl.Value.Integer = 0;
     }
-
     AttribOp->Asl.AmlOpcode = AML_RAW_DATA_BYTE;
     AttribOp->Asl.ParseOpcode = PARSEOP_RAW_DATA;
 
     /* Only a few AccessAttributes support AccessLength */
 
     Attribute = (UINT8) AttribOp->Asl.Value.Integer;
-    if ((Attribute != AML_FIELD_ATTRIB_BYTES) &&
+    if ((Attribute != AML_FIELD_ATTRIB_MULTIBYTE) &&
         (Attribute != AML_FIELD_ATTRIB_RAW_BYTES) &&
-        (Attribute != AML_FIELD_ATTRIB_RAW_PROCESS_BYTES))
+        (Attribute != AML_FIELD_ATTRIB_RAW_PROCESS))
     {
         return;
     }
@@ -517,7 +475,6 @@ OpcDoConnection (
     ACPI_PARSE_OBJECT       *BufferOp;
     ACPI_PARSE_OBJECT       *BufferLengthOp;
     ACPI_PARSE_OBJECT       *BufferDataOp;
-    ASL_RESOURCE_INFO       Info;
     UINT8                   State;
 
 
@@ -532,10 +489,8 @@ OpcDoConnection (
     BufferLengthOp = BufferOp->Asl.Child;
     BufferDataOp = BufferLengthOp->Asl.Next;
 
-    Info.DescriptorTypeOp = BufferDataOp->Asl.Next;
-    Info.CurrentByteOffset = 0;
     State = ACPI_RSTATE_NORMAL;
-    Rnode = RsDoOneResourceDescriptor (&Info, &State);
+    Rnode = RsDoOneResourceDescriptor (BufferDataOp->Asl.Next, 0, &State);
     if (!Rnode)
     {
         return; /* error */
@@ -548,21 +503,21 @@ OpcDoConnection (
      * First Child  -> BufferLength
      * Second Child -> Descriptor Buffer (raw byte data)
      */
-    BufferOp->Asl.ParseOpcode = PARSEOP_BUFFER;
-    BufferOp->Asl.AmlOpcode = AML_BUFFER_OP;
-    BufferOp->Asl.CompileFlags = OP_AML_PACKAGE | OP_IS_RESOURCE_DESC;
+    BufferOp->Asl.ParseOpcode         = PARSEOP_BUFFER;
+    BufferOp->Asl.AmlOpcode           = AML_BUFFER_OP;
+    BufferOp->Asl.CompileFlags        = NODE_AML_PACKAGE | NODE_IS_RESOURCE_DESC;
     UtSetParseOpName (BufferOp);
 
-    BufferLengthOp->Asl.ParseOpcode = PARSEOP_INTEGER;
+    BufferLengthOp->Asl.ParseOpcode   = PARSEOP_INTEGER;
     BufferLengthOp->Asl.Value.Integer = Rnode->BufferLength;
     (void) OpcSetOptimalIntegerSize (BufferLengthOp);
     UtSetParseOpName (BufferLengthOp);
 
-    BufferDataOp->Asl.ParseOpcode = PARSEOP_RAW_DATA;
-    BufferDataOp->Asl.AmlOpcode = AML_RAW_DATA_CHAIN;
-    BufferDataOp->Asl.AmlOpcodeLength = 0;
-    BufferDataOp->Asl.AmlLength = Rnode->BufferLength;
-    BufferDataOp->Asl.Value.Buffer = (UINT8 *) Rnode;
+    BufferDataOp->Asl.ParseOpcode         = PARSEOP_RAW_DATA;
+    BufferDataOp->Asl.AmlOpcode           = AML_RAW_DATA_CHAIN;
+    BufferDataOp->Asl.AmlOpcodeLength     = 0;
+    BufferDataOp->Asl.AmlLength           = Rnode->BufferLength;
+    BufferDataOp->Asl.Value.Buffer        = (UINT8 *) Rnode;
     UtSetParseOpName (BufferDataOp);
 }
 
@@ -598,7 +553,7 @@ OpcDoUnicode (
 
     /* Change op into a buffer object */
 
-    Op->Asl.CompileFlags &= ~OP_COMPILE_TIME_CONST;
+    Op->Asl.CompileFlags &= ~NODE_COMPILE_TIME_CONST;
     Op->Asl.ParseOpcode = PARSEOP_BUFFER;
     UtSetParseOpName (Op);
 
@@ -626,8 +581,8 @@ OpcDoUnicode (
      * Just set the buffer size node to be the buffer length, regardless
      * of whether it was previously an integer or a default_arg placeholder
      */
-    BufferLengthOp->Asl.ParseOpcode = PARSEOP_INTEGER;
-    BufferLengthOp->Asl.AmlOpcode = AML_DWORD_OP;
+    BufferLengthOp->Asl.ParseOpcode   = PARSEOP_INTEGER;
+    BufferLengthOp->Asl.AmlOpcode     = AML_DWORD_OP;
     BufferLengthOp->Asl.Value.Integer = Length;
     UtSetParseOpName (BufferLengthOp);
 
@@ -635,11 +590,11 @@ OpcDoUnicode (
 
     /* The Unicode string is a raw data buffer */
 
-    InitializerOp->Asl.Value.Buffer = (UINT8 *) UnicodeString;
-    InitializerOp->Asl.AmlOpcode = AML_RAW_DATA_BUFFER;
-    InitializerOp->Asl.AmlLength = Length;
-    InitializerOp->Asl.ParseOpcode = PARSEOP_RAW_DATA;
-    InitializerOp->Asl.Child = NULL;
+    InitializerOp->Asl.Value.Buffer   = (UINT8 *) UnicodeString;
+    InitializerOp->Asl.AmlOpcode      = AML_RAW_DATA_BUFFER;
+    InitializerOp->Asl.AmlLength      = Length;
+    InitializerOp->Asl.ParseOpcode    = PARSEOP_RAW_DATA;
+    InitializerOp->Asl.Child          = NULL;
     UtSetParseOpName (InitializerOp);
 }
 
@@ -698,7 +653,7 @@ OpcDoEisaId (
      * The EISAID string must be exactly 7 characters and of the form
      * "UUUXXXX" -- 3 uppercase letters and 4 hex digits (e.g., "PNP0001")
      */
-    if (strlen (InString) != 7)
+    if (ACPI_STRLEN (InString) != 7)
     {
         Status = AE_BAD_PARAMETER;
     }
@@ -756,7 +711,7 @@ OpcDoEisaId (
      */
     Op->Asl.Value.Integer = EisaId;
 
-    Op->Asl.CompileFlags &= ~OP_COMPILE_TIME_CONST;
+    Op->Asl.CompileFlags &= ~NODE_COMPILE_TIME_CONST;
     Op->Asl.ParseOpcode = PARSEOP_INTEGER;
     (void) OpcSetOptimalIntegerSize (Op);
 
@@ -770,7 +725,7 @@ OpcDoEisaId (
  *
  * FUNCTION:    OpcDoUuId
  *
- * PARAMETERS:  Op                  - Parse node
+ * PARAMETERS:  Op        - Parse node
  *
  * RETURN:      None
  *
@@ -788,7 +743,7 @@ OpcDoUuId (
     ACPI_PARSE_OBJECT       *NewOp;
 
 
-    InString = ACPI_CAST_PTR (char, Op->Asl.Value.String);
+    InString = (char *) Op->Asl.Value.String;
     Buffer = UtLocalCalloc (16);
 
     Status = AuValidateUuid (InString);
@@ -808,27 +763,27 @@ OpcDoUuId (
 
     /* Disable further optimization */
 
-    Op->Asl.CompileFlags &= ~OP_COMPILE_TIME_CONST;
+    Op->Asl.CompileFlags &= ~NODE_COMPILE_TIME_CONST;
     UtSetParseOpName (Op);
 
     /* Child node is the buffer length */
 
-    NewOp = TrAllocateOp (PARSEOP_INTEGER);
+    NewOp = TrAllocateNode (PARSEOP_INTEGER);
 
-    NewOp->Asl.AmlOpcode = AML_BYTE_OP;
+    NewOp->Asl.AmlOpcode     = AML_BYTE_OP;
     NewOp->Asl.Value.Integer = 16;
-    NewOp->Asl.Parent = Op;
+    NewOp->Asl.Parent        = Op;
 
     Op->Asl.Child = NewOp;
     Op = NewOp;
 
     /* Peer to the child is the raw buffer data */
 
-    NewOp = TrAllocateOp (PARSEOP_RAW_DATA);
-    NewOp->Asl.AmlOpcode = AML_RAW_DATA_BUFFER;
-    NewOp->Asl.AmlLength = 16;
-    NewOp->Asl.Value.String = ACPI_CAST_PTR (char, Buffer);
-    NewOp->Asl.Parent = Op->Asl.Parent;
+    NewOp = TrAllocateNode (PARSEOP_RAW_DATA);
+    NewOp->Asl.AmlOpcode     = AML_RAW_DATA_BUFFER;
+    NewOp->Asl.AmlLength     = 16;
+    NewOp->Asl.Value.String  = (char *) Buffer;
+    NewOp->Asl.Parent        = Op->Asl.Parent;
 
     Op->Asl.Next = NewOp;
 }
@@ -838,7 +793,7 @@ OpcDoUuId (
  *
  * FUNCTION:    OpcGenerateAmlOpcode
  *
- * PARAMETERS:  Op                  - Parse node
+ * PARAMETERS:  Op        - Parse node
  *
  * RETURN:      None
  *
@@ -852,6 +807,7 @@ void
 OpcGenerateAmlOpcode (
     ACPI_PARSE_OBJECT       *Op)
 {
+
     UINT16                  Index;
 
 
@@ -897,21 +853,6 @@ OpcGenerateAmlOpcode (
         OpcDoEisaId (Op);
         break;
 
-    case PARSEOP_PRINTF:
-
-        OpcDoPrintf (Op);
-        break;
-
-    case PARSEOP_FPRINTF:
-
-        OpcDoFprintf (Op);
-        break;
-
-    case PARSEOP_TOPLD:
-
-        OpcDoPld (Op);
-        break;
-
     case PARSEOP_TOUUID:
 
         OpcDoUuId (Op);
@@ -924,7 +865,14 @@ OpcGenerateAmlOpcode (
 
     case PARSEOP_INCLUDE:
 
-        AslGbl_HasIncludeFiles = TRUE;
+        Op->Asl.Child->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
+        Gbl_HasIncludeFiles = TRUE;
+        break;
+
+    case PARSEOP_EXTERNAL:
+
+        Op->Asl.Child->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
+        Op->Asl.Child->Asl.Next->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
         break;
 
     case PARSEOP_TIMER:
