@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -256,7 +256,7 @@ AslDoOptions (
         }
         break;
 
-    case 'b':   /* Debug options */
+    case 'b':   /* Debug output options */
 
         switch (AcpiGbl_Optarg[0])
         {
@@ -265,38 +265,10 @@ AslDoOptions (
             AslCompilerdebug = 1; /* same as yydebug */
             DtParserdebug = 1;
             PrParserdebug = 1;
-            Gbl_DebugFlag = TRUE;
-            Gbl_KeepPreprocessorTempFile = TRUE;
-            break;
-
-        case 'p':   /* Prune ASL parse tree */
-
-            /* Get the required argument */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            Gbl_PruneParseTree = TRUE;
-            Gbl_PruneDepth = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
-            break;
-
-        case 's':
-
-            Gbl_DebugFlag = TRUE;
             break;
 
         case 't':
 
-            /* Get the required argument */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            Gbl_PruneType = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
             break;
 
         default:
@@ -305,6 +277,9 @@ AslDoOptions (
             return (-1);
         }
 
+        /* Produce debug output file */
+
+        Gbl_DebugFlag = TRUE;
         break;
 
     case 'c':
@@ -347,22 +322,6 @@ AslDoOptions (
 
             break;
 
-        case 'f':
-
-            AcpiGbl_ForceAmlDisassembly = TRUE;
-            break;
-
-        case 'l':   /* Use legacy ASL code (not ASL+) for disassembly */
-
-            Gbl_DoCompile = FALSE;
-            AcpiGbl_CstyleDisassembly = FALSE;
-            break;
-
-        case 'v':
-
-            AcpiGbl_DbOpt_Verbose = TRUE;
-            break;
-
         default:
 
             printf ("Unknown option: -d%s\n", AcpiGbl_Optarg);
@@ -526,13 +485,6 @@ AslDoOptions (
             Gbl_PreprocessorOutputFlag = TRUE;
             break;
 
-        case 'm':
-
-            /* Produce hardware map summary file */
-
-            Gbl_MapfileFlag = TRUE;
-            break;
-
         case 'n':
 
             /* Produce namespace file */
@@ -643,6 +595,7 @@ AslDoOptions (
 
         Gbl_OutputFilenamePrefix = AcpiGbl_Optarg;
         UtConvertBackslashes (Gbl_OutputFilenamePrefix);
+
         Gbl_UseDefaultAmlFilename = FALSE;
         break;
 
