@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #define __DTCOMPILER_H__
@@ -154,13 +118,10 @@
 #ifndef _DTCOMPILER
 #define _DTCOMPILER
 
+#include <stdio.h>
 #include "acdisasm.h"
 
 
-#define ASL_FIELD_CACHE_SIZE            512
-#define ASL_SUBTABLE_CACHE_SIZE         128
-
-
 #undef DT_EXTERN
 
 #ifdef _DECLARE_DT_GLOBALS
@@ -192,16 +153,15 @@
  */
 typedef struct dt_field
 {
-    char                    *Name;       /* Field name (from name : value) */
-    char                    *Value;      /* Field value (from name : value) */
-    UINT32                  StringLength; /* Length of Value */
-    struct dt_field         *Next;       /* Next field */
-    struct dt_field         *NextLabel;  /* If field is a label, next label */
-    UINT32                  Line;        /* Line number for this field */
-    UINT32                  ByteOffset;  /* Offset in source file for field */
-    UINT32                  NameColumn;  /* Start column for field name */
-    UINT32                  Column;      /* Start column for field value */
-    UINT32                  TableOffset; /* Binary offset within ACPI table */
+    char                    *Name;      /* Field name (from name : value) */
+    char                    *Value;     /* Field value (from name : value) */
+    struct dt_field         *Next;      /* Next field */
+    struct dt_field         *NextLabel; /* If field is a label, next label */
+    UINT32                  Line;       /* Line number for this field */
+    UINT32                  ByteOffset; /* Offset in source file for field */
+    UINT32                  NameColumn; /* Start column for field name */
+    UINT32                  Column;     /* Start column for field value */
+    UINT32                  TableOffset;/* Binary offset within ACPI table */
     UINT8                   Flags;
 
 } DT_FIELD;
@@ -210,17 +170,6 @@ typedef struct dt_field
 
 #define DT_FIELD_NOT_ALLOCATED      1
 
-/*
- * Structure used for each individual key or value
- */
-typedef struct dt_table_unit
-{
-    char                    *Value;      /* Field value (from name : value) */
-    UINT32                  Line;        /* Line number for this field */
-    UINT32                  Column;      /* Start column for field value */
-
-} DT_TABLE_UNIT;
-
 
 /*
  * Structure used for individual subtables within an ACPI table
@@ -233,7 +182,6 @@ typedef struct dt_subtable
     struct dt_subtable      *StackTop;
     UINT8                   *Buffer;
     UINT8                   *LengthField;
-    char                    *Name;
     UINT32                  Length;
     UINT32                  TotalLength;
     UINT32                  SizeOfLengthField;
@@ -249,39 +197,23 @@ typedef struct dt_subtable
 
 /* List of all field names and values from the input source */
 
-DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*AslGbl_FieldList, NULL);
+DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*Gbl_FieldList, NULL);
 
 /* List of all compiled tables and subtables */
 
-DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*AslGbl_RootTable, NULL);
+DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*Gbl_RootTable, NULL);
 
 /* Stack for subtables */
 
-DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*AslGbl_SubtableStack, NULL);
+DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*Gbl_SubtableStack, NULL);
 
 /* List for defined labels */
 
-DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*AslGbl_LabelList, NULL);
+DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*Gbl_LabelList, NULL);
 
 /* Current offset within the binary output table */
 
-DT_EXTERN UINT32            DT_INIT_GLOBAL (AslGbl_CurrentTableOffset, 0);
-
-/* Data table compiler Flex/Bison prototype */
-
-DT_EXTERN BOOLEAN           DT_INIT_GLOBAL (AslGbl_DtLexBisonPrototype, FALSE);
-
-/* Local caches */
-
-DT_EXTERN UINT32            DT_INIT_GLOBAL (AslGbl_SubtableCount, 0);
-DT_EXTERN ASL_CACHE_INFO    DT_INIT_GLOBAL (*AslGbl_SubtableCacheList, NULL);
-DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*AslGbl_SubtableCacheNext, NULL);
-DT_EXTERN DT_SUBTABLE       DT_INIT_GLOBAL (*AslGbl_SubtableCacheLast, NULL);
-
-DT_EXTERN UINT32            DT_INIT_GLOBAL (AslGbl_FieldCount, 0);
-DT_EXTERN ASL_CACHE_INFO    DT_INIT_GLOBAL (*AslGbl_FieldCacheList, NULL);
-DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*AslGbl_FieldCacheNext, NULL);
-DT_EXTERN DT_FIELD          DT_INIT_GLOBAL (*AslGbl_FieldCacheLast, NULL);
+DT_EXTERN UINT32            DT_INIT_GLOBAL (Gbl_CurrentTableOffset, 0);
 
 
 /* dtcompiler - main module */
@@ -290,31 +222,15 @@ ACPI_STATUS
 DtCompileTable (
     DT_FIELD                **Field,
     ACPI_DMTABLE_INFO       *Info,
-    DT_SUBTABLE             **RetSubtable);
-
-ACPI_STATUS
-DtCompileTwoSubtables (
-    void                    **List,
-    ACPI_DMTABLE_INFO       *TableInfo1,
-    ACPI_DMTABLE_INFO       *TableInfo2);
-
-ACPI_STATUS
-DtCompilePadding (
-    UINT32                  Length,
-    DT_SUBTABLE             **RetSubtable);
+    DT_SUBTABLE             **RetSubtable,
+    BOOLEAN                 Required);
 
 
 /* dtio - binary and text input/output */
 
 UINT32
 DtGetNextLine (
-    FILE                    *Handle,
-    UINT32                  Flags);
-
-/* Flags for DtGetNextLine */
-
-#define DT_ALLOW_MULTILINE_QUOTES   0x01
-
+    FILE                    *Handle);
 
 DT_FIELD *
 DtScanFile (
@@ -440,43 +356,12 @@ DtCompileFlag (
     ACPI_DMTABLE_INFO       *Info);
 
 
-/* dtfield - DT_FIELD operations */
-
-void
-DtLinkField (
-    DT_FIELD                *Field);
-
-void
-DtCreateField (
-    DT_TABLE_UNIT           *FieldKey,
-    DT_TABLE_UNIT           *FieldValue,
-    UINT32                  Offset);
-
-DT_TABLE_UNIT *
-DtCreateTableUnit (
-    char                    *Data,
-    UINT32                  Line,
-    UINT32                  Column);
-
-
 /* dtparser - lex/yacc files */
 
-int
-DtCompilerParserparse (
-    void);
-
 UINT64
 DtEvaluateExpression (
     char                    *ExprString);
 
-void
-DtCompilerInitLexer (
-    FILE                    *inFile);
-
-void
-DtCompilerTerminateLexer (
-    void);
-
 int
 DtInitLexer (
     char                    *String);
@@ -525,9 +410,10 @@ DtFatal (
     DT_FIELD                *FieldObject,
     char                    *ExtraMessage);
 
-UINT64
-DtDoConstant (
-    char                    *String);
+ACPI_STATUS
+DtStrtoul64 (
+    char                    *String,
+    UINT64                  *ReturnInteger);
 
 char*
 DtGetFieldValue (
@@ -554,6 +440,10 @@ void
 DtSetTableLength(
     void);
 
+void
+DtFreeFieldList (
+    void);
+
 
 /* dttable - individual table compilation */
 
@@ -585,10 +475,6 @@ ACPI_STATUS
 DtCompileDmar (
     void                    **PFieldList);
 
-ACPI_STATUS
-DtCompileDrtm (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompileEinj (
     void                    **PFieldList);
@@ -613,14 +499,6 @@ ACPI_STATUS
 DtCompileHest (
     void                    **PFieldList);
 
-ACPI_STATUS
-DtCompileHmat (
-    void                    **PFieldList);
-
-ACPI_STATUS
-DtCompileIort (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompileIvrs (
     void                    **PFieldList);
@@ -649,24 +527,12 @@ ACPI_STATUS
 DtCompileMtmr (
     void                    **PFieldList);
 
-ACPI_STATUS
-DtCompileNfit (
-    void                    **PFieldList);
-
-ACPI_STATUS
-DtCompilePcct (
-    void                    **PFieldList);
-
-ACPI_STATUS
-DtCompilePdtt (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompilePmtt (
     void                    **PFieldList);
 
 ACPI_STATUS
-DtCompilePptt (
+DtCompilePcct (
     void                    **PFieldList);
 
 ACPI_STATUS
@@ -677,10 +543,6 @@ ACPI_STATUS
 DtCompileS3pt (
     DT_FIELD                **PFieldList);
 
-ACPI_STATUS
-DtCompileSdev (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompileSlic (
     void                    **PFieldList);
@@ -693,18 +555,6 @@ ACPI_STATUS
 DtCompileSrat (
     void                    **PFieldList);
 
-ACPI_STATUS
-DtCompileStao (
-    void                    **PFieldList);
-
-ACPI_STATUS
-DtCompileTcpa (
-    void                    **PFieldList);
-
-ACPI_STATUS
-DtCompileTpm2 (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompileUefi (
     void                    **PFieldList);
@@ -717,19 +567,13 @@ ACPI_STATUS
 DtCompileWdat (
     void                    **PFieldList);
 
-ACPI_STATUS
-DtCompileWpbt (
-    void                    **PFieldList);
-
 ACPI_STATUS
 DtCompileXsdt (
     void                    **PFieldList);
 
 ACPI_STATUS
 DtCompileGeneric (
-    void                    **PFieldList,
-    char                    *TermFieldName,
-    UINT32                  *PFieldLength);
+    void                    **PFieldList);
 
 ACPI_DMTABLE_INFO *
 DtGetGenericTableInfo (
@@ -746,7 +590,6 @@ extern const unsigned char  TemplateCsrt[];
 extern const unsigned char  TemplateDbg2[];
 extern const unsigned char  TemplateDbgp[];
 extern const unsigned char  TemplateDmar[];
-extern const unsigned char  TemplateDrtm[];
 extern const unsigned char  TemplateEcdt[];
 extern const unsigned char  TemplateEinj[];
 extern const unsigned char  TemplateErst[];
@@ -754,9 +597,7 @@ extern const unsigned char  TemplateFadt[];
 extern const unsigned char  TemplateFpdt[];
 extern const unsigned char  TemplateGtdt[];
 extern const unsigned char  TemplateHest[];
-extern const unsigned char  TemplateHmat[];
 extern const unsigned char  TemplateHpet[];
-extern const unsigned char  TemplateIort[];
 extern const unsigned char  TemplateIvrs[];
 extern const unsigned char  TemplateLpit[];
 extern const unsigned char  TemplateMadt[];
@@ -764,25 +605,17 @@ extern const unsigned char  TemplateMcfg[];
 extern const unsigned char  TemplateMchi[];
 extern const unsigned char  TemplateMpst[];
 extern const unsigned char  TemplateMsct[];
-extern const unsigned char  TemplateMsdm[];
 extern const unsigned char  TemplateMtmr[];
-extern const unsigned char  TemplateNfit[];
 extern const unsigned char  TemplatePcct[];
-extern const unsigned char  TemplatePdtt[];
 extern const unsigned char  TemplatePmtt[];
-extern const unsigned char  TemplatePptt[];
-extern const unsigned char  TemplateRasf[];
 extern const unsigned char  TemplateRsdt[];
 extern const unsigned char  TemplateS3pt[];
 extern const unsigned char  TemplateSbst[];
-extern const unsigned char  TemplateSdei[];
-extern const unsigned char  TemplateSdev[];
 extern const unsigned char  TemplateSlic[];
 extern const unsigned char  TemplateSlit[];
 extern const unsigned char  TemplateSpcr[];
 extern const unsigned char  TemplateSpmi[];
 extern const unsigned char  TemplateSrat[];
-extern const unsigned char  TemplateStao[];
 extern const unsigned char  TemplateTcpa[];
 extern const unsigned char  TemplateTpm2[];
 extern const unsigned char  TemplateUefi[];
@@ -791,9 +624,6 @@ extern const unsigned char  TemplateWaet[];
 extern const unsigned char  TemplateWdat[];
 extern const unsigned char  TemplateWddt[];
 extern const unsigned char  TemplateWdrt[];
-extern const unsigned char  TemplateWpbt[];
-extern const unsigned char  TemplateWsmt[];
-extern const unsigned char  TemplateXenv[];
 extern const unsigned char  TemplateXsdt[];
 
 #endif
