@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -120,14 +120,12 @@
 #include "acdisasm.h"
 #include "acinterp.h"
 #include "acnamesp.h"
-#include "acdebug.h"
 
 #ifdef ACPI_DISASSEMBLER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dmopcode")
 
-
 /* Local prototypes */
 
 static void
@@ -342,10 +340,10 @@ AcpiDmPredefinedDescription (
      * Note: NameString is guaranteed to be upper case here.
      */
     LastCharIsDigit =
-        (isdigit ((int) NameString[3]));    /* d */
+        (ACPI_IS_DIGIT (NameString[3]));    /* d */
     LastCharsAreHex =
-        (isxdigit ((int) NameString[2]) &&  /* xx */
-         isxdigit ((int) NameString[3]));
+        (ACPI_IS_XDIGIT (NameString[2]) &&  /* xx */
+         ACPI_IS_XDIGIT (NameString[3]));
 
     switch (NameString[1])
     {
@@ -641,6 +639,7 @@ AcpiDmRegionFlags (
     ACPI_PARSE_OBJECT       *Op)
 {
 
+
     /* The next Op contains the SpaceId */
 
     Op = AcpiPsGetDepthNext (NULL, Op);
@@ -710,6 +709,7 @@ AcpiDmMatchKeyword (
     ACPI_PARSE_OBJECT       *Op)
 {
 
+
     if (((UINT32) Op->Common.Value.Integer) > ACPI_MAX_MATCH_OPCODE)
     {
         AcpiOsPrintf ("/* Unknown Match Keyword encoding */");
@@ -766,27 +766,27 @@ AcpiDmDisassembleOneOp (
 
     case ACPI_DASM_LNOT_SUFFIX:
 
-        if (!AcpiGbl_CstyleDisassembly)
+        switch (Op->Common.AmlOpcode)
         {
-            switch (Op->Common.AmlOpcode)
-            {
-            case AML_LEQUAL_OP:
-                AcpiOsPrintf ("LNotEqual");
-                break;
+        case AML_LEQUAL_OP:
 
-            case AML_LGREATER_OP:
-                AcpiOsPrintf ("LLessEqual");
-                break;
+            AcpiOsPrintf ("LNotEqual");
+            break;
 
-            case AML_LLESS_OP:
-                AcpiOsPrintf ("LGreaterEqual");
-                break;
+        case AML_LGREATER_OP:
 
-            default:
-                break;
-            }
+            AcpiOsPrintf ("LLessEqual");
+            break;
+
+        case AML_LLESS_OP:
+
+            AcpiOsPrintf ("LGreaterEqual");
+            break;
+
+        default:
+
+            break;
         }
-
         Op->Common.DisasmOpcode = 0;
         Op->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
         return;
@@ -795,6 +795,7 @@ AcpiDmDisassembleOneOp (
         break;
     }
 
+
     OpInfo = AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode);
 
     /* The op and arguments */
@@ -916,7 +917,7 @@ AcpiDmDisassembleOneOp (
         else if (AcpiDmIsPldBuffer (Op))
         {
             Op->Common.DisasmOpcode = ACPI_DASM_PLD_METHOD;
-            AcpiOsPrintf ("ToPLD (");
+            AcpiOsPrintf ("Buffer");
         }
         else
         {
@@ -925,6 +926,18 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
+    case AML_INT_STATICSTRING_OP:
+
+        if (Op->Common.Value.String)
+        {
+            AcpiOsPrintf ("%s", Op->Common.Value.String);
+        }
+        else
+        {
+            AcpiOsPrintf ("\"<NULL STATIC STRING PTR>\"");
+        }
+        break;
+
     case AML_INT_NAMEPATH_OP:
 
         AcpiDmNamestring (Op->Common.Value.Name);
@@ -992,9 +1005,7 @@ AcpiDmDisassembleOneOp (
             Length = (UINT32) Child->Common.Value.Integer;
 
             Info->Level += 1;
-            Info->MappingOp = Op;
             Op->Common.DisasmOpcode = ACPI_DASM_RESOURCE;
-
             AcpiDmResourceTemplate (Info, Op->Common.Parent, Aml, Length);
 
             Info->Level -= 1;
@@ -1040,7 +1051,7 @@ AcpiDmDisassembleOneOp (
             (WalkState->Results) &&
             (WalkState->ResultCount))
         {
-            AcpiDbDecodeInternalObject (
+            AcpiDmDecodeInternalObject (
                 WalkState->Results->Results.ObjDesc [
                     (WalkState->ResultCount - 1) %
                         ACPI_RESULTS_FRAME_OBJ_NUM]);
