@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
@@ -357,8 +358,7 @@ AcpiDmBlockType (
     case AML_BUFFER_OP:
 
         if ((Op->Common.DisasmOpcode == ACPI_DASM_UNICODE) ||
-            (Op->Common.DisasmOpcode == ACPI_DASM_UUID) ||
-            (Op->Common.DisasmOpcode == ACPI_DASM_PLD_METHOD))
+            (Op->Common.DisasmOpcode == ACPI_DASM_UUID))
         {
             return (BLOCK_NONE);
         }
@@ -374,19 +374,6 @@ AcpiDmBlockType (
 
         return (BLOCK_PAREN);
 
-    case AML_INT_METHODCALL_OP:
-
-        if (Op->Common.Parent &&
-            ((Op->Common.Parent->Common.AmlOpcode == AML_PACKAGE_OP) ||
-             (Op->Common.Parent->Common.AmlOpcode == AML_VAR_PACKAGE_OP)))
-        {
-            /* This is a reference to a method, not an invocation */
-
-            return (BLOCK_NONE);
-        }
-
-        /*lint -fallthrough */
-
     default:
 
         OpInfo = AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode);
@@ -484,24 +471,8 @@ AcpiDmDescendingOp (
     const ACPI_OPCODE_INFO  *OpInfo;
     UINT32                  Name;
     ACPI_PARSE_OBJECT       *NextOp;
-    UINT32                  AmlOffset;
 
 
-    if (AcpiGbl_DbOpt_Verbose && AcpiGbl_PreviousOp)
-    {
-        /* Dump the entire statement in AML byte code */
-
-        if (Op->Common.Aml > AcpiGbl_PreviousOp->Common.Aml)
-        {
-            AcpiOsPrintf ("\n");
-            AcpiUtDumpBuffer (AcpiGbl_PreviousOp->Common.Aml,
-                (Op->Common.Aml - AcpiGbl_PreviousOp->Common.Aml),
-                DB_BYTE_DISPLAY, 0);
-            AcpiDmIndent (Level);
-        }
-    }
-    AcpiGbl_PreviousOp = Op;
-
     if (Op->Common.DisasmFlags & ACPI_PARSEOP_IGNORE)
     {
         /* Ignore this op -- it was handled elsewhere */
@@ -517,12 +488,10 @@ AcpiDmDescendingOp (
 
         if (Info->WalkState)
         {
-            AmlOffset = (UINT32) ACPI_PTR_DIFF (Op->Common.Aml,
-                            Info->WalkState->ParserState.AmlStart);
             VERBOSE_PRINT ((DB_FULL_OP_INFO,
                 (Info->WalkState->MethodNode ?
                     Info->WalkState->MethodNode->Name.Ascii : "   "),
-                AmlOffset, (UINT32) Op->Common.AmlOpcode));
+                Op->Common.AmlOffset, (UINT32) Op->Common.AmlOpcode));
         }
 
         if (Op->Common.AmlOpcode == AML_SCOPE_OP)
@@ -581,20 +550,13 @@ AcpiDmDescendingOp (
      * keep track of the current column.
      */
     Info->Count++;
-    if (Info->Count /* +Info->LastLevel */ > 12)
+    if (Info->Count /* +Info->LastLevel */ > 10)
     {
         Info->Count = 0;
         AcpiOsPrintf ("\n");
         AcpiDmIndent (Info->LastLevel + 1);
     }
 
-    /* If ASL+ is enabled, check for a C-style operator */
-
-    if (AcpiDmCheckForSymbolicOpcode (Op, Info))
-    {
-        return (AE_OK);
-    }
-
     /* Print the opcode name */
 
     AcpiDmDisassembleOneOp (NULL, Info, Op);
@@ -654,7 +616,7 @@ AcpiDmDescendingOp (
 
                 if (Op->Common.AmlOpcode != AML_INT_NAMEDFIELD_OP)
                 {
-                    if (AcpiGbl_DbOpt_Verbose)
+                    if (AcpiGbl_DbOpt_verbose)
                     {
                         (void) AcpiPsDisplayObjectPathname (NULL, Op);
                     }
@@ -674,6 +636,7 @@ AcpiDmDescendingOp (
                 AcpiDmPredefinedDescription (Op);
                 break;
 
+
             case AML_NAME_OP:
 
                 /* Check for _HID and related EISAID() */
@@ -682,11 +645,13 @@ AcpiDmDescendingOp (
                 AcpiOsPrintf (", ");
                 break;
 
+
             case AML_REGION_OP:
 
                 AcpiDmRegionFlags (Op);
                 break;
 
+
             case AML_POWER_RES_OP:
 
                 /* Mark the next two Ops as part of the parameter list */
@@ -699,6 +664,7 @@ AcpiDmDescendingOp (
                 NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
                 return (AE_OK);
 
+
             case AML_PROCESSOR_OP:
 
                 /* Mark the next three Ops as part of the parameter list */
@@ -714,17 +680,20 @@ AcpiDmDescendingOp (
                 NextOp->Common.DisasmFlags |= ACPI_PARSEOP_PARAMLIST;
                 return (AE_OK);
 
+
             case AML_MUTEX_OP:
             case AML_DATA_REGION_OP:
 
                 AcpiOsPrintf (", ");
                 return (AE_OK);
 
+
             case AML_EVENT_OP:
             case AML_ALIAS_OP:
 
                 return (AE_OK);
 
+
             case AML_SCOPE_OP:
             case AML_DEVICE_OP:
             case AML_THERMAL_ZONE_OP:
@@ -732,6 +701,7 @@ AcpiDmDescendingOp (
                 AcpiOsPrintf (")");
                 break;
 
+
             default:
 
                 AcpiOsPrintf ("*** Unhandled named opcode %X\n",
@@ -928,9 +898,9 @@ AcpiDmAscendingOp (
     {
     case BLOCK_PAREN:
 
-        /* Completed an op that has arguments, add closing paren if needed */
+        /* Completed an op that has arguments, add closing paren */
 
-        AcpiDmCloseOperator (Op);
+        AcpiOsPrintf (")");
 
         if (Op->Common.AmlOpcode == AML_NAME_OP)
         {
@@ -1102,21 +1072,8 @@ AcpiDmAscendingOp (
     {
         Info->Level++;
     }
-
-    /*
-     * For ASL+, check for and emit a C-style symbol. If valid, the
-     * symbol string has been deferred until after the first operand
-     */
-    if (AcpiGbl_CstyleDisassembly)
-    {
-        if (Op->Asl.OperatorSymbol)
-        {
-            AcpiOsPrintf ("%s", Op->Asl.OperatorSymbol);
-            Op->Asl.OperatorSymbol = NULL;
-        }
-    }
-
     return (AE_OK);
 }
 
+
 #endif  /* ACPI_DISASSEMBLER */
