@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
+#define __EVXFGPE_C__
 #define EXPORT_ACPI_INTERFACES
 
 #include "acpi.h"
@@ -188,7 +154,6 @@ AcpiUpdateAllGpes (
     void)
 {
     ACPI_STATUS             Status;
-    BOOLEAN                 IsPollingNeeded = FALSE;
 
 
     ACPI_FUNCTION_TRACE (AcpiUpdateAllGpes);
@@ -205,8 +170,7 @@ AcpiUpdateAllGpes (
         goto UnlockAndExit;
     }
 
-    Status = AcpiEvWalkGpeList (AcpiEvInitializeGpeBlock,
-        &IsPollingNeeded);
+    Status = AcpiEvWalkGpeList (AcpiEvInitializeGpeBlock, NULL);
     if (ACPI_SUCCESS (Status))
     {
         AcpiGbl_AllGpesInitialized = TRUE;
@@ -214,13 +178,6 @@ AcpiUpdateAllGpes (
 
 UnlockAndExit:
     (void) AcpiUtReleaseMutex (ACPI_MTX_EVENTS);
-
-    if (IsPollingNeeded && AcpiGbl_AllGpesInitialized)
-    {
-        /* Poll GPEs to handle already triggered events */
-
-        AcpiEvGpeDetect (AcpiGbl_GpeXruptListHead);
-    }
     return_ACPI_STATUS (Status);
 }
 
@@ -264,20 +221,10 @@ AcpiEnableGpe (
     GpeEventInfo = AcpiEvGetGpeEventInfo (GpeDevice, GpeNumber);
     if (GpeEventInfo)
     {
-        if (ACPI_GPE_DISPATCH_TYPE (GpeEventInfo->Flags) !=
+        if ((GpeEventInfo->Flags & ACPI_GPE_DISPATCH_MASK) !=
             ACPI_GPE_DISPATCH_NONE)
         {
-            Status = AcpiEvAddGpeReference (GpeEventInfo, TRUE);
-            if (ACPI_SUCCESS (Status) &&
-                ACPI_GPE_IS_POLLING_NEEDED (GpeEventInfo))
-            {
-                /* Poll edge-triggered GPEs to handle existing events */
-
-                AcpiOsReleaseLock (AcpiGbl_GpeLock, Flags);
-                (void) AcpiEvDetectGpe (
-                    GpeDevice, GpeEventInfo, GpeNumber);
-                Flags = AcpiOsAcquireLock (AcpiGbl_GpeLock);
-            }
+            Status = AcpiEvAddGpeReference (GpeEventInfo);
         }
         else
         {
@@ -348,21 +295,12 @@ ACPI_EXPORT_SYMBOL (AcpiDisableGpe)
  * RETURN:      Status
  *
  * DESCRIPTION: Enable or disable an individual GPE. This function bypasses
- *              the reference count mechanism used in the AcpiEnableGpe(),
- *              AcpiDisableGpe() interfaces.
- *              This API is typically used by the GPE raw handler mode driver
- *              to switch between the polling mode and the interrupt mode after
- *              the driver has enabled the GPE.
- *              The APIs should be invoked in this order:
- *               AcpiEnableGpe()              <- Ensure the reference count > 0
- *               AcpiSetGpe(ACPI_GPE_DISABLE) <- Enter polling mode
- *               AcpiSetGpe(ACPI_GPE_ENABLE)  <- Leave polling mode
- *               AcpiDisableGpe()             <- Decrease the reference count
+ *              the reference count mechanism used in the AcpiEnableGpe and
+ *              AcpiDisableGpe interfaces -- and should be used with care.
  *
- * Note: If a GPE is shared by 2 silicon components, then both the drivers
- *       should support GPE polling mode or disabling the GPE for long period
- *       for one driver may break the other. So use it with care since all
- *       firmware _Lxx/_Exx handlers currently rely on the GPE interrupt mode.
+ * Note: Typically used to disable a runtime GPE for short period of time,
+ * then re-enable it, without disturbing the existing reference counts. This
+ * is useful, for example, in the Embedded Controller (EC) driver.
  *
  ******************************************************************************/
 
@@ -397,14 +335,12 @@ AcpiSetGpe (
     {
     case ACPI_GPE_ENABLE:
 
-        Status = AcpiHwLowSetGpe (GpeEventInfo, ACPI_GPE_ENABLE);
-        GpeEventInfo->DisableForDispatch = FALSE;
+        Status = AcpiEvEnableGpe (GpeEventInfo);
         break;
 
     case ACPI_GPE_DISABLE:
 
         Status = AcpiHwLowSetGpe (GpeEventInfo, ACPI_GPE_DISABLE);
-        GpeEventInfo->DisableForDispatch = TRUE;
         break;
 
     default:
@@ -421,56 +357,6 @@ UnlockAndExit:
 ACPI_EXPORT_SYMBOL (AcpiSetGpe)
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiMaskGpe
- *
- * PARAMETERS:  GpeDevice           - Parent GPE Device. NULL for GPE0/GPE1
- *              GpeNumber           - GPE level within the GPE block
- *              IsMasked            - Whether the GPE is masked or not
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Unconditionally mask/unmask the an individual GPE, ex., to
- *              prevent a GPE flooding.
- *
- ******************************************************************************/
-
-ACPI_STATUS
-AcpiMaskGpe (
-    ACPI_HANDLE             GpeDevice,
-    UINT32                  GpeNumber,
-    BOOLEAN                 IsMasked)
-{
-    ACPI_GPE_EVENT_INFO     *GpeEventInfo;
-    ACPI_STATUS             Status;
-    ACPI_CPU_FLAGS          Flags;
-
-
-    ACPI_FUNCTION_TRACE (AcpiMaskGpe);
-
-
-    Flags = AcpiOsAcquireLock (AcpiGbl_GpeLock);
-
-    /* Ensure that we have a valid GPE number */
-
-    GpeEventInfo = AcpiEvGetGpeEventInfo (GpeDevice, GpeNumber);
-    if (!GpeEventInfo)
-    {
-        Status = AE_BAD_PARAMETER;
-        goto UnlockAndExit;
-    }
-
-    Status = AcpiEvMaskGpe (GpeEventInfo, IsMasked);
-
-UnlockAndExit:
-    AcpiOsReleaseLock (AcpiGbl_GpeLock, Flags);
-    return_ACPI_STATUS (Status);
-}
-
-ACPI_EXPORT_SYMBOL (AcpiMaskGpe)
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiMarkGpeForWake
@@ -618,8 +504,8 @@ AcpiSetupGpeForWake (
      * known as an "implicit notify". Note: The GPE is assumed to be
      * level-triggered (for windows compatibility).
      */
-    if (ACPI_GPE_DISPATCH_TYPE (GpeEventInfo->Flags) ==
-        ACPI_GPE_DISPATCH_NONE)
+    if ((GpeEventInfo->Flags & ACPI_GPE_DISPATCH_MASK) ==
+            ACPI_GPE_DISPATCH_NONE)
     {
         /*
          * This is the first device for implicit notify on this GPE.
@@ -628,23 +514,13 @@ AcpiSetupGpeForWake (
         GpeEventInfo->Flags =
             (ACPI_GPE_DISPATCH_NOTIFY | ACPI_GPE_LEVEL_TRIGGERED);
     }
-    else if (GpeEventInfo->Flags & ACPI_GPE_AUTO_ENABLED)
-    {
-        /*
-         * A reference to this GPE has been added during the GPE block
-         * initialization, so drop it now to prevent the GPE from being
-         * permanently enabled and clear its ACPI_GPE_AUTO_ENABLED flag.
-         */
-        (void) AcpiEvRemoveGpeReference (GpeEventInfo);
-        GpeEventInfo->Flags &= ~~ACPI_GPE_AUTO_ENABLED;
-    }
 
     /*
      * If we already have an implicit notify on this GPE, add
      * this device to the notify list.
      */
-    if (ACPI_GPE_DISPATCH_TYPE (GpeEventInfo->Flags) ==
-        ACPI_GPE_DISPATCH_NOTIFY)
+    if ((GpeEventInfo->Flags & ACPI_GPE_DISPATCH_MASK) ==
+            ACPI_GPE_DISPATCH_NOTIFY)
     {
         /* Ensure that the device is not already in the list */
 
@@ -885,9 +761,9 @@ ACPI_EXPORT_SYMBOL (AcpiGetGpeStatus)
  *
  * RETURN:      Status
  *
- * DESCRIPTION: Clear and conditionally re-enable a GPE. This completes the GPE
+ * DESCRIPTION: Clear and conditionally reenable a GPE. This completes the GPE
  *              processing. Intended for use by asynchronous host-installed
- *              GPE handlers. The GPE is only re-enabled if the EnableForRun bit
+ *              GPE handlers. The GPE is only reenabled if the EnableForRun bit
  *              is set in the GPE info.
  *
  ******************************************************************************/
@@ -1000,44 +876,6 @@ AcpiEnableAllRuntimeGpes (
 ACPI_EXPORT_SYMBOL (AcpiEnableAllRuntimeGpes)
 
 
-/******************************************************************************
- *
- * FUNCTION:    AcpiEnableAllWakeupGpes
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Enable all "wakeup" GPEs and disable all of the other GPEs, in
- *              all GPE blocks.
- *
- ******************************************************************************/
-
-ACPI_STATUS
-AcpiEnableAllWakeupGpes (
-    void)
-{
-    ACPI_STATUS             Status;
-
-
-    ACPI_FUNCTION_TRACE (AcpiEnableAllWakeupGpes);
-
-
-    Status = AcpiUtAcquireMutex (ACPI_MTX_EVENTS);
-    if (ACPI_FAILURE (Status))
-    {
-        return_ACPI_STATUS (Status);
-    }
-
-    Status = AcpiHwEnableAllWakeupGpes ();
-    (void) AcpiUtReleaseMutex (ACPI_MTX_EVENTS);
-
-    return_ACPI_STATUS (Status);
-}
-
-ACPI_EXPORT_SYMBOL (AcpiEnableAllWakeupGpes)
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiInstallGpeBlock
@@ -1109,8 +947,8 @@ AcpiInstallGpeBlock (
      * is always zero
      */
     Status = AcpiEvCreateGpeBlock (Node, GpeBlockAddress->Address,
-        GpeBlockAddress->SpaceId, RegisterCount,
-        0, InterruptNumber, &GpeBlock);
+                GpeBlockAddress->SpaceId, RegisterCount,
+                0, InterruptNumber, &GpeBlock);
     if (ACPI_FAILURE (Status))
     {
         goto UnlockAndExit;
