@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,44 +111,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __EXDEBUG_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acinterp.h"
@@ -189,8 +155,6 @@ AcpiExDoDebugObject (
 {
     UINT32                  i;
     UINT32                  Timer;
-    ACPI_OPERAND_OBJECT     *ObjectDesc;
-    UINT32                  Value;
 
 
     ACPI_FUNCTION_TRACE_PTR (ExDoDebugObject, SourceDesc);
@@ -204,19 +168,13 @@ AcpiExDoDebugObject (
         return_VOID;
     }
 
-    /* Newline -- don't emit the line header */
-
-    if (SourceDesc &&
-        (ACPI_GET_DESCRIPTOR_TYPE (SourceDesc) == ACPI_DESC_TYPE_OPERAND) &&
-        (SourceDesc->Common.Type == ACPI_TYPE_STRING))
-    {
-        if ((SourceDesc->String.Length == 1) &&
-            (*SourceDesc->String.Pointer == '\n'))
-        {
-            AcpiOsPrintf ("\n");
-            return_VOID;
-        }
-    }
+    /*
+     * We will emit the current timer value (in microseconds) with each
+     * debug output. Only need the lower 26 bits. This allows for 67
+     * million microseconds or 67 seconds before rollover.
+     */
+    Timer = (UINT32) (AcpiOsGetTimer () / 10); /* (100 nanoseconds to microseconds) */
+    Timer &= 0x03FFFFFF;
 
     /*
      * Print line header as long as we are not in the middle of an
@@ -224,31 +182,14 @@ AcpiExDoDebugObject (
      */
     if (!((Level > 0) && Index == 0))
     {
-        if (AcpiGbl_DisplayDebugTimer)
-        {
-            /*
-             * We will emit the current timer value (in microseconds) with each
-             * debug output. Only need the lower 26 bits. This allows for 67
-             * million microseconds or 67 seconds before rollover.
-             *
-             * Convert 100 nanosecond units to microseconds
-             */
-            Timer = ((UINT32) AcpiOsGetTimer () / 10);
-            Timer &= 0x03FFFFFF;
-
-            AcpiOsPrintf ("ACPI Debug: T=0x%8.8X %*s", Timer, Level, " ");
-        }
-        else
-        {
-            AcpiOsPrintf ("ACPI Debug: %*s", Level, " ");
-        }
+        AcpiOsPrintf ("[ACPI Debug %.8u] %*s", Timer, Level, " ");
     }
 
     /* Display the index for package output only */
 
     if (Index > 0)
     {
-       AcpiOsPrintf ("(%.2u) ", Index - 1);
+       AcpiOsPrintf ("(%.2u) ", Index-1);
     }
 
     if (!SourceDesc)
@@ -259,13 +200,7 @@ AcpiExDoDebugObject (
 
     if (ACPI_GET_DESCRIPTOR_TYPE (SourceDesc) == ACPI_DESC_TYPE_OPERAND)
     {
-        /* No object type prefix needed for integers and strings */
-
-        if ((SourceDesc->Common.Type != ACPI_TYPE_INTEGER) &&
-            (SourceDesc->Common.Type != ACPI_TYPE_STRING))
-        {
-            AcpiOsPrintf ("%s  ", AcpiUtGetObjectTypeName (SourceDesc));
-        }
+        AcpiOsPrintf ("%s ", AcpiUtGetObjectTypeName (SourceDesc));
 
         if (!AcpiUtValidInternalObject (SourceDesc))
         {
@@ -275,9 +210,9 @@ AcpiExDoDebugObject (
     }
     else if (ACPI_GET_DESCRIPTOR_TYPE (SourceDesc) == ACPI_DESC_TYPE_NAMED)
     {
-        AcpiOsPrintf ("%s  (Node %p)\n",
+        AcpiOsPrintf ("%s: %p\n",
             AcpiUtGetTypeName (((ACPI_NAMESPACE_NODE *) SourceDesc)->Type),
-                SourceDesc);
+            SourceDesc);
         return_VOID;
     }
     else
@@ -315,12 +250,13 @@ AcpiExDoDebugObject (
 
     case ACPI_TYPE_STRING:
 
-        AcpiOsPrintf ("\"%s\"\n", SourceDesc->String.Pointer);
+        AcpiOsPrintf ("[0x%.2X] \"%s\"\n",
+            SourceDesc->String.Length, SourceDesc->String.Pointer);
         break;
 
     case ACPI_TYPE_PACKAGE:
 
-        AcpiOsPrintf ("(Contains 0x%.2X Elements):\n",
+        AcpiOsPrintf ("[Contains 0x%.2X Elements]\n",
             SourceDesc->Package.Count);
 
         /* Output the entire contents of the package */
@@ -328,7 +264,7 @@ AcpiExDoDebugObject (
         for (i = 0; i < SourceDesc->Package.Count; i++)
         {
             AcpiExDoDebugObject (SourceDesc->Package.Elements[i],
-                Level + 4, i + 1);
+                Level+4, i+1);
         }
         break;
 
@@ -364,7 +300,7 @@ AcpiExDoDebugObject (
         if (SourceDesc->Reference.Node)
         {
             if (ACPI_GET_DESCRIPTOR_TYPE (SourceDesc->Reference.Node) !=
-                ACPI_DESC_TYPE_NAMED)
+                    ACPI_DESC_TYPE_NAMED)
             {
                 AcpiOsPrintf (" %p - Not a valid namespace node\n",
                     SourceDesc->Reference.Node);
@@ -389,7 +325,7 @@ AcpiExDoDebugObject (
                 default:
 
                     AcpiExDoDebugObject ((SourceDesc->Reference.Node)->Object,
-                        Level + 4, 0);
+                        Level+4, 0);
                     break;
                 }
             }
@@ -397,61 +333,23 @@ AcpiExDoDebugObject (
         else if (SourceDesc->Reference.Object)
         {
             if (ACPI_GET_DESCRIPTOR_TYPE (SourceDesc->Reference.Object) ==
-                ACPI_DESC_TYPE_NAMED)
+                    ACPI_DESC_TYPE_NAMED)
             {
-                /* Reference object is a namespace node */
-
-                AcpiExDoDebugObject (ACPI_CAST_PTR (ACPI_OPERAND_OBJECT,
-                    SourceDesc->Reference.Object),
-                    Level + 4, 0);
+                AcpiExDoDebugObject (((ACPI_NAMESPACE_NODE *)
+                    SourceDesc->Reference.Object)->Object,
+                    Level+4, 0);
             }
             else
             {
-                ObjectDesc = SourceDesc->Reference.Object;
-                Value = SourceDesc->Reference.Value;
-
-                switch (ObjectDesc->Common.Type)
-                {
-                case ACPI_TYPE_BUFFER:
-
-                    AcpiOsPrintf ("Buffer[%u] = 0x%2.2X\n",
-                        Value, *SourceDesc->Reference.IndexPointer);
-                    break;
-
-                case ACPI_TYPE_STRING:
-
-                    AcpiOsPrintf ("String[%u] = \"%c\" (0x%2.2X)\n",
-                        Value, *SourceDesc->Reference.IndexPointer,
-                        *SourceDesc->Reference.IndexPointer);
-                    break;
-
-                case ACPI_TYPE_PACKAGE:
-
-                    AcpiOsPrintf ("Package[%u] = ", Value);
-                    if (!(*SourceDesc->Reference.Where))
-                    {
-                        AcpiOsPrintf ("[Uninitialized Package Element]\n");
-                    }
-                    else
-                    {
-                        AcpiExDoDebugObject (*SourceDesc->Reference.Where,
-                            Level+4, 0);
-                    }
-                    break;
-
-                default:
-
-                    AcpiOsPrintf ("Unknown Reference object type %X\n",
-                        ObjectDesc->Common.Type);
-                    break;
-                }
+                AcpiExDoDebugObject (SourceDesc->Reference.Object,
+                    Level+4, 0);
             }
         }
         break;
 
     default:
 
-        AcpiOsPrintf ("(Descriptor %p)\n", SourceDesc);
+        AcpiOsPrintf ("%p\n", SourceDesc);
         break;
     }
 
