@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,9 @@
  *
  *****************************************************************************/
 
+
+#define __EXFIELD_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acdispat.h"
@@ -343,39 +346,6 @@ AcpiExReadDataFromField (
         Buffer = &BufferDesc->Integer.Value;
     }
 
-    if ((ObjDesc->Common.Type == ACPI_TYPE_LOCAL_REGION_FIELD) &&
-        (ObjDesc->Field.RegionObj->Region.SpaceId == ACPI_ADR_SPACE_GPIO))
-    {
-        /*
-         * For GPIO (GeneralPurposeIo), the Address will be the bit offset
-         * from the previous Connection() operator, making it effectively a
-         * pin number index. The BitLength is the length of the field, which
-         * is thus the number of pins.
-         */
-        ACPI_DEBUG_PRINT ((ACPI_DB_BFIELD,
-            "GPIO FieldRead [FROM]:  Pin %u Bits %u\n",
-            ObjDesc->Field.PinNumberIndex, ObjDesc->Field.BitLength));
-
-        /* Lock entire transaction if requested */
-
-        AcpiExAcquireGlobalLock (ObjDesc->CommonField.FieldFlags);
-
-        /* Perform the write */
-
-        Status = AcpiExAccessRegion (ObjDesc, 0,
-                    (UINT64 *) Buffer, ACPI_READ);
-        AcpiExReleaseGlobalLock (ObjDesc->CommonField.FieldFlags);
-        if (ACPI_FAILURE (Status))
-        {
-            AcpiUtRemoveReference (BufferDesc);
-        }
-        else
-        {
-            *RetBufferDesc = BufferDesc;
-        }
-        return_ACPI_STATUS (Status);
-    }
-
     ACPI_DEBUG_PRINT ((ACPI_DB_BFIELD,
         "FieldRead [TO]:   Obj %p, Type %X, Buf %p, ByteLen %X\n",
         ObjDesc, ObjDesc->Common.Type, Buffer, (UINT32) Length));
@@ -532,7 +502,7 @@ AcpiExWriteDataToField (
         }
 
         Buffer = BufferDesc->Buffer.Pointer;
-        memcpy (Buffer, SourceDesc->Buffer.Pointer, Length);
+        ACPI_MEMCPY (Buffer, SourceDesc->Buffer.Pointer, Length);
 
         /* Lock entire transaction if requested */
 
@@ -549,41 +519,6 @@ AcpiExWriteDataToField (
         *ResultDesc = BufferDesc;
         return_ACPI_STATUS (Status);
     }
-    else if ((ObjDesc->Common.Type == ACPI_TYPE_LOCAL_REGION_FIELD) &&
-             (ObjDesc->Field.RegionObj->Region.SpaceId == ACPI_ADR_SPACE_GPIO))
-    {
-        /*
-         * For GPIO (GeneralPurposeIo), we will bypass the entire field
-         * mechanism and handoff the bit address and bit width directly to
-         * the handler. The Address will be the bit offset
-         * from the previous Connection() operator, making it effectively a
-         * pin number index. The BitLength is the length of the field, which
-         * is thus the number of pins.
-         */
-        if (SourceDesc->Common.Type != ACPI_TYPE_INTEGER)
-        {
-            return_ACPI_STATUS (AE_AML_OPERAND_TYPE);
-        }
-
-        ACPI_DEBUG_PRINT ((ACPI_DB_BFIELD,
-            "GPIO FieldWrite [FROM]: (%s:%X), Val %.8X  [TO]:  Pin %u Bits %u\n",
-            AcpiUtGetTypeName (SourceDesc->Common.Type),
-            SourceDesc->Common.Type, (UINT32) SourceDesc->Integer.Value,
-            ObjDesc->Field.PinNumberIndex, ObjDesc->Field.BitLength));
-
-        Buffer = &SourceDesc->Integer.Value;
-
-        /* Lock entire transaction if requested */
-
-        AcpiExAcquireGlobalLock (ObjDesc->CommonField.FieldFlags);
-
-        /* Perform the write */
-
-        Status = AcpiExAccessRegion (ObjDesc, 0,
-                    (UINT64 *) Buffer, ACPI_WRITE);
-        AcpiExReleaseGlobalLock (ObjDesc->CommonField.FieldFlags);
-        return_ACPI_STATUS (Status);
-    }
 
     /* Get a pointer to the data to be written */
 
