@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __HWPCI_C__
+
 #include "acpi.h"
 #include "accommon.h"
 
@@ -212,7 +214,7 @@ AcpiHwDerivePciId (
     ACPI_HANDLE             PciRegion)
 {
     ACPI_STATUS             Status;
-    ACPI_PCI_DEVICE         *ListHead;
+    ACPI_PCI_DEVICE         *ListHead = NULL;
 
 
     ACPI_FUNCTION_TRACE (HwDerivePciId);
@@ -270,6 +272,7 @@ AcpiHwBuildPciList (
     ACPI_HANDLE             ParentDevice;
     ACPI_STATUS             Status;
     ACPI_PCI_DEVICE         *ListElement;
+    ACPI_PCI_DEVICE         *ListHead = NULL;
 
 
     /*
@@ -277,7 +280,6 @@ AcpiHwBuildPciList (
      * a list of device nodes. Loop will exit when either the PCI device is
      * found, or the root of the namespace is reached.
      */
-    *ReturnListHead = NULL;
     CurrentDevice = PciRegion;
     while (1)
     {
@@ -294,6 +296,7 @@ AcpiHwBuildPciList (
 
         if (ParentDevice == RootPciDevice)
         {
+            *ReturnListHead = ListHead;
             return (AE_OK);
         }
 
@@ -308,9 +311,9 @@ AcpiHwBuildPciList (
 
         /* Put new element at the head of the list */
 
-        ListElement->Next = *ReturnListHead;
+        ListElement->Next = ListHead;
         ListElement->Device = ParentDevice;
-        *ReturnListHead = ListElement;
+        ListHead = ListElement;
 
         CurrentDevice = ParentDevice;
     }
