@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,44 +112,10 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __HWREGS_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acevents.h"
@@ -162,12 +128,6 @@
 
 /* Local Prototypes */
 
-static UINT8
-AcpiHwGetAccessBitWidth (
-    UINT64                  Address,
-    ACPI_GENERIC_ADDRESS    *Reg,
-    UINT8                   MaxBitWidth);
-
 static ACPI_STATUS
 AcpiHwReadMultiple (
     UINT32                  *Value,
@@ -182,91 +142,6 @@ AcpiHwWriteMultiple (
 
 #endif /* !ACPI_REDUCED_HARDWARE */
 
-
-/******************************************************************************
- *
- * FUNCTION:    AcpiHwGetAccessBitWidth
- *
- * PARAMETERS:  Address             - GAS register address
- *              Reg                 - GAS register structure
- *              MaxBitWidth         - Max BitWidth supported (32 or 64)
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Obtain optimal access bit width
- *
- ******************************************************************************/
-
-static UINT8
-AcpiHwGetAccessBitWidth (
-    UINT64                  Address,
-    ACPI_GENERIC_ADDRESS    *Reg,
-    UINT8                   MaxBitWidth)
-{
-    UINT8                   AccessBitWidth;
-
-
-    /*
-     * GAS format "register", used by FADT:
-     *  1. Detected if BitOffset is 0 and BitWidth is 8/16/32/64;
-     *  2. AccessSize field is ignored and BitWidth field is used for
-     *     determining the boundary of the IO accesses.
-     * GAS format "region", used by APEI registers:
-     *  1. Detected if BitOffset is not 0 or BitWidth is not 8/16/32/64;
-     *  2. AccessSize field is used for determining the boundary of the
-     *     IO accesses;
-     *  3. BitOffset/BitWidth fields are used to describe the "region".
-     *
-     * Note: This algorithm assumes that the "Address" fields should always
-     *       contain aligned values.
-     */
-    if (!Reg->BitOffset && Reg->BitWidth &&
-        ACPI_IS_POWER_OF_TWO (Reg->BitWidth) &&
-        ACPI_IS_ALIGNED (Reg->BitWidth, 8))
-    {
-        AccessBitWidth = Reg->BitWidth;
-    }
-    else if (Reg->AccessWidth)
-    {
-        AccessBitWidth = (1 << (Reg->AccessWidth + 2));
-    }
-    else
-    {
-        AccessBitWidth = ACPI_ROUND_UP_POWER_OF_TWO_8 (
-            Reg->BitOffset + Reg->BitWidth);
-        if (AccessBitWidth <= 8)
-        {
-            AccessBitWidth = 8;
-        }
-        else
-        {
-            while (!ACPI_IS_ALIGNED (Address, AccessBitWidth >> 3))
-            {
-                AccessBitWidth >>= 1;
-            }
-        }
-    }
-
-    /* Maximum IO port access bit width is 32 */
-
-    if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_IO)
-    {
-        MaxBitWidth = 32;
-    }
-
-    /*
-     * Return access width according to the requested maximum access bit width,
-     * as the caller should know the format of the register and may enforce
-     * a 32-bit accesses.
-     */
-    if (AccessBitWidth < MaxBitWidth)
-    {
-        return (AccessBitWidth);
-    }
-    return (MaxBitWidth);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    AcpiHwValidateRegister
@@ -289,9 +164,6 @@ AcpiHwValidateRegister (
     UINT8                   MaxBitWidth,
     UINT64                  *Address)
 {
-    UINT8                   BitWidth;
-    UINT8                   AccessWidth;
-
 
     /* Must have a valid pointer to a GAS structure */
 
@@ -321,25 +193,24 @@ AcpiHwValidateRegister (
         return (AE_SUPPORT);
     }
 
-    /* Validate the AccessWidth */
+    /* Validate the BitWidth */
 
-    if (Reg->AccessWidth > 4)
+    if ((Reg->BitWidth != 8) &&
+        (Reg->BitWidth != 16) &&
+        (Reg->BitWidth != 32) &&
+        (Reg->BitWidth != MaxBitWidth))
     {
         ACPI_ERROR ((AE_INFO,
-            "Unsupported register access width: 0x%X", Reg->AccessWidth));
+            "Unsupported register bit width: 0x%X", Reg->BitWidth));
         return (AE_SUPPORT);
     }
 
-    /* Validate the BitWidth, convert AccessWidth into number of bits */
+    /* Validate the BitOffset. Just a warning for now. */
 
-    AccessWidth = AcpiHwGetAccessBitWidth (*Address, Reg, MaxBitWidth);
-    BitWidth = ACPI_ROUND_UP (Reg->BitOffset + Reg->BitWidth, AccessWidth);
-    if (MaxBitWidth < BitWidth)
+    if (Reg->BitOffset != 0)
     {
         ACPI_WARNING ((AE_INFO,
-            "Requested bit width 0x%X is smaller than register bit width 0x%X",
-            MaxBitWidth, BitWidth));
-        return (AE_SUPPORT);
+            "Unsupported register bit offset: 0x%X", Reg->BitOffset));
     }
 
     return (AE_OK);
@@ -360,7 +231,10 @@ AcpiHwValidateRegister (
  *              64-bit values is not needed.
  *
  * LIMITATIONS: <These limitations also apply to AcpiHwWrite>
+ *      BitWidth must be exactly 8, 16, or 32.
  *      SpaceID must be SystemMemory or SystemIO.
+ *      BitOffset and AccessWidth are currently ignored, as there has
+ *          not been a need to implement these.
  *
  ******************************************************************************/
 
@@ -370,12 +244,7 @@ AcpiHwRead (
     ACPI_GENERIC_ADDRESS    *Reg)
 {
     UINT64                  Address;
-    UINT8                   AccessWidth;
-    UINT32                  BitWidth;
-    UINT8                   BitOffset;
     UINT64                  Value64;
-    UINT32                  Value32;
-    UINT8                   Index;
     ACPI_STATUS             Status;
 
 
@@ -390,58 +259,30 @@ AcpiHwRead (
         return (Status);
     }
 
-    /*
-     * Initialize entire 32-bit return value to zero, convert AccessWidth
-     * into number of bits based
-     */
+    /* Initialize entire 32-bit return value to zero */
+
     *Value = 0;
-    AccessWidth = AcpiHwGetAccessBitWidth (Address, Reg, 32);
-    BitWidth = Reg->BitOffset + Reg->BitWidth;
-    BitOffset = Reg->BitOffset;
 
     /*
      * Two address spaces supported: Memory or IO. PCI_Config is
      * not supported here because the GAS structure is insufficient
      */
-    Index = 0;
-    while (BitWidth)
+    if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
     {
-        if (BitOffset >= AccessWidth)
-        {
-            Value32 = 0;
-            BitOffset -= AccessWidth;
-        }
-        else
-        {
-            if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
-            {
-                Status = AcpiOsReadMemory ((ACPI_PHYSICAL_ADDRESS)
-                    Address + Index * ACPI_DIV_8 (AccessWidth),
-                    &Value64, AccessWidth);
-                Value32 = (UINT32) Value64;
-            }
-            else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
-            {
-                Status = AcpiHwReadPort ((ACPI_IO_ADDRESS)
-                    Address + Index * ACPI_DIV_8 (AccessWidth),
-                    &Value32, AccessWidth);
-            }
-        }
+        Status = AcpiOsReadMemory ((ACPI_PHYSICAL_ADDRESS)
+                    Address, &Value64, Reg->BitWidth);
 
-        /*
-         * Use offset style bit writes because "Index * AccessWidth" is
-         * ensured to be less than 32-bits by AcpiHwValidateRegister().
-         */
-        ACPI_SET_BITS (Value, Index * AccessWidth,
-            ACPI_MASK_BITS_ABOVE_32 (AccessWidth), Value32);
-
-        BitWidth -= BitWidth > AccessWidth ? AccessWidth : BitWidth;
-        Index++;
+        *Value = (UINT32) Value64;
+    }
+    else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
+    {
+        Status = AcpiHwReadPort ((ACPI_IO_ADDRESS)
+                    Address, Value, Reg->BitWidth);
     }
 
     ACPI_DEBUG_PRINT ((ACPI_DB_IO,
         "Read:  %8.8X width %2d from %8.8X%8.8X (%s)\n",
-        *Value, AccessWidth, ACPI_FORMAT_UINT64 (Address),
+        *Value, Reg->BitWidth, ACPI_FORMAT_UINT64 (Address),
         AcpiUtGetRegionName (Reg->SpaceId)));
 
     return (Status);
@@ -469,12 +310,6 @@ AcpiHwWrite (
     ACPI_GENERIC_ADDRESS    *Reg)
 {
     UINT64                  Address;
-    UINT8                   AccessWidth;
-    UINT32                  BitWidth;
-    UINT8                   BitOffset;
-    UINT64                  Value64;
-    UINT32                  Value32;
-    UINT8                   Index;
     ACPI_STATUS             Status;
 
 
@@ -489,58 +324,24 @@ AcpiHwWrite (
         return (Status);
     }
 
-    /* Convert AccessWidth into number of bits based */
-
-    AccessWidth = AcpiHwGetAccessBitWidth (Address, Reg, 32);
-    BitWidth = Reg->BitOffset + Reg->BitWidth;
-    BitOffset = Reg->BitOffset;
-
     /*
      * Two address spaces supported: Memory or IO. PCI_Config is
      * not supported here because the GAS structure is insufficient
      */
-    Index = 0;
-    while (BitWidth)
+    if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
     {
-        /*
-         * Use offset style bit reads because "Index * AccessWidth" is
-         * ensured to be less than 32-bits by AcpiHwValidateRegister().
-         */
-        Value32 = ACPI_GET_BITS (&Value, Index * AccessWidth,
-            ACPI_MASK_BITS_ABOVE_32 (AccessWidth));
-
-        if (BitOffset >= AccessWidth)
-        {
-            BitOffset -= AccessWidth;
-        }
-        else
-        {
-            if (Reg->SpaceId == ACPI_ADR_SPACE_SYSTEM_MEMORY)
-            {
-                Value64 = (UINT64) Value32;
-                Status = AcpiOsWriteMemory ((ACPI_PHYSICAL_ADDRESS)
-                    Address + Index * ACPI_DIV_8 (AccessWidth),
-                    Value64, AccessWidth);
-            }
-            else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
-            {
-                Status = AcpiHwWritePort ((ACPI_IO_ADDRESS)
-                    Address + Index * ACPI_DIV_8 (AccessWidth),
-                    Value32, AccessWidth);
-            }
-        }
-
-        /*
-         * Index * AccessWidth is ensured to be less than 32-bits by
-         * AcpiHwValidateRegister().
-         */
-        BitWidth -= BitWidth > AccessWidth ? AccessWidth : BitWidth;
-        Index++;
+        Status = AcpiOsWriteMemory ((ACPI_PHYSICAL_ADDRESS)
+                    Address, (UINT64) Value, Reg->BitWidth);
+    }
+    else /* ACPI_ADR_SPACE_SYSTEM_IO, validated earlier */
+    {
+        Status = AcpiHwWritePort ((ACPI_IO_ADDRESS)
+                    Address, Value, Reg->BitWidth);
     }
 
     ACPI_DEBUG_PRINT ((ACPI_DB_IO,
         "Wrote: %8.8X width %2d   to %8.8X%8.8X (%s)\n",
-        Value, AccessWidth, ACPI_FORMAT_UINT64 (Address),
+        Value, Reg->BitWidth, ACPI_FORMAT_UINT64 (Address),
         AcpiUtGetRegionName (Reg->SpaceId)));
 
     return (Status);
@@ -580,7 +381,7 @@ AcpiHwClearAcpiStatus (
     /* Clear the fixed events in PM1 A/B */
 
     Status = AcpiHwRegisterWrite (ACPI_REGISTER_PM1_STATUS,
-        ACPI_BITMASK_ALL_FIXED_STATUS);
+                ACPI_BITMASK_ALL_FIXED_STATUS);
 
     AcpiOsReleaseLock (AcpiGbl_HardwareLock, LockFlags);
 
@@ -699,22 +500,22 @@ AcpiHwRegisterRead (
     case ACPI_REGISTER_PM1_STATUS:           /* PM1 A/B: 16-bit access each */
 
         Status = AcpiHwReadMultiple (&Value,
-            &AcpiGbl_XPm1aStatus,
-            &AcpiGbl_XPm1bStatus);
+                    &AcpiGbl_XPm1aStatus,
+                    &AcpiGbl_XPm1bStatus);
         break;
 
     case ACPI_REGISTER_PM1_ENABLE:           /* PM1 A/B: 16-bit access each */
 
         Status = AcpiHwReadMultiple (&Value,
-            &AcpiGbl_XPm1aEnable,
-            &AcpiGbl_XPm1bEnable);
+                    &AcpiGbl_XPm1aEnable,
+                    &AcpiGbl_XPm1bEnable);
         break;
 
     case ACPI_REGISTER_PM1_CONTROL:          /* PM1 A/B: 16-bit access each */
 
         Status = AcpiHwReadMultiple (&Value,
-            &AcpiGbl_FADT.XPm1aControlBlock,
-            &AcpiGbl_FADT.XPm1bControlBlock);
+                    &AcpiGbl_FADT.XPm1aControlBlock,
+                    &AcpiGbl_FADT.XPm1bControlBlock);
 
         /*
          * Zero the write-only bits. From the ACPI specification, "Hardware
@@ -810,15 +611,15 @@ AcpiHwRegisterWrite (
         Value &= ~ACPI_PM1_STATUS_PRESERVED_BITS;
 
         Status = AcpiHwWriteMultiple (Value,
-            &AcpiGbl_XPm1aStatus,
-            &AcpiGbl_XPm1bStatus);
+                    &AcpiGbl_XPm1aStatus,
+                    &AcpiGbl_XPm1bStatus);
         break;
 
     case ACPI_REGISTER_PM1_ENABLE:           /* PM1 A/B: 16-bit access each */
 
         Status = AcpiHwWriteMultiple (Value,
-            &AcpiGbl_XPm1aEnable,
-            &AcpiGbl_XPm1bEnable);
+                    &AcpiGbl_XPm1aEnable,
+                    &AcpiGbl_XPm1bEnable);
         break;
 
     case ACPI_REGISTER_PM1_CONTROL:          /* PM1 A/B: 16-bit access each */
@@ -827,8 +628,8 @@ AcpiHwRegisterWrite (
          * Note: This includes SCI_EN, we never want to change this bit
          */
         Status = AcpiHwReadMultiple (&ReadValue,
-            &AcpiGbl_FADT.XPm1aControlBlock,
-            &AcpiGbl_FADT.XPm1bControlBlock);
+                    &AcpiGbl_FADT.XPm1aControlBlock,
+                    &AcpiGbl_FADT.XPm1bControlBlock);
         if (ACPI_FAILURE (Status))
         {
             goto Exit;
@@ -841,8 +642,8 @@ AcpiHwRegisterWrite (
         /* Now we can write the data */
 
         Status = AcpiHwWriteMultiple (Value,
-            &AcpiGbl_FADT.XPm1aControlBlock,
-            &AcpiGbl_FADT.XPm1bControlBlock);
+                    &AcpiGbl_FADT.XPm1aControlBlock,
+                    &AcpiGbl_FADT.XPm1bControlBlock);
         break;
 
     case ACPI_REGISTER_PM2_CONTROL:          /* 8-bit access */
