@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __TBUTILS_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "actables.h"
@@ -147,6 +149,8 @@ ACPI_STATUS
 AcpiTbInitializeFacs (
     void)
 {
+    ACPI_STATUS             Status;
+
 
     /* If Hardware Reduced flag is set, there is no FACS */
 
@@ -156,23 +160,9 @@ AcpiTbInitializeFacs (
         return (AE_OK);
     }
 
-    (void) AcpiGetTableByIndex (ACPI_TABLE_INDEX_FACS,
-                ACPI_CAST_INDIRECT_PTR (ACPI_TABLE_HEADER, &AcpiGbl_Facs32));
-    (void) AcpiGetTableByIndex (ACPI_TABLE_INDEX_X_FACS,
-                ACPI_CAST_INDIRECT_PTR (ACPI_TABLE_HEADER, &AcpiGbl_Facs64));
-
-    if (AcpiGbl_Facs64 && (!AcpiGbl_Facs32 || !AcpiGbl_Use32BitFacsAddresses))
-    {
-        AcpiGbl_FACS = AcpiGbl_Facs64;
-    }
-    else if (AcpiGbl_Facs32)
-    {
-        AcpiGbl_FACS = AcpiGbl_Facs32;
-    }
-
-    /* If there is no FACS, just continue. There was already an error msg */
-
-    return (AE_OK);
+    Status = AcpiGetTableByIndex (ACPI_TABLE_INDEX_FACS,
+                ACPI_CAST_INDIRECT_PTR (ACPI_TABLE_HEADER, &AcpiGbl_FACS));
+    return (Status);
 }
 #endif /* !ACPI_REDUCED_HARDWARE */
 
@@ -195,7 +185,7 @@ AcpiTbTablesLoaded (
     void)
 {
 
-    if (AcpiGbl_RootTableList.CurrentTableCount >= 4)
+    if (AcpiGbl_RootTableList.CurrentTableCount >= 3)
     {
         return (TRUE);
     }
@@ -274,7 +264,7 @@ AcpiTbCopyDsdt (
         return (NULL);
     }
 
-    memcpy (NewTable, TableDesc->Pointer, TableDesc->Length);
+    ACPI_MEMCPY (NewTable, TableDesc->Pointer, TableDesc->Length);
     AcpiTbUninstallTable (TableDesc);
 
     AcpiTbInitTableDescriptor (
@@ -473,11 +463,11 @@ AcpiTbParseRootTable (
     TableEntry = ACPI_ADD_PTR (UINT8, Table, sizeof (ACPI_TABLE_HEADER));
 
     /*
-     * First three entries in the table array are reserved for the DSDT
-     * and 32bit/64bit FACS, which are not actually present in the
-     * RSDT/XSDT - they come from the FADT
+     * First two entries in the table array are reserved for the DSDT
+     * and FACS, which are not actually present in the RSDT/XSDT - they
+     * come from the FADT
      */
-    AcpiGbl_RootTableList.CurrentTableCount = 3;
+    AcpiGbl_RootTableList.CurrentTableCount = 2;
 
     /* Initialize the root table array from the RSDT/XSDT */
 
