@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Module Name: utclib - ACPICA implementations of C library functions
+ * Module Name: cmclib - Local implementation of C library functions
  *
  *****************************************************************************/
 
@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,62 +113,31 @@
  *
  *****************************************************************************/
 
-#define ACPI_CLIBRARY
+
+#define __CMCLIB_C__
+
 #include "acpi.h"
 #include "accommon.h"
 
 /*
- * This module contains implementations of the standard C library functions
- * that are required by the ACPICA code at both application level and kernel
- * level.
- *
- * The module is an optional feature that can be used if a local/system
- * C library is not available. Some operating system kernels may not have
- * an internal C library.
- *
- * In general, these functions are less efficient than an inline or assembly
- * code implementation.
- *
- * These C functions and the associated prototypes are enabled by default
- * unless the ACPI_USE_SYSTEM_CLIBRARY symbol is defined. This is usually
- * automatically defined for the ACPICA applications such as iASL and
- * AcpiExec, so that these user-level applications use the local C library
- * instead of the functions in this module.
+ * These implementations of standard C Library routines can optionally be
+ * used if a C library is not available. In general, they are less efficient
+ * than an inline or assembly implementation
  */
 
-/*******************************************************************************
- *
- * Functions implemented in this module:
- *
- * FUNCTION:    memcmp
- * FUNCTION:    memcpy
- * FUNCTION:    memset
- * FUNCTION:    strlen
- * FUNCTION:    strcpy
- * FUNCTION:    strncpy
- * FUNCTION:    strcmp
- * FUNCTION:    strchr
- * FUNCTION:    strncmp
- * FUNCTION:    strcat
- * FUNCTION:    strncat
- * FUNCTION:    strstr
- * FUNCTION:    strtoul
- * FUNCTION:    toupper
- * FUNCTION:    tolower
- * FUNCTION:    is* functions
- *
- ******************************************************************************/
-
 #define _COMPONENT          ACPI_UTILITIES
-        ACPI_MODULE_NAME    ("utclib")
+        ACPI_MODULE_NAME    ("cmclib")
 
 
-#ifndef ACPI_USE_SYSTEM_CLIBRARY    /* Entire module */
+#ifndef ACPI_USE_SYSTEM_CLIBRARY
+
+#define NEGATIVE    1
+#define POSITIVE    0
 
 
 /*******************************************************************************
  *
- * FUNCTION:    memcmp
+ * FUNCTION:    AcpiUtMemcmp (memcmp)
  *
  * PARAMETERS:  Buffer1         - First Buffer
  *              Buffer2         - Second Buffer
@@ -181,14 +150,11 @@
  ******************************************************************************/
 
 int
-memcmp (
-    void                    *VBuffer1,
-    void                    *VBuffer2,
+AcpiUtMemcmp (
+    const char              *Buffer1,
+    const char              *Buffer2,
     ACPI_SIZE               Count)
 {
-    char                    *Buffer1 = (char *) VBuffer1;
-    char                    *Buffer2 = (char *) VBuffer2;
-
 
     for ( ; Count-- && (*Buffer1 == *Buffer2); Buffer1++, Buffer2++)
     {
@@ -201,7 +167,7 @@ memcmp (
 
 /*******************************************************************************
  *
- * FUNCTION:    memcpy
+ * FUNCTION:    AcpiUtMemcpy (memcpy)
  *
  * PARAMETERS:  Dest        - Target of the copy
  *              Src         - Source buffer to copy
@@ -214,7 +180,7 @@ memcmp (
  ******************************************************************************/
 
 void *
-memcpy (
+AcpiUtMemcpy (
     void                    *Dest,
     const void              *Src,
     ACPI_SIZE               Count)
@@ -237,7 +203,7 @@ memcpy (
 
 /*******************************************************************************
  *
- * FUNCTION:    memset
+ * FUNCTION:    AcpiUtMemset (memset)
  *
  * PARAMETERS:  Dest        - Buffer to set
  *              Value       - Value to set each byte of memory
@@ -250,9 +216,9 @@ memcpy (
  ******************************************************************************/
 
 void *
-memset (
+AcpiUtMemset (
     void                    *Dest,
-    int                     Value,
+    UINT8                   Value,
     ACPI_SIZE               Count)
 {
     char                    *New = (char *) Dest;
@@ -271,7 +237,7 @@ memset (
 
 /*******************************************************************************
  *
- * FUNCTION:    strlen
+ * FUNCTION:    AcpiUtStrlen (strlen)
  *
  * PARAMETERS:  String              - Null terminated string
  *
@@ -283,7 +249,7 @@ memset (
 
 
 ACPI_SIZE
-strlen (
+AcpiUtStrlen (
     const char              *String)
 {
     UINT32                  Length = 0;
@@ -303,7 +269,7 @@ strlen (
 
 /*******************************************************************************
  *
- * FUNCTION:    strcpy
+ * FUNCTION:    AcpiUtStrcpy (strcpy)
  *
  * PARAMETERS:  DstString       - Target of the copy
  *              SrcString       - The source string to copy
@@ -315,7 +281,7 @@ strlen (
  ******************************************************************************/
 
 char *
-strcpy (
+AcpiUtStrcpy (
     char                    *DstString,
     const char              *SrcString)
 {
@@ -341,7 +307,7 @@ strcpy (
 
 /*******************************************************************************
  *
- * FUNCTION:    strncpy
+ * FUNCTION:    AcpiUtStrncpy (strncpy)
  *
  * PARAMETERS:  DstString       - Target of the copy
  *              SrcString       - The source string to copy
@@ -354,7 +320,7 @@ strcpy (
  ******************************************************************************/
 
 char *
-strncpy (
+AcpiUtStrncpy (
     char                    *DstString,
     const char              *SrcString,
     ACPI_SIZE               Count)
@@ -384,7 +350,7 @@ strncpy (
 
 /*******************************************************************************
  *
- * FUNCTION:    strcmp
+ * FUNCTION:    AcpiUtStrcmp (strcmp)
  *
  * PARAMETERS:  String1         - First string
  *              String2         - Second string
@@ -396,7 +362,7 @@ strncpy (
  ******************************************************************************/
 
 int
-strcmp (
+AcpiUtStrcmp (
     const char              *String1,
     const char              *String2)
 {
@@ -416,7 +382,7 @@ strcmp (
 
 /*******************************************************************************
  *
- * FUNCTION:    strchr
+ * FUNCTION:    AcpiUtStrchr (strchr)
  *
  * PARAMETERS:  String          - Search string
  *              ch              - character to search for
@@ -428,7 +394,7 @@ strcmp (
  ******************************************************************************/
 
 char *
-strchr (
+AcpiUtStrchr (
     const char              *String,
     int                     ch)
 {
@@ -448,7 +414,7 @@ strchr (
 
 /*******************************************************************************
  *
- * FUNCTION:    strncmp
+ * FUNCTION:    AcpiUtStrncmp (strncmp)
  *
  * PARAMETERS:  String1         - First string
  *              String2         - Second string
@@ -461,7 +427,7 @@ strchr (
  ******************************************************************************/
 
 int
-strncmp (
+AcpiUtStrncmp (
     const char              *String1,
     const char              *String2,
     ACPI_SIZE               Count)
@@ -483,7 +449,7 @@ strncmp (
 
 /*******************************************************************************
  *
- * FUNCTION:    strcat
+ * FUNCTION:    AcpiUtStrcat (Strcat)
  *
  * PARAMETERS:  DstString       - Target of the copy
  *              SrcString       - The source string to copy
@@ -495,7 +461,7 @@ strncmp (
  ******************************************************************************/
 
 char *
-strcat (
+AcpiUtStrcat (
     char                    *DstString,
     const char              *SrcString)
 {
@@ -518,7 +484,7 @@ strcat (
 
 /*******************************************************************************
  *
- * FUNCTION:    strncat
+ * FUNCTION:    AcpiUtStrncat (strncat)
  *
  * PARAMETERS:  DstString       - Target of the copy
  *              SrcString       - The source string to copy
@@ -532,7 +498,7 @@ strcat (
  ******************************************************************************/
 
 char *
-strncat (
+AcpiUtStrncat (
     char                    *DstString,
     const char              *SrcString,
     ACPI_SIZE               Count)
@@ -566,7 +532,7 @@ strncat (
 
 /*******************************************************************************
  *
- * FUNCTION:    strstr
+ * FUNCTION:    AcpiUtStrstr (strstr)
  *
  * PARAMETERS:  String1         - Target string
  *              String2         - Substring to search for
@@ -580,35 +546,38 @@ strncat (
  ******************************************************************************/
 
 char *
-strstr (
+AcpiUtStrstr (
     char                    *String1,
     char                    *String2)
 {
-    UINT32                  Length;
+    char                    *String;
 
 
-    Length = strlen (String2);
-    if (!Length)
+    if (AcpiUtStrlen (String2) > AcpiUtStrlen (String1))
     {
-        return (String1);
+        return (NULL);
     }
 
-    while (strlen (String1) >= Length)
+    /* Walk entire string, comparing the letters */
+
+    for (String = String1; *String2; )
     {
-        if (memcmp (String1, String2, Length) == 0)
+        if (*String2 != *String)
         {
-            return (String1);
+            return (NULL);
         }
-        String1++;
+
+        String2++;
+        String++;
     }
 
-    return (NULL);
+    return (String1);
 }
 
 
 /*******************************************************************************
  *
- * FUNCTION:    strtoul
+ * FUNCTION:    AcpiUtStrtoul (strtoul)
  *
  * PARAMETERS:  String          - Null terminated string
  *              Terminater      - Where a pointer to the terminating byte is
@@ -618,12 +587,12 @@ strstr (
  * RETURN:      Converted value
  *
  * DESCRIPTION: Convert a string into a 32-bit unsigned value.
- *              Note: use strtoul64 for 64-bit integers.
+ *              Note: use AcpiUtStrtoul64 for 64-bit integers.
  *
  ******************************************************************************/
 
 UINT32
-strtoul (
+AcpiUtStrtoul (
     const char              *String,
     char                    **Terminator,
     UINT32                  Base)
@@ -642,7 +611,7 @@ strtoul (
      * skip over any white space in the buffer:
      */
     StringStart = String;
-    while (isspace (*String) || *String == '\t')
+    while (ACPI_IS_SPACE (*String) || *String == '\t')
     {
         ++String;
     }
@@ -653,17 +622,17 @@ strtoul (
      */
     if (*String == '-')
     {
-        sign = ACPI_SIGN_NEGATIVE;
+        sign = NEGATIVE;
         ++String;
     }
     else if (*String == '+')
     {
         ++String;
-        sign = ACPI_SIGN_POSITIVE;
+        sign = POSITIVE;
     }
     else
     {
-        sign = ACPI_SIGN_POSITIVE;
+        sign = POSITIVE;
     }
 
     /*
@@ -674,7 +643,7 @@ strtoul (
     {
         if (*String == '0')
         {
-            if (tolower (*(++String)) == 'x')
+            if (AcpiUtToLower (*(++String)) == 'x')
             {
                 Base = 16;
                 ++String;
@@ -709,7 +678,7 @@ strtoul (
 
     if (Base == 16 &&
         *String == '0' &&
-        tolower (*(++String)) == 'x')
+        AcpiUtToLower (*(++String)) == 'x')
     {
         String++;
     }
@@ -719,14 +688,14 @@ strtoul (
      */
     while (*String)
     {
-        if (isdigit (*String))
+        if (ACPI_IS_DIGIT (*String))
         {
             index = (UINT32) ((UINT8) *String - '0');
         }
         else
         {
-            index = (UINT32) toupper (*String);
-            if (isupper (index))
+            index = (UINT32) AcpiUtToUpper (*String);
+            if (ACPI_IS_UPPER (index))
             {
                 index = index - 'A' + 10;
             }
@@ -786,7 +755,7 @@ done:
     /*
      * If a minus sign was present, then "the conversion is negated":
      */
-    if (sign == ACPI_SIGN_NEGATIVE)
+    if (sign == NEGATIVE)
     {
         ReturnValue = (ACPI_UINT32_MAX - ReturnValue) + 1;
     }
@@ -797,7 +766,7 @@ done:
 
 /*******************************************************************************
  *
- * FUNCTION:    toupper
+ * FUNCTION:    AcpiUtToUpper (TOUPPER)
  *
  * PARAMETERS:  c           - Character to convert
  *
@@ -808,17 +777,17 @@ done:
  ******************************************************************************/
 
 int
-toupper (
+AcpiUtToUpper (
     int                     c)
 {
 
-    return (islower(c) ? ((c)-0x20) : (c));
+    return (ACPI_IS_LOWER(c) ? ((c)-0x20) : (c));
 }
 
 
 /*******************************************************************************
  *
- * FUNCTION:    tolower
+ * FUNCTION:    AcpiUtToLower (TOLOWER)
  *
  * PARAMETERS:  c           - Character to convert
  *
@@ -829,23 +798,23 @@ toupper (
  ******************************************************************************/
 
 int
-tolower (
+AcpiUtToLower (
     int                     c)
 {
 
-    return (isupper(c) ? ((c)+0x20) : (c));
+    return (ACPI_IS_UPPER(c) ? ((c)+0x20) : (c));
 }
 
 
 /*******************************************************************************
  *
- * FUNCTION:    is* function array
+ * FUNCTION:    is* functions
  *
  * DESCRIPTION: is* functions use the ctype table below
  *
  ******************************************************************************/
 
-const UINT8 AcpiGbl_Ctypes[257] = {
+const UINT8 _acpi_ctype[257] = {
     _ACPI_CN,            /* 0x00     0 NUL */
     _ACPI_CN,            /* 0x01     1 SOH */
     _ACPI_CN,            /* 0x02     2 STX */
