@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -132,7 +132,7 @@
 #define ACPI_RAW_TABLE_DATA_HEADER      "Raw Table Data"
 
 
-typedef struct acpi_dmtable_info
+typedef const struct acpi_dmtable_info
 {
     UINT8                       Opcode;
     UINT16                      Offset;
@@ -201,7 +201,6 @@ typedef enum
     /* Types used only for the Data Table Compiler */
 
     ACPI_DMT_BUFFER,
-    ACPI_DMT_RAW_BUFFER,  /* Large, multiple line buffer */
     ACPI_DMT_DEVICE_PATH,
     ACPI_DMT_LABEL,
     ACPI_DMT_PCI_PATH,
@@ -220,11 +219,9 @@ typedef enum
     ACPI_DMT_HEST,
     ACPI_DMT_HESTNTFY,
     ACPI_DMT_HESTNTYP,
-    ACPI_DMT_IORTMEM,
     ACPI_DMT_IVRS,
     ACPI_DMT_LPIT,
     ACPI_DMT_MADT,
-    ACPI_DMT_NFIT,
     ACPI_DMT_PCCT,
     ACPI_DMT_PMTT,
     ACPI_DMT_SLIC,
@@ -252,6 +249,7 @@ typedef struct acpi_dmtable_data
     ACPI_DMTABLE_HANDLER    TableHandler;
     ACPI_CMTABLE_HANDLER    CmTableHandler;
     const unsigned char     *Template;
+    char                    *Name;
 
 } ACPI_DMTABLE_DATA;
 
@@ -264,7 +262,6 @@ typedef struct acpi_op_walk_info
     UINT32                  BitOffset;
     UINT32                  Flags;
     ACPI_WALK_STATE         *WalkState;
-    ACPI_PARSE_OBJECT       *MappingOp;
 
 } ACPI_OP_WALK_INFO;
 
@@ -282,7 +279,6 @@ ACPI_STATUS (*ASL_WALK_CALLBACK) (
 
 typedef
 void (*ACPI_RESOURCE_HANDLER) (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
@@ -319,7 +315,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoCpep0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoCsrt0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoCsrt1[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoCsrt2[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoCsrt2a[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDbg2[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDbg2Device[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDbg2Addr[];
@@ -336,11 +331,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDmar2[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDmar3[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDmar4[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm0[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm0a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm1[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm1a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoDrtm2[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoEcdt[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoEinj[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoEinj0[];
@@ -351,7 +341,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFadt1[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFadt2[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFadt3[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFadt5[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFadt6[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFpdt[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFpdtHdr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoFpdt0[];
@@ -377,20 +366,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoHpet[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoLpitHdr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoLpit0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoLpit1[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort0[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort0a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort1[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort1a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort2[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort3[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort3a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort3b[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIort3c[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIortAcc[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIortHdr[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIortMap[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIortPad[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIvrs[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIvrs0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoIvrs1[];
@@ -415,7 +390,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadt11[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadt12[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadt13[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadt14[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadt15[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMadtHdr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMcfg[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMcfg0[];
@@ -430,18 +404,6 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMsct[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMsct0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMtmr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoMtmr0[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfitHdr[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit0[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit1[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit2[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit2a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit3[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit3a[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit4[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit5[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit6[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoNfit6a[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoPmtt[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoPmtt0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoPmtt1[];
@@ -459,7 +421,9 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoS3ptHdr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoS3pt0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoS3pt1[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSbst[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSlic[];
+extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSlicHdr[];
+extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSlic0[];
+extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSlic1[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSlit[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSpcr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSpmi[];
@@ -468,12 +432,7 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSratHdr[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSrat0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSrat1[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSrat2[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoSrat3[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoStao[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoStaoStr[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoTcpaHdr[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoTcpaClient[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoTcpaServer[];
+extern ACPI_DMTABLE_INFO        AcpiDmTableInfoTcpa[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoTpm2[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoUefi[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoVrtc[];
@@ -483,17 +442,14 @@ extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWdat[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWdat0[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWddt[];
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWdrt[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWpbt[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoWpbt0[];
-extern ACPI_DMTABLE_INFO        AcpiDmTableInfoXenv[];
 
 extern ACPI_DMTABLE_INFO        AcpiDmTableInfoGeneric[][2];
 
+
 /*
- * dmtable and ahtable
+ * dmtable
  */
-extern const ACPI_DMTABLE_DATA  AcpiDmTableData[];
-extern const AH_TABLE           AcpiSupportedTables[];
+extern ACPI_DMTABLE_DATA        AcpiDmTableData[];
 
 UINT8
 AcpiDmGenerateChecksum (
@@ -501,7 +457,7 @@ AcpiDmGenerateChecksum (
     UINT32                  Length,
     UINT8                   OriginalChecksum);
 
-const ACPI_DMTABLE_DATA *
+ACPI_DMTABLE_DATA *
 AcpiDmGetTableData (
     char                    *Signature);
 
@@ -535,20 +491,6 @@ AcpiDmLineHeader2 (
  * dmtbdump
  */
 void
-AcpiDmDumpBuffer (
-    void                    *Table,
-    UINT32                  BufferOffset,
-    UINT32                  Length,
-    UINT32                  AbsoluteOffset,
-    char                    *Header);
-
-void
-AcpiDmDumpUnicode (
-    void                    *Table,
-    UINT32                  BufferOffset,
-    UINT32                  ByteLength);
-
-void
 AcpiDmDumpAsf (
     ACPI_TABLE_HEADER       *Table);
 
@@ -568,10 +510,6 @@ void
 AcpiDmDumpDmar (
     ACPI_TABLE_HEADER       *Table);
 
-void
-AcpiDmDumpDrtm (
-    ACPI_TABLE_HEADER       *Table);
-
 void
 AcpiDmDumpEinj (
     ACPI_TABLE_HEADER       *Table);
@@ -596,10 +534,6 @@ void
 AcpiDmDumpHest (
     ACPI_TABLE_HEADER       *Table);
 
-void
-AcpiDmDumpIort (
-    ACPI_TABLE_HEADER       *Table);
-
 void
 AcpiDmDumpIvrs (
     ACPI_TABLE_HEADER       *Table);
@@ -628,10 +562,6 @@ void
 AcpiDmDumpMtmr (
     ACPI_TABLE_HEADER       *Table);
 
-void
-AcpiDmDumpNfit (
-    ACPI_TABLE_HEADER       *Table);
-
 void
 AcpiDmDumpPcct (
     ACPI_TABLE_HEADER       *Table);
@@ -664,14 +594,6 @@ void
 AcpiDmDumpSrat (
     ACPI_TABLE_HEADER       *Table);
 
-void
-AcpiDmDumpStao (
-    ACPI_TABLE_HEADER       *Table);
-
-void
-AcpiDmDumpTcpa (
-    ACPI_TABLE_HEADER       *Table);
-
 void
 AcpiDmDumpVrtc (
     ACPI_TABLE_HEADER       *Table);
@@ -680,10 +602,6 @@ void
 AcpiDmDumpWdat (
     ACPI_TABLE_HEADER       *Table);
 
-void
-AcpiDmDumpWpbt (
-    ACPI_TABLE_HEADER       *Table);
-
 void
 AcpiDmDumpXsdt (
     ACPI_TABLE_HEADER       *Table);
@@ -715,6 +633,10 @@ AcpiDmDisassembleOneOp (
     ACPI_OP_WALK_INFO       *Info,
     ACPI_PARSE_OBJECT       *Op);
 
+void
+AcpiDmDecodeInternalObject (
+    ACPI_OPERAND_OBJECT     *ObjDesc);
+
 UINT32
 AcpiDmListType (
     ACPI_PARSE_OBJECT       *Op);
@@ -773,6 +695,29 @@ AcpiDmNamestring (
     char                    *Name);
 
 
+/*
+ * dmobject
+ */
+void
+AcpiDmDisplayInternalObject (
+    ACPI_OPERAND_OBJECT     *ObjDesc,
+    ACPI_WALK_STATE         *WalkState);
+
+void
+AcpiDmDisplayArguments (
+    ACPI_WALK_STATE         *WalkState);
+
+void
+AcpiDmDisplayLocals (
+    ACPI_WALK_STATE         *WalkState);
+
+void
+AcpiDmDumpMethodInfo (
+    ACPI_STATUS             Status,
+    ACPI_WALK_STATE         *WalkState,
+    ACPI_PARSE_OBJECT       *Op);
+
+
 /*
  * dmbuffer
  */
@@ -919,84 +864,72 @@ AcpiDmDescriptorName (
  */
 void
 AcpiDmWordDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmDwordDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmExtendedDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmQwordDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmMemory24Descriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmMemory32Descriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmFixedMemory32Descriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmGenericRegisterDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmInterruptDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmVendorLargeDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmGpioDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmSerialBusDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
@@ -1014,56 +947,48 @@ AcpiDmVendorCommon (
  */
 void
 AcpiDmIrqDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmDmaDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmFixedDmaDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmIoDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmFixedIoDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmStartDependentDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmEndDependentDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
 
 void
 AcpiDmVendorSmallDescriptor (
-    ACPI_OP_WALK_INFO       *Info,
     AML_RESOURCE            *Resource,
     UINT32                  Length,
     UINT32                  Level);
@@ -1102,28 +1027,12 @@ AcpiDmCheckResourceReference (
     ACPI_WALK_STATE         *WalkState);
 
 
-/*
- * dmcstyle
- */
-BOOLEAN
-AcpiDmCheckForSymbolicOpcode (
-    ACPI_PARSE_OBJECT       *Op,
-    ACPI_OP_WALK_INFO       *Info);
-
-void
-AcpiDmCloseOperator (
-    ACPI_PARSE_OBJECT       *Op);
-
-
 /*
  * acdisasm
  */
 void
 AdDisassemblerHeader (
-    char                    *Filename,
-    UINT8                   TableType);
+    char                    *Filename);
 
-#define ACPI_IS_AML_TABLE   0
-#define ACPI_IS_DATA_TABLE  1
 
 #endif  /* __ACDISASM_H__ */
