@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #ifndef __ACTBL2_H__
@@ -160,8 +124,8 @@
  * These tables are not consumed directly by the ACPICA subsystem, but are
  * included here to support device drivers and the AML disassembler.
  *
- * Generally, the tables in this file are defined by third-party specifications,
- * and are not defined directly by the ACPI specification itself.
+ * The tables in this file are defined by third-party specifications, and are
+ * not defined directly by the ACPI specification itself.
  *
  ******************************************************************************/
 
@@ -179,26 +143,21 @@
 #define ACPI_SIG_DMAR           "DMAR"      /* DMA Remapping table */
 #define ACPI_SIG_HPET           "HPET"      /* High Precision Event Timer table */
 #define ACPI_SIG_IBFT           "IBFT"      /* iSCSI Boot Firmware Table */
-#define ACPI_SIG_IORT           "IORT"      /* IO Remapping Table */
 #define ACPI_SIG_IVRS           "IVRS"      /* I/O Virtualization Reporting Structure */
 #define ACPI_SIG_LPIT           "LPIT"      /* Low Power Idle Table */
 #define ACPI_SIG_MCFG           "MCFG"      /* PCI Memory Mapped Configuration table */
 #define ACPI_SIG_MCHI           "MCHI"      /* Management Controller Host Interface table */
-#define ACPI_SIG_MSDM           "MSDM"      /* Microsoft Data Management Table */
 #define ACPI_SIG_MTMR           "MTMR"      /* MID Timer table */
 #define ACPI_SIG_SLIC           "SLIC"      /* Software Licensing Description Table */
 #define ACPI_SIG_SPCR           "SPCR"      /* Serial Port Console Redirection table */
 #define ACPI_SIG_SPMI           "SPMI"      /* Server Platform Management Interface table */
 #define ACPI_SIG_TCPA           "TCPA"      /* Trusted Computing Platform Alliance table */
-#define ACPI_SIG_TPM2           "TPM2"      /* Trusted Platform Module 2.0 H/W interface table */
 #define ACPI_SIG_UEFI           "UEFI"      /* Uefi Boot Optimization Table */
 #define ACPI_SIG_VRTC           "VRTC"      /* Virtual Real Time Clock Table */
 #define ACPI_SIG_WAET           "WAET"      /* Windows ACPI Emulated devices Table */
 #define ACPI_SIG_WDAT           "WDAT"      /* Watchdog Action Table */
 #define ACPI_SIG_WDDT           "WDDT"      /* Watchdog Timer Description Table */
 #define ACPI_SIG_WDRT           "WDRT"      /* Watchdog Resource Table */
-#define ACPI_SIG_WSMT           "WSMT"      /* Windows SMM Security Migrations Table */
-#define ACPI_SIG_XXXX           "XXXX"      /* Intermediate AML header for ASL/ASL+ converter */
 
 #ifdef ACPI_UNDEFINED_TABLES
 /*
@@ -474,7 +433,7 @@ typedef struct acpi_csrt_descriptor
  * DBG2 - Debug Port Table 2
  *        Version 0 (Both main table and subtables)
  *
- * Conforms to "Microsoft Debug Port Table 2 (DBG2)", December 10, 2015
+ * Conforms to "Microsoft Debug Port Table 2 (DBG2)", May 22 2012.
  *
  ******************************************************************************/
 
@@ -531,11 +490,6 @@ typedef struct acpi_dbg2_device
 
 #define ACPI_DBG2_16550_COMPATIBLE  0x0000
 #define ACPI_DBG2_16550_SUBSET      0x0001
-#define ACPI_DBG2_ARM_PL011         0x0003
-#define ACPI_DBG2_ARM_SBSA_32BIT    0x000D
-#define ACPI_DBG2_ARM_SBSA_GENERIC  0x000E
-#define ACPI_DBG2_ARM_DCC           0x000F
-#define ACPI_DBG2_BCM2835           0x0010
 
 #define ACPI_DBG2_1394_STANDARD     0x0000
 
@@ -568,7 +522,7 @@ typedef struct acpi_table_dbgp
  *        Version 1
  *
  * Conforms to "Intel Virtualization Technology for Directed I/O",
- * Version 2.3, October 2014
+ * Version 2.2, Sept. 2013
  *
  ******************************************************************************/
 
@@ -584,8 +538,6 @@ typedef struct acpi_table_dmar
 /* Masks for Flags field above */
 
 #define ACPI_DMAR_INTR_REMAP        (1)
-#define ACPI_DMAR_X2APIC_OPT_OUT    (1<<1)
-#define ACPI_DMAR_X2APIC_MODE       (1<<2)
 
 
 /* DMAR subtable header */
@@ -869,199 +821,6 @@ typedef struct acpi_ibft_target
 } ACPI_IBFT_TARGET;
 
 
-/*******************************************************************************
- *
- * IORT - IO Remapping Table
- *
- * Conforms to "IO Remapping Table System Software on ARM Platforms",
- * Document number: ARM DEN 0049C, May 2017
- *
- ******************************************************************************/
-
-typedef struct acpi_table_iort
-{
-    ACPI_TABLE_HEADER       Header;
-    UINT32                  NodeCount;
-    UINT32                  NodeOffset;
-    UINT32                  Reserved;
-
-} ACPI_TABLE_IORT;
-
-
-/*
- * IORT subtables
- */
-typedef struct acpi_iort_node
-{
-    UINT8                   Type;
-    UINT16                  Length;
-    UINT8                   Revision;
-    UINT32                  Reserved;
-    UINT32                  MappingCount;
-    UINT32                  MappingOffset;
-    char                    NodeData[1];
-
-} ACPI_IORT_NODE;
-
-/* Values for subtable Type above */
-
-enum AcpiIortNodeType
-{
-    ACPI_IORT_NODE_ITS_GROUP            = 0x00,
-    ACPI_IORT_NODE_NAMED_COMPONENT      = 0x01,
-    ACPI_IORT_NODE_PCI_ROOT_COMPLEX     = 0x02,
-    ACPI_IORT_NODE_SMMU                 = 0x03,
-    ACPI_IORT_NODE_SMMU_V3              = 0x04
-};
-
-
-typedef struct acpi_iort_id_mapping
-{
-    UINT32                  InputBase;          /* Lowest value in input range */
-    UINT32                  IdCount;            /* Number of IDs */
-    UINT32                  OutputBase;         /* Lowest value in output range */
-    UINT32                  OutputReference;    /* A reference to the output node */
-    UINT32                  Flags;
-
-} ACPI_IORT_ID_MAPPING;
-
-/* Masks for Flags field above for IORT subtable */
-
-#define ACPI_IORT_ID_SINGLE_MAPPING (1)
-
-
-typedef struct acpi_iort_memory_access
-{
-    UINT32                  CacheCoherency;
-    UINT8                   Hints;
-    UINT16                  Reserved;
-    UINT8                   MemoryFlags;
-
-} ACPI_IORT_MEMORY_ACCESS;
-
-/* Values for CacheCoherency field above */
-
-#define ACPI_IORT_NODE_COHERENT         0x00000001  /* The device node is fully coherent */
-#define ACPI_IORT_NODE_NOT_COHERENT     0x00000000  /* The device node is not coherent */
-
-/* Masks for Hints field above */
-
-#define ACPI_IORT_HT_TRANSIENT          (1)
-#define ACPI_IORT_HT_WRITE              (1<<1)
-#define ACPI_IORT_HT_READ               (1<<2)
-#define ACPI_IORT_HT_OVERRIDE           (1<<3)
-
-/* Masks for MemoryFlags field above */
-
-#define ACPI_IORT_MF_COHERENCY          (1)
-#define ACPI_IORT_MF_ATTRIBUTES         (1<<1)
-
-
-/*
- * IORT node specific subtables
- */
-typedef struct acpi_iort_its_group
-{
-    UINT32                  ItsCount;
-    UINT32                  Identifiers[1];         /* GIC ITS identifier arrary */
-
-} ACPI_IORT_ITS_GROUP;
-
-
-typedef struct acpi_iort_named_component
-{
-    UINT32                  NodeFlags;
-    UINT64                  MemoryProperties;       /* Memory access properties */
-    UINT8                   MemoryAddressLimit;     /* Memory address size limit */
-    char                    DeviceName[1];          /* Path of namespace object */
-
-} ACPI_IORT_NAMED_COMPONENT;
-
-
-typedef struct acpi_iort_root_complex
-{
-    UINT64                  MemoryProperties;       /* Memory access properties */
-    UINT32                  AtsAttribute;
-    UINT32                  PciSegmentNumber;
-
-} ACPI_IORT_ROOT_COMPLEX;
-
-/* Values for AtsAttribute field above */
-
-#define ACPI_IORT_ATS_SUPPORTED         0x00000001  /* The root complex supports ATS */
-#define ACPI_IORT_ATS_UNSUPPORTED       0x00000000  /* The root complex doesn't support ATS */
-
-
-typedef struct acpi_iort_smmu
-{
-    UINT64                  BaseAddress;            /* SMMU base address */
-    UINT64                  Span;                   /* Length of memory range */
-    UINT32                  Model;
-    UINT32                  Flags;
-    UINT32                  GlobalInterruptOffset;
-    UINT32                  ContextInterruptCount;
-    UINT32                  ContextInterruptOffset;
-    UINT32                  PmuInterruptCount;
-    UINT32                  PmuInterruptOffset;
-    UINT64                  Interrupts[1];          /* Interrupt array */
-
-} ACPI_IORT_SMMU;
-
-/* Values for Model field above */
-
-#define ACPI_IORT_SMMU_V1               0x00000000  /* Generic SMMUv1 */
-#define ACPI_IORT_SMMU_V2               0x00000001  /* Generic SMMUv2 */
-#define ACPI_IORT_SMMU_CORELINK_MMU400  0x00000002  /* ARM Corelink MMU-400 */
-#define ACPI_IORT_SMMU_CORELINK_MMU500  0x00000003  /* ARM Corelink MMU-500 */
-#define ACPI_IORT_SMMU_CORELINK_MMU401  0x00000004  /* ARM Corelink MMU-401 */
-#define ACPI_IORT_SMMU_CAVIUM_THUNDERX  0x00000005  /* Cavium ThunderX SMMUv2 */
-
-/* Masks for Flags field above */
-
-#define ACPI_IORT_SMMU_DVM_SUPPORTED    (1)
-#define ACPI_IORT_SMMU_COHERENT_WALK    (1<<1)
-
-/* Global interrupt format */
-
-typedef struct acpi_iort_smmu_gsi
-{
-    UINT32                  NSgIrpt;
-    UINT32                  NSgIrptFlags;
-    UINT32                  NSgCfgIrpt;
-    UINT32                  NSgCfgIrptFlags;
-} ACPI_IORT_SMMU_GSI;
-
-
-typedef struct acpi_iort_smmu_v3
-{
-    UINT64                  BaseAddress;            /* SMMUv3 base address */
-    UINT32                  Flags;
-    UINT32                  Reserved;
-    UINT64                  VatosAddress;
-    UINT32                  Model;
-    UINT32                  EventGsiv;
-    UINT32                  PriGsiv;
-    UINT32                  GerrGsiv;
-    UINT32                  SyncGsiv;
-    UINT8                   Pxm;
-    UINT8                   Reserved1;
-    UINT16                  Reserved2;
-
-} ACPI_IORT_SMMU_V3;
-
-/* Values for Model field above */
-
-#define ACPI_IORT_SMMU_V3_GENERIC           0x00000000  /* Generic SMMUv3 */
-#define ACPI_IORT_SMMU_V3_HISILICON_HI161X  0x00000001  /* HiSilicon Hi161x SMMUv3 */
-#define ACPI_IORT_SMMU_V3_CAVIUM_CN99XX     0x00000002  /* Cavium CN99xx SMMUv3 */
-
-/* Masks for Flags field above */
-
-#define ACPI_IORT_SMMU_V3_COHACC_OVERRIDE   (1)
-#define ACPI_IORT_SMMU_V3_HTTU_OVERRIDE     (1<<1)
-#define ACPI_IORT_SMMU_V3_PXM_VALID         (1<<3)
-
-
 /*******************************************************************************
  *
  * IVRS - I/O Virtualization Reporting Structure
@@ -1264,7 +1023,7 @@ typedef struct acpi_ivrs_memory
  *
  * LPIT - Low Power Idle Table
  *
- * Conforms to "ACPI Low Power Idle Table (LPIT)" July 2014.
+ * Conforms to "ACPI Low Power Idle Table (LPIT) and _LPD Proposal (DRAFT)"
  *
  ******************************************************************************/
 
@@ -1292,7 +1051,7 @@ typedef struct acpi_lpit_header
 enum AcpiLpitType
 {
     ACPI_LPIT_TYPE_NATIVE_CSTATE    = 0x00,
-    ACPI_LPIT_TYPE_RESERVED         = 0x01      /* 1 and above are reserved */
+    ACPI_LPIT_TYPE_SIMPLE_IO        = 0x01
 };
 
 /* Masks for Flags field above  */
@@ -1318,6 +1077,24 @@ typedef struct acpi_lpit_native
 } ACPI_LPIT_NATIVE;
 
 
+/* 0x01: Simple I/O based LPI structure */
+
+typedef struct acpi_lpit_io
+{
+    ACPI_LPIT_HEADER        Header;
+    ACPI_GENERIC_ADDRESS    EntryTrigger;
+    UINT32                  TriggerAction;
+    UINT64                  TriggerValue;
+    UINT64                  TriggerMask;
+    ACPI_GENERIC_ADDRESS    MinimumIdleState;
+    UINT32                  Residency;
+    UINT32                  Latency;
+    ACPI_GENERIC_ADDRESS    ResidencyCounter;
+    UINT64                  CounterFrequency;
+
+} ACPI_LPIT_IO;
+
+
 /*******************************************************************************
  *
  * MCFG - PCI Memory Mapped Configuration table and subtable
@@ -1377,24 +1154,6 @@ typedef struct acpi_table_mchi
 } ACPI_TABLE_MCHI;
 
 
-/*******************************************************************************
- *
- * MSDM - Microsoft Data Management table
- *
- * Conforms to "Microsoft Software Licensing Tables (SLIC and MSDM)",
- * November 29, 2011. Copyright 2011 Microsoft
- *
- ******************************************************************************/
-
-/* Basic MSDM table is only the common ACPI header */
-
-typedef struct acpi_table_msdm
-{
-    ACPI_TABLE_HEADER       Header;             /* Common ACPI table header */
-
-} ACPI_TABLE_MSDM;
-
-
 /*******************************************************************************
  *
  * MTMR - MID Timer Table
@@ -1426,9 +1185,10 @@ typedef struct acpi_mtmr_entry
 /*******************************************************************************
  *
  * SLIC - Software Licensing Description Table
+ *        Version 1
  *
- * Conforms to "Microsoft Software Licensing Tables (SLIC and MSDM)",
- * November 29, 2011. Copyright 2011 Microsoft
+ * Conforms to "OEM Activation 2.0 for Windows Vista Operating Systems",
+ * Copyright 2006
  *
  ******************************************************************************/
 
@@ -1441,13 +1201,69 @@ typedef struct acpi_table_slic
 } ACPI_TABLE_SLIC;
 
 
+/* Common SLIC subtable header */
+
+typedef struct acpi_slic_header
+{
+    UINT32                  Type;
+    UINT32                  Length;
+
+} ACPI_SLIC_HEADER;
+
+/* Values for Type field above */
+
+enum AcpiSlicType
+{
+    ACPI_SLIC_TYPE_PUBLIC_KEY           = 0,
+    ACPI_SLIC_TYPE_WINDOWS_MARKER       = 1,
+    ACPI_SLIC_TYPE_RESERVED             = 2    /* 2 and greater are reserved */
+};
+
+
+/*
+ * SLIC Subtables, correspond to Type in ACPI_SLIC_HEADER
+ */
+
+/* 0: Public Key Structure */
+
+typedef struct acpi_slic_key
+{
+    ACPI_SLIC_HEADER        Header;
+    UINT8                   KeyType;
+    UINT8                   Version;
+    UINT16                  Reserved;
+    UINT32                  Algorithm;
+    char                    Magic[4];
+    UINT32                  BitLength;
+    UINT32                  Exponent;
+    UINT8                   Modulus[128];
+
+} ACPI_SLIC_KEY;
+
+
+/* 1: Windows Marker Structure */
+
+typedef struct acpi_slic_marker
+{
+    ACPI_SLIC_HEADER        Header;
+    UINT32                  Version;
+    char                    OemId[ACPI_OEM_ID_SIZE];            /* ASCII OEM identification */
+    char                    OemTableId[ACPI_OEM_TABLE_ID_SIZE]; /* ASCII OEM table identification */
+    char                    WindowsFlag[8];
+    UINT32                  SlicVersion;
+    UINT8                   Reserved[16];
+    UINT8                   Signature[128];
+
+} ACPI_SLIC_MARKER;
+
+
 /*******************************************************************************
  *
  * SPCR - Serial Port Console Redirection table
- *        Version 2
+ *        Version 1
  *
  * Conforms to "Serial Port Console Redirection Table",
- * Version 1.03, August 10, 2015
+ * Version 1.00, January 11, 2002
  *
  ******************************************************************************/
 
@@ -1481,8 +1297,6 @@ typedef struct acpi_table_spcr
 
 #define ACPI_SPCR_DO_NOT_DISABLE    (1)
 
-/* Values for Interface Type: See the definition of the DBG2 table */
-
 
 /*******************************************************************************
  *
@@ -1531,141 +1345,21 @@ enum AcpiSpmiInterfaceTypes
 /*******************************************************************************
  *
  * TCPA - Trusted Computing Platform Alliance table
- *        Version 2
+ *        Version 1
  *
- * Conforms to "TCG ACPI Specification, Family 1.2 and 2.0",
- * Version 1.2, Revision 8
- * February 27, 2017
- *
- * NOTE: There are two versions of the table with the same signature --
- * the client version and the server version. The common PlatformClass
- * field is used to differentiate the two types of tables.
+ * Conforms to "TCG PC Specific Implementation Specification",
+ * Version 1.1, August 18, 2003
  *
  ******************************************************************************/
 
-typedef struct acpi_table_tcpa_hdr
+typedef struct acpi_table_tcpa
 {
     ACPI_TABLE_HEADER       Header;             /* Common ACPI table header */
-    UINT16                  PlatformClass;
-
-} ACPI_TABLE_TCPA_HDR;
-
-/*
- * Values for PlatformClass above.
- * This is how the client and server subtables are differentiated
- */
-#define ACPI_TCPA_CLIENT_TABLE          0
-#define ACPI_TCPA_SERVER_TABLE          1
-
-
-typedef struct acpi_table_tcpa_client
-{
-    UINT32                  MinimumLogLength;   /* Minimum length for the event log area */
+    UINT16                  Reserved;
+    UINT32                  MaxLogLength;       /* Maximum length for the event log area */
     UINT64                  LogAddress;         /* Address of the event log area */
 
-} ACPI_TABLE_TCPA_CLIENT;
-
-typedef struct acpi_table_tcpa_server
-{
-    UINT16                  Reserved;
-    UINT64                  MinimumLogLength;   /* Minimum length for the event log area */
-    UINT64                  LogAddress;         /* Address of the event log area */
-    UINT16                  SpecRevision;
-    UINT8                   DeviceFlags;
-    UINT8                   InterruptFlags;
-    UINT8                   GpeNumber;
-    UINT8                   Reserved2[3];
-    UINT32                  GlobalInterrupt;
-    ACPI_GENERIC_ADDRESS    Address;
-    UINT32                  Reserved3;
-    ACPI_GENERIC_ADDRESS    ConfigAddress;
-    UINT8                   Group;
-    UINT8                   Bus;                /* PCI Bus/Segment/Function numbers */
-    UINT8                   Device;
-    UINT8                   Function;
-
-} ACPI_TABLE_TCPA_SERVER;
-
-/* Values for DeviceFlags above */
-
-#define ACPI_TCPA_PCI_DEVICE            (1)
-#define ACPI_TCPA_BUS_PNP               (1<<1)
-#define ACPI_TCPA_ADDRESS_VALID         (1<<2)
-
-/* Values for InterruptFlags above */
-
-#define ACPI_TCPA_INTERRUPT_MODE        (1)
-#define ACPI_TCPA_INTERRUPT_POLARITY    (1<<1)
-#define ACPI_TCPA_SCI_VIA_GPE           (1<<2)
-#define ACPI_TCPA_GLOBAL_INTERRUPT      (1<<3)
-
-
-/*******************************************************************************
- *
- * TPM2 - Trusted Platform Module (TPM) 2.0 Hardware Interface Table
- *        Version 4
- *
- * Conforms to "TCG ACPI Specification, Family 1.2 and 2.0",
- * Version 1.2, Revision 8
- * February 27, 2017
- *
- ******************************************************************************/
-
-typedef struct acpi_table_tpm2
-{
-    ACPI_TABLE_HEADER       Header;             /* Common ACPI table header */
-    UINT16                  PlatformClass;
-    UINT16                  Reserved;
-    UINT64                  ControlAddress;
-    UINT32                  StartMethod;
-
-    /* Platform-specific data follows */
-
-} ACPI_TABLE_TPM2;
-
-/* Values for StartMethod above */
-
-#define ACPI_TPM2_NOT_ALLOWED                       0
-#define ACPI_TPM2_START_METHOD                      2
-#define ACPI_TPM2_MEMORY_MAPPED                     6
-#define ACPI_TPM2_COMMAND_BUFFER                    7
-#define ACPI_TPM2_COMMAND_BUFFER_WITH_START_METHOD  8
-#define ACPI_TPM2_COMMAND_BUFFER_WITH_ARM_SMC       11  /* V1.2 Rev 8 */
-
-
-/* Trailer appears after any StartMethod subtables */
-
-typedef struct acpi_tpm2_trailer
-{
-    UINT32                  MinimumLogLength;   /* Minimum length for the event log area */
-    UINT64                  LogAddress;         /* Address of the event log area */
-
-} ACPI_TPM2_TRAILER;
-
-
-/*
- * Subtables (StartMethod-specific)
- */
-
-/* 11: Start Method for ARM SMC (V1.2 Rev 8) */
-
-typedef struct acpi_tpm2_arm_smc
-{
-    UINT32                  GlobalInterrupt;
-    UINT8                   InterruptFlags;
-    UINT8                   OperationFlags;
-    UINT16                  Reserved;
-    UINT32                  FunctionId;
-
-} ACPI_TPM2_ARM_SMC;
-
-/* Values for InterruptFlags above */
-
-#define ACPI_TPM2_INTERRUPT_SUPPORT     (1)
-
-/* Values for OperationFlags above */
-
-#define ACPI_TPM2_IDLE_SUPPORT          (1)
+} ACPI_TABLE_TCPA;
 
 
 /*******************************************************************************
@@ -1885,30 +1579,6 @@ typedef struct acpi_table_wdrt
 } ACPI_TABLE_WDRT;
 
 
-/*******************************************************************************
- *
- * WSMT - Windows SMM Security Migrations Table
- *        Version 1
- *
- * Conforms to "Windows SMM Security Migrations Table",
- * Version 1.0, April 18, 2016
- *
- ******************************************************************************/
-
-typedef struct acpi_table_wsmt
-{
-    ACPI_TABLE_HEADER       Header;             /* Common ACPI table header */
-    UINT32                  ProtectionFlags;
-
-} ACPI_TABLE_WSMT;
-
-/* Flags for ProtectionFlags field above */
-
-#define ACPI_WSMT_FIXED_COMM_BUFFERS                (1)
-#define ACPI_WSMT_COMM_BUFFER_NESTED_PTR_PROTECTION (2)
-#define ACPI_WSMT_SYSTEM_RESOURCE_PROTECTION        (4)
-
-
 /* Reset to default packing */
 
 #pragma pack()
