@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -240,7 +240,7 @@ ApGetTableLength (
     if (ACPI_VALIDATE_RSDP_SIG (Table->Signature))
     {
         Rsdp = ACPI_CAST_PTR (ACPI_TABLE_RSDP, Table);
-        return (AcpiTbGetRsdpLength (Rsdp));
+        return (Rsdp->Length);
     }
 
     /* Normal ACPI table */
@@ -447,7 +447,7 @@ ApDumpTableByName (
     int                     TableStatus;
 
 
-    if (strlen (Signature) != ACPI_NAME_SIZE)
+    if (ACPI_STRLEN (Signature) != ACPI_NAME_SIZE)
     {
         AcpiLogError (
             "Invalid table signature [%s]: must be exactly 4 characters\n",
@@ -457,18 +457,18 @@ ApDumpTableByName (
 
     /* Table signatures are expected to be uppercase */
 
-    strcpy (LocalSignature, Signature);
+    ACPI_STRCPY (LocalSignature, Signature);
     AcpiUtStrupr (LocalSignature);
 
     /* To be friendly, handle tables whose signatures do not match the name */
 
     if (ACPI_COMPARE_NAME (LocalSignature, "FADT"))
     {
-        strcpy (LocalSignature, ACPI_SIG_FADT);
+        ACPI_STRCPY (LocalSignature, ACPI_SIG_FADT);
     }
     else if (ACPI_COMPARE_NAME (LocalSignature, "MADT"))
     {
-        strcpy (LocalSignature, ACPI_SIG_MADT);
+        ACPI_STRCPY (LocalSignature, ACPI_SIG_MADT);
     }
 
     /* Dump all instances of this signature (to handle multiple SSDTs) */
