@@ -8,13 +8,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2012, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +31,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +43,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +55,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +80,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +92,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -115,29 +115,59 @@
 
 #include "aecommon.h"
 
-#ifdef _DEBUG
-#include <crtdbg.h>
-#endif
-
-#define _COMPONENT          PARSER
+#define _COMPONENT          ACPI_TOOLS
         ACPI_MODULE_NAME    ("aemain")
 
 
-UINT8                   AcpiGbl_RegionFillValue = 0;
-BOOLEAN                 AcpiGbl_IgnoreErrors = FALSE;
-BOOLEAN                 AcpiGbl_DbOpt_NoRegionSupport = FALSE;
-BOOLEAN                 AcpiGbl_DebugTimeout = FALSE;
-UINT8                   AcpiGbl_UseHwReducedFadt = FALSE;
+/*
+ * Main routine for the ACPI user-space execution utility.
+ *
+ * Portability note: The utility depends upon the host for command-line
+ * wildcard support - it is not implemented locally. For example:
+ *
+ * Linux/Unix systems: Shell expands wildcards automatically.
+ *
+ * Windows: The setargv.obj module must be linked in to automatically
+ * expand wildcards.
+ */
+extern BOOLEAN              AcpiGbl_DebugTimeout;
 
-static UINT8            AcpiGbl_BatchMode = 0;
-static char             BatchBuffer[128];
-static AE_TABLE_DESC    *AeTableListHead = NULL;
+/* Local prototypes */
 
-#define ASL_MAX_FILES   256
-static char             *FileList[ASL_MAX_FILES];
+static int
+AeDoOptions (
+    int                     argc,
+    char                    **argv);
+
+static ACPI_STATUS
+AcpiDbRunBatchMode (
+    void);
 
 
-#define AE_SUPPORTED_OPTIONS    "?b:d:e:f:gm^orv:x:"
+#define AE_BUFFER_SIZE              1024
+#define ASL_MAX_FILES               256
+
+/* Execution modes */
+
+#define AE_MODE_COMMAND_LOOP        0   /* Normal command execution loop */
+#define AE_MODE_BATCH_MULTIPLE      1   /* -b option to execute a command line */
+#define AE_MODE_BATCH_SINGLE        2   /* -m option to execute a single control method */
+
+
+/* Globals */
+
+UINT8                       AcpiGbl_RegionFillValue = 0;
+BOOLEAN                     AcpiGbl_IgnoreErrors = FALSE;
+BOOLEAN                     AcpiGbl_DbOpt_NoRegionSupport = FALSE;
+UINT8                       AcpiGbl_UseHwReducedFadt = FALSE;
+BOOLEAN                     AcpiGbl_DoInterfaceTests = FALSE;
+BOOLEAN                     AcpiGbl_LoadTestTables = FALSE;
+static UINT8                AcpiGbl_ExecutionMode = AE_MODE_COMMAND_LOOP;
+static char                 BatchBuffer[AE_BUFFER_SIZE];    /* Batch command buffer */
+static AE_TABLE_DESC        *AeTableListHead = NULL;
+
+#define ACPIEXEC_NAME               "AML Execution/Debug Utility"
+#define AE_SUPPORTED_OPTIONS        "?b:d:e:f:ghm^orv^:x:"
 
 
 /******************************************************************************
@@ -153,13 +183,14 @@ static char             *FileList[ASL_MAX_FILES];
  *****************************************************************************/
 
 static void
-usage (void)
+usage (
+    void)
 {
 
     ACPI_USAGE_HEADER ("acpiexec [options] AMLfile1 AMLfile2 ...");
 
-    ACPI_OPTION ("-?",                  "Display this message");
-    ACPI_OPTION ("-b <CommandLine>",    "Batch mode command execution");
+    ACPI_OPTION ("-b \"CommandLine\"",  "Batch mode command line execution (cmd1;cmd2;...)");
+    ACPI_OPTION ("-h -?",               "Display this help message");
     ACPI_OPTION ("-m [Method]",         "Batch mode method execution. Default=MAIN");
     printf ("\n");
 
@@ -167,23 +198,442 @@ usage (void)
     ACPI_OPTION ("-di",                 "Disable execution of STA/INI methods during init");
     ACPI_OPTION ("-do",                 "Disable Operation Region address simulation");
     ACPI_OPTION ("-dr",                 "Disable repair of method return values");
+    ACPI_OPTION ("-ds",                 "Disable method auto-serialization");
     ACPI_OPTION ("-dt",                 "Disable allocation tracking (performance)");
     printf ("\n");
 
     ACPI_OPTION ("-ef",                 "Enable display of final memory statistics");
-    ACPI_OPTION ("-em",                 "Enable Interpreter Serialized Mode");
+    ACPI_OPTION ("-ei",                 "Enable additional tests for ACPICA interfaces");
+    ACPI_OPTION ("-el",                 "Enable loading of additional test tables");
     ACPI_OPTION ("-es",                 "Enable Interpreter Slack Mode");
     ACPI_OPTION ("-et",                 "Enable debug semaphore timeout");
     printf ("\n");
 
     ACPI_OPTION ("-f <Value>",          "Operation Region initialization fill value");
     ACPI_OPTION ("-r",                  "Use hardware-reduced FADT V5");
+    ACPI_OPTION ("-v",                  "Display version information");
     ACPI_OPTION ("-vi",                 "Verbose initialization output");
     ACPI_OPTION ("-vr",                 "Verbose region handler output");
     ACPI_OPTION ("-x <DebugLevel>",     "Debug output level");
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    AeDoOptions
+ *
+ * PARAMETERS:  argc/argv           - Standard argc/argv
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Command line option processing
+ *
+ *****************************************************************************/
+
+static int
+AeDoOptions (
+    int                     argc,
+    char                    **argv)
+{
+    int                     j;
+
+
+    while ((j = AcpiGetopt (argc, argv, AE_SUPPORTED_OPTIONS)) != ACPI_OPT_END) switch (j)
+    {
+    case 'b':
+
+        if (strlen (AcpiGbl_Optarg) > (AE_BUFFER_SIZE -1))
+        {
+            printf ("**** The length of command line (%u) exceeded maximum (%u)\n",
+                (UINT32) strlen (AcpiGbl_Optarg), (AE_BUFFER_SIZE -1));
+            return (-1);
+        }
+        AcpiGbl_ExecutionMode = AE_MODE_BATCH_MULTIPLE;
+        strcpy (BatchBuffer, AcpiGbl_Optarg);
+        break;
+
+    case 'd':
+
+        switch (AcpiGbl_Optarg[0])
+        {
+        case 'a':
+
+            AcpiGbl_IgnoreErrors = TRUE;
+            break;
+
+        case 'i':
+
+            AcpiGbl_DbOpt_ini_methods = FALSE;
+            break;
+
+        case 'o':
+
+            AcpiGbl_DbOpt_NoRegionSupport = TRUE;
+            break;
+
+        case 'r':
+
+            AcpiGbl_DisableAutoRepair = TRUE;
+            break;
+
+        case 's':
+
+            AcpiGbl_AutoSerializeMethods = FALSE;
+            break;
+
+        case 't':
+
+            #ifdef ACPI_DBG_TRACK_ALLOCATIONS
+                AcpiGbl_DisableMemTracking = TRUE;
+            #endif
+            break;
+
+        default:
+
+            printf ("Unknown option: -d%s\n", AcpiGbl_Optarg);
+            return (-1);
+        }
+        break;
+
+    case 'e':
+
+        switch (AcpiGbl_Optarg[0])
+        {
+        case 'f':
+
+            #ifdef ACPI_DBG_TRACK_ALLOCATIONS
+                AcpiGbl_DisplayFinalMemStats = TRUE;
+            #endif
+            break;
+
+        case 'i':
+
+            AcpiGbl_DoInterfaceTests = TRUE;
+            break;
+
+        case 'l':
+
+            AcpiGbl_LoadTestTables = TRUE;
+            break;
+
+        case 's':
+
+            AcpiGbl_EnableInterpreterSlack = TRUE;
+            printf ("Enabling AML Interpreter slack mode\n");
+            break;
+
+        case 't':
+
+            AcpiGbl_DebugTimeout = TRUE;
+            break;
+
+        default:
+
+            printf ("Unknown option: -e%s\n", AcpiGbl_Optarg);
+            return (-1);
+        }
+        break;
+
+    case 'f':
+
+        AcpiGbl_RegionFillValue = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
+        break;
+
+    case 'g':
+
+        AcpiGbl_DbOpt_tables = TRUE;
+        AcpiGbl_DbFilename = NULL;
+        break;
+
+    case 'h':
+    case '?':
+
+        usage();
+        return (0);
+
+    case 'm':
+
+        AcpiGbl_ExecutionMode = AE_MODE_BATCH_SINGLE;
+        switch (AcpiGbl_Optarg[0])
+        {
+        case '^':
+
+            strcpy (BatchBuffer, "MAIN");
+            break;
+
+        default:
+
+            strcpy (BatchBuffer, AcpiGbl_Optarg);
+            break;
+        }
+        break;
+
+    case 'o':
+
+        AcpiGbl_DbOpt_disasm = TRUE;
+        AcpiGbl_DbOpt_stats = TRUE;
+        break;
+
+    case 'r':
+
+        AcpiGbl_UseHwReducedFadt = TRUE;
+        printf ("Using ACPI 5.0 Hardware Reduced Mode via version 5 FADT\n");
+        break;
+
+    case 'v':
+
+        switch (AcpiGbl_Optarg[0])
+        {
+        case '^':  /* -v: (Version): signon already emitted, just exit */
+
+            exit (0);
+
+        case 'i':
+
+            AcpiDbgLevel |= ACPI_LV_INIT_NAMES;
+            break;
+
+        case 'r':
+
+            AcpiGbl_DisplayRegionAccess = TRUE;
+            break;
+
+        default:
+
+            printf ("Unknown option: -v%s\n", AcpiGbl_Optarg);
+            return (-1);
+        }
+        break;
+
+    case 'x':
+
+        AcpiDbgLevel = strtoul (AcpiGbl_Optarg, NULL, 0);
+        AcpiGbl_DbConsoleDebugLevel = AcpiDbgLevel;
+        printf ("Debug Level: 0x%8.8X\n", AcpiDbgLevel);
+        break;
+
+    default:
+
+        usage();
+        return (-1);
+    }
+
+    return (0);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    main
+ *
+ * PARAMETERS:  argc, argv
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Main routine for AcpiExec utility
+ *
+ *****************************************************************************/
+
+int ACPI_SYSTEM_XFACE
+main (
+    int                     argc,
+    char                    **argv)
+{
+    ACPI_STATUS             Status;
+    UINT32                  InitFlags;
+    ACPI_TABLE_HEADER       *Table = NULL;
+    UINT32                  TableCount;
+    AE_TABLE_DESC           *TableDesc;
+
+
+    ACPI_DEBUG_INITIALIZE (); /* For debug version only */
+    signal (SIGINT, AeCtrlCHandler);
+
+    /* Init debug globals */
+
+    AcpiDbgLevel = ACPI_NORMAL_DEFAULT;
+    AcpiDbgLayer = 0xFFFFFFFF;
+
+    /* Init ACPICA and start debugger thread */
+
+    Status = AcpiInitializeSubsystem ();
+    AE_CHECK_OK (AcpiInitializeSubsystem, Status);
+    if (ACPI_FAILURE (Status))
+    {
+        goto ErrorExit;
+    }
+
+    printf (ACPI_COMMON_SIGNON (ACPIEXEC_NAME));
+    if (argc < 2)
+    {
+        usage ();
+        return (0);
+    }
+
+    /* Get the command line options */
+
+    if (AeDoOptions (argc, argv))
+    {
+        goto ErrorExit;
+    }
+
+    /* The remaining arguments are filenames for ACPI tables */
+
+    if (!argv[AcpiGbl_Optind])
+    {
+        goto EnterDebugger;
+    }
+
+    AcpiGbl_DbOpt_tables = TRUE;
+    TableCount = 0;
+
+    /* Get each of the ACPI table files on the command line */
+
+    while (argv[AcpiGbl_Optind])
+    {
+        /* Get one entire table */
+
+        Status = AcpiUtReadTableFromFile (argv[AcpiGbl_Optind], &Table);
+        if (ACPI_FAILURE (Status))
+        {
+            printf ("**** Could not get table from file %s, %s\n",
+                argv[AcpiGbl_Optind], AcpiFormatException (Status));
+            goto ErrorExit;
+        }
+
+        /* Ignore non-AML tables, we can't use them. Except for an FADT */
+
+        if (!ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_FADT) &&
+            !AcpiUtIsAmlTable (Table))
+        {
+            ACPI_INFO ((AE_INFO,
+                "Table [%4.4s] is not an AML table, ignoring",
+                Table->Signature));
+            AcpiOsFree (Table);
+        }
+        else
+        {
+            /* Allocate and link a table descriptor */
+
+            TableDesc = AcpiOsAllocate (sizeof (AE_TABLE_DESC));
+            TableDesc->Table = Table;
+            TableDesc->Next = AeTableListHead;
+            AeTableListHead = TableDesc;
+
+            TableCount++;
+        }
+
+        AcpiGbl_Optind++;
+    }
+
+    printf ("\n");
+
+    /* Build a local RSDT with all tables and let ACPICA process the RSDT */
+
+    Status = AeBuildLocalTables (TableCount, AeTableListHead);
+    if (ACPI_FAILURE (Status))
+    {
+        goto ErrorExit;
+    }
+
+    Status = AeInstallTables ();
+    if (ACPI_FAILURE (Status))
+    {
+        printf ("**** Could not load ACPI tables, %s\n",
+            AcpiFormatException (Status));
+        goto EnterDebugger;
+    }
+
+    /*
+     * Install most of the handlers.
+     * Override some default region handlers, especially SystemMemory
+     */
+    Status = AeInstallEarlyHandlers ();
+    if (ACPI_FAILURE (Status))
+    {
+        goto EnterDebugger;
+    }
+
+    /* Setup initialization flags for ACPICA */
+
+    InitFlags = (ACPI_NO_HANDLER_INIT | ACPI_NO_ACPI_ENABLE);
+    if (!AcpiGbl_DbOpt_ini_methods)
+    {
+        InitFlags |= (ACPI_NO_DEVICE_INIT | ACPI_NO_OBJECT_INIT);
+    }
+
+    /*
+     * Main initialization for ACPICA subsystem
+     * TBD: Need a way to call this after the ACPI table "LOAD" command
+     */
+    Status = AcpiEnableSubsystem (InitFlags);
+    if (ACPI_FAILURE (Status))
+    {
+        printf ("**** Could not EnableSubsystem, %s\n",
+            AcpiFormatException (Status));
+        goto EnterDebugger;
+    }
+
+    /*
+     * Install handlers for "device driver" space IDs (EC,SMBus, etc.)
+     * and fixed event handlers
+     */
+    AeInstallLateHandlers ();
+
+    /* Finish the ACPICA initialization */
+
+    Status = AcpiInitializeObjects (InitFlags);
+    if (ACPI_FAILURE (Status))
+    {
+        printf ("**** Could not InitializeObjects, %s\n",
+            AcpiFormatException (Status));
+        goto EnterDebugger;
+    }
+
+    AeMiscellaneousTests ();
+
+
+EnterDebugger:
+
+    /* Exit if error above and we are in one of the batch modes */
+
+    if (ACPI_FAILURE (Status) && (AcpiGbl_ExecutionMode > 0))
+    {
+        goto ErrorExit;
+    }
+
+    /* Run a batch command or enter the command loop */
+
+    switch (AcpiGbl_ExecutionMode)
+    {
+    default:
+    case AE_MODE_COMMAND_LOOP:
+
+        AcpiDbUserCommands (ACPI_DEBUGGER_COMMAND_PROMPT, NULL);
+        break;
+
+    case AE_MODE_BATCH_MULTIPLE:
+
+        AcpiDbRunBatchMode ();
+        break;
+
+    case AE_MODE_BATCH_SINGLE:
+
+        AcpiDbExecute (BatchBuffer, NULL, NULL, EX_NO_SINGLE_STEP);
+        Status = AcpiTerminate ();
+        break;
+    }
+
+    return (0);
+
+
+ErrorExit:
+
+    (void) AcpiOsTerminate ();
+    return (-1);
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    AcpiDbRunBatchMode
@@ -238,538 +688,3 @@ AcpiDbRunBatchMode (
     Status = AcpiTerminate ();
     return (Status);
 }
-
-
-/*******************************************************************************
- *
- * FUNCTION:    FlStrdup
- *
- * DESCRIPTION: Local strdup function
- *
- ******************************************************************************/
-
-static char *
-FlStrdup (
-    char                *String)
-{
-    char                *NewString;
-
-
-    NewString = AcpiOsAllocate (strlen (String) + 1);
-    if (!NewString)
-    {
-        return (NULL);
-    }
-
-    strcpy (NewString, String);
-    return (NewString);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    FlSplitInputPathname
- *
- * PARAMETERS:  InputFilename       - The user-specified ASL source file to be
- *                                    compiled
- *              OutDirectoryPath    - Where the directory path prefix is
- *                                    returned
- *              OutFilename         - Where the filename part is returned
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Split the input path into a directory and filename part
- *              1) Directory part used to open include files
- *              2) Filename part used to generate output filenames
- *
- ******************************************************************************/
-
-ACPI_STATUS
-FlSplitInputPathname (
-    char                    *InputPath,
-    char                    **OutDirectoryPath,
-    char                    **OutFilename)
-{
-    char                    *Substring;
-    char                    *DirectoryPath;
-    char                    *Filename;
-
-
-    *OutDirectoryPath = NULL;
-    *OutFilename = NULL;
-
-    if (!InputPath)
-    {
-        return (AE_OK);
-    }
-
-    /* Get the path to the input filename's directory */
-
-    DirectoryPath = FlStrdup (InputPath);
-    if (!DirectoryPath)
-    {
-        return (AE_NO_MEMORY);
-    }
-
-    /* Convert backslashes to slashes in the entire path */
-
-    UtConvertBackslashes (DirectoryPath);
-
-    /* Backup to last slash or colon */
-
-    Substring = strrchr (DirectoryPath, '/');
-    if (!Substring)
-    {
-        Substring = strrchr (DirectoryPath, ':');
-    }
-
-    /* Extract the simple filename */
-
-    if (!Substring)
-    {
-        DirectoryPath[0] = 0;
-        Filename = FlStrdup (InputPath);
-    }
-    else
-    {
-        Filename = FlStrdup (Substring + 1);
-        *(Substring+1) = 0;
-    }
-
-    if (!Filename)
-    {
-        return (AE_NO_MEMORY);
-    }
-
-    *OutDirectoryPath = DirectoryPath;
-    *OutFilename = Filename;
-    return (AE_OK);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    AsDoWildcard
- *
- * PARAMETERS:  DirectoryPathname   - Path to parent directory
- *              FileSpecifier       - the wildcard specification (*.c, etc.)
- *
- * RETURN:      Pointer to a list of filenames
- *
- * DESCRIPTION: Process files via wildcards. This function is for the Windows
- *              case only.
- *
- ******************************************************************************/
-
-static char **
-AsDoWildcard (
-    char                    *DirectoryPathname,
-    char                    *FileSpecifier)
-{
-#ifdef WIN32
-    void                    *DirInfo;
-    char                    *Filename;
-    int                     FileCount;
-
-
-    FileCount = 0;
-
-    /* Open parent directory */
-
-    DirInfo = AcpiOsOpenDirectory (DirectoryPathname, FileSpecifier, REQUEST_FILE_ONLY);
-    if (!DirInfo)
-    {
-        /* Either the directory or file does not exist */
-
-        printf ("File or directory %s%s does not exist\n", DirectoryPathname, FileSpecifier);
-        return (NULL);
-    }
-
-    /* Process each file that matches the wildcard specification */
-
-    while ((Filename = AcpiOsGetNextFilename (DirInfo)))
-    {
-        /* Add the filename to the file list */
-
-        FileList[FileCount] = AcpiOsAllocate (strlen (Filename) + 1);
-        strcpy (FileList[FileCount], Filename);
-        FileCount++;
-
-        if (FileCount >= ASL_MAX_FILES)
-        {
-            printf ("Max files reached\n");
-            FileList[0] = NULL;
-            return (FileList);
-        }
-    }
-
-    /* Cleanup */
-
-    AcpiOsCloseDirectory (DirInfo);
-    FileList[FileCount] = NULL;
-    return (FileList);
-
-#else
-    if (!FileSpecifier)
-    {
-        return (NULL);
-    }
-
-    /*
-     * Linux/Unix cases - Wildcards are expanded by the shell automatically.
-     * Just return the filename in a null terminated list
-     */
-    FileList[0] = AcpiOsAllocate (strlen (FileSpecifier) + 1);
-    strcpy (FileList[0], FileSpecifier);
-    FileList[1] = NULL;
-
-    return (FileList);
-#endif
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    main
- *
- * PARAMETERS:  argc, argv
- *
- * RETURN:      Status
- *
- * DESCRIPTION: Main routine for AcpiDump utility
- *
- *****************************************************************************/
-
-int ACPI_SYSTEM_XFACE
-main (
-    int                     argc,
-    char                    **argv)
-{
-    int                     j;
-    ACPI_STATUS             Status;
-    UINT32                  InitFlags;
-    ACPI_TABLE_HEADER       *Table = NULL;
-    UINT32                  TableCount;
-    AE_TABLE_DESC           *TableDesc;
-    char                    **WildcardList;
-    char                    *Filename;
-    char                    *Directory;
-    char                    *FullPathname;
-
-
-#ifdef _DEBUG
-    _CrtSetDbgFlag (_CRTDBG_CHECK_ALWAYS_DF | _CRTDBG_LEAK_CHECK_DF |
-                    _CrtSetDbgFlag(_CRTDBG_REPORT_FLAG));
-#endif
-
-    printf (ACPI_COMMON_SIGNON ("AML Execution/Debug Utility"));
-
-    if (argc < 2)
-    {
-        usage ();
-        return (0);
-    }
-
-    signal (SIGINT, AeCtrlCHandler);
-
-    /* Init globals */
-
-    AcpiDbgLevel = ACPI_NORMAL_DEFAULT;
-    AcpiDbgLayer = 0xFFFFFFFF;
-
-    /* Init ACPI and start debugger thread */
-
-    Status = AcpiInitializeSubsystem ();
-    AE_CHECK_OK (AcpiInitializeSubsystem, Status);
-
-    /* Get the command line options */
-
-    while ((j = AcpiGetopt (argc, argv, AE_SUPPORTED_OPTIONS)) != EOF) switch(j)
-    {
-    case 'b':
-        if (strlen (AcpiGbl_Optarg) > 127)
-        {
-            printf ("**** The length of command line (%u) exceeded maximum (127)\n",
-                (UINT32) strlen (AcpiGbl_Optarg));
-            return (-1);
-        }
-        AcpiGbl_BatchMode = 1;
-        strcpy (BatchBuffer, AcpiGbl_Optarg);
-        break;
-
-    case 'd':
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'a':
-            AcpiGbl_IgnoreErrors = TRUE;
-            break;
-
-        case 'i':
-            AcpiGbl_DbOpt_ini_methods = FALSE;
-            break;
-
-        case 'o':
-            AcpiGbl_DbOpt_NoRegionSupport = TRUE;
-            break;
-
-        case 'r':
-            AcpiGbl_DisableAutoRepair = TRUE;
-            break;
-
-        case 't':
-            #ifdef ACPI_DBG_TRACK_ALLOCATIONS
-                AcpiGbl_DisableMemTracking = TRUE;
-            #endif
-            break;
-
-        default:
-            printf ("Unknown option: -d%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
-    case 'e':
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'f':
-            #ifdef ACPI_DBG_TRACK_ALLOCATIONS
-                AcpiGbl_DisplayFinalMemStats = TRUE;
-            #endif
-            break;
-
-        case 'm':
-            AcpiGbl_AllMethodsSerialized = TRUE;
-            printf ("Enabling AML Interpreter serialized mode\n");
-            break;
-
-        case 's':
-            AcpiGbl_EnableInterpreterSlack = TRUE;
-            printf ("Enabling AML Interpreter slack mode\n");
-            break;
-
-        case 't':
-            AcpiGbl_DebugTimeout = TRUE;
-            break;
-
-        default:
-            printf ("Unknown option: -e%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
-    case 'f':
-        AcpiGbl_RegionFillValue = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
-        break;
-
-    case 'g':
-        AcpiGbl_DbOpt_tables = TRUE;
-        AcpiGbl_DbFilename = NULL;
-        break;
-
-    case 'm':
-        AcpiGbl_BatchMode = 2;
-        switch (AcpiGbl_Optarg[0])
-        {
-        case '^':
-            strcpy (BatchBuffer, "MAIN");
-            break;
-
-        default:
-            strcpy (BatchBuffer, AcpiGbl_Optarg);
-            break;
-        }
-        break;
-
-    case 'o':
-        AcpiGbl_DbOpt_disasm = TRUE;
-        AcpiGbl_DbOpt_stats = TRUE;
-        break;
-
-    case 'r':
-        AcpiGbl_UseHwReducedFadt = TRUE;
-        printf ("Using ACPI 5.0 Hardware Reduced Mode via version 5 FADT\n");
-        break;
-
-    case 'v':
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'i':
-            AcpiDbgLevel |= ACPI_LV_INIT_NAMES;
-            break;
-
-        case 'r':
-            AcpiGbl_DisplayRegionAccess = TRUE;
-            break;
-
-        default:
-            printf ("Unknown option: -v%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
-    case 'x':
-        AcpiDbgLevel = strtoul (AcpiGbl_Optarg, NULL, 0);
-        AcpiGbl_DbConsoleDebugLevel = AcpiDbgLevel;
-        printf ("Debug Level: 0x%8.8X\n", AcpiDbgLevel);
-        break;
-
-    case '?':
-    case 'h':
-    default:
-        usage();
-        return (-1);
-    }
-
-
-    InitFlags = (ACPI_NO_HANDLER_INIT | ACPI_NO_ACPI_ENABLE);
-    if (!AcpiGbl_DbOpt_ini_methods)
-    {
-        InitFlags |= (ACPI_NO_DEVICE_INIT | ACPI_NO_OBJECT_INIT);
-    }
-
-    /* The remaining arguments are filenames for ACPI tables */
-
-    if (argv[AcpiGbl_Optind])
-    {
-        AcpiGbl_DbOpt_tables = TRUE;
-        TableCount = 0;
-
-        /* Get each of the ACPI table files on the command line */
-
-        while (argv[AcpiGbl_Optind])
-        {
-            /* Split incoming path into a directory/filename combo */
-
-            Status = FlSplitInputPathname (argv[AcpiGbl_Optind], &Directory, &Filename);
-            if (ACPI_FAILURE (Status))
-            {
-                return (Status);
-            }
-
-            /* Expand wildcards (Windows only) */
-
-            WildcardList = AsDoWildcard (Directory, Filename);
-            if (!WildcardList)
-            {
-                return (-1);
-            }
-
-            while (*WildcardList)
-            {
-                FullPathname = AcpiOsAllocate (
-                    strlen (Directory) + strlen (*WildcardList) + 1);
-
-                /* Construct a full path to the file */
-
-                strcpy (FullPathname, Directory);
-                strcat (FullPathname, *WildcardList);
-
-                /* Get one table */
-
-                Status = AcpiDbReadTableFromFile (FullPathname, &Table);
-                if (ACPI_FAILURE (Status))
-                {
-                    printf ("**** Could not get input table %s, %s\n", FullPathname,
-                        AcpiFormatException (Status));
-                    goto enterloop;
-                }
-
-                AcpiOsFree (FullPathname);
-                AcpiOsFree (*WildcardList);
-                *WildcardList = NULL;
-                WildcardList++;
-
-                /* Ignore non-AML tables, we can't use them. Except for an FADT */
-
-                if (!ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_FADT) &&
-                    !AcpiUtIsAmlTable (Table))
-                {
-                    ACPI_WARNING ((AE_INFO,"Table %4.4s is not an AML table, ignoring",
-                        Table->Signature));
-                    AcpiOsFree (Table);
-                    continue;
-                }
-
-                /* Allocate and link a table descriptor */
-
-                TableDesc = AcpiOsAllocate (sizeof (AE_TABLE_DESC));
-                TableDesc->Table = Table;
-                TableDesc->Next = AeTableListHead;
-                AeTableListHead = TableDesc;
-
-                TableCount++;
-            }
-
-            AcpiGbl_Optind++;
-        }
-
-        /* Build a local RSDT with all tables and let ACPICA process the RSDT */
-
-        Status = AeBuildLocalTables (TableCount, AeTableListHead);
-        if (ACPI_FAILURE (Status))
-        {
-            return (-1);
-        }
-
-        Status = AeInstallTables ();
-        if (ACPI_FAILURE (Status))
-        {
-            printf ("**** Could not load ACPI tables, %s\n", AcpiFormatException (Status));
-            goto enterloop;
-        }
-
-         /*
-          * Install most of the handlers.
-          * Override some default region handlers, especially SystemMemory
-          */
-        Status = AeInstallEarlyHandlers ();
-        if (ACPI_FAILURE (Status))
-        {
-            goto enterloop;
-        }
-
-        /*
-         * TBD: Need a way to call this after the "LOAD" command
-         */
-        Status = AcpiEnableSubsystem (InitFlags);
-        if (ACPI_FAILURE (Status))
-        {
-            printf ("**** Could not EnableSubsystem, %s\n", AcpiFormatException (Status));
-            goto enterloop;
-        }
-
-        Status = AcpiInitializeObjects (InitFlags);
-        if (ACPI_FAILURE (Status))
-        {
-            printf ("**** Could not InitializeObjects, %s\n", AcpiFormatException (Status));
-            goto enterloop;
-        }
-
-        /*
-         * Install handlers for "device driver" space IDs (EC,SMBus, etc.)
-         * and fixed event handlers
-         */
-        AeInstallLateHandlers ();
-        AeMiscellaneousTests ();
-    }
-
-enterloop:
-
-    if (AcpiGbl_BatchMode == 1)
-    {
-        AcpiDbRunBatchMode ();
-    }
-    else if (AcpiGbl_BatchMode == 2)
-    {
-        AcpiDbExecute (BatchBuffer, NULL, NULL, EX_NO_SINGLE_STEP);
-    }
-    else
-    {
-        /* Enter the debugger command loop */
-
-        AcpiDbUserCommands (ACPI_DEBUGGER_COMMAND_PROMPT, NULL);
-    }
-
-    return (0);
-}
-
